#!/usr/bin/env python

import os
import sys
import struct
import datetime
import locale
import math
import gtk
import cairo
import signal
import colorsys

from icc import ICC

basedir = os.path.dirname(os.path.realpath(__file__))
if not os.path.exists(os.path.join(basedir, "giccler.py")):
    if os.path.exists(os.path.join(os.getcwd(), "giccler.py")):
        basedir = os.getcwd()
sys.path.insert(0, basedir)

class Giccler(gtk.Window):
    
    profile    = None
    _stat      = None
    _grid      = 0
    hovered    = (-1, "", 0)
    clickdist  = (0, 0)
    handlesize = 10
    grad       = None
    in_color   = None
    mouse      = (0., 0.)
    smoothing  = 5
    smoothmax  = 20
    window     = [1,1,1,1,1,1,1,1,1,1]
    
    curves = {
        "r" : [(0,0.5), (1,0.5)],
        "g" : [(0,0.5), (1,0.5)],
        "b" : [(0,0.5), (1,0.5)]
    }
    
    colors = {
        "r" : (1, 0, 0),
        "g" : (0, 1, 0),
        "b" : (0, 0, 1)
    }
    
    ramps = {
        "r" : [],
        "g" : [],
        "b" : []
    }
    
    def __init__(self, args):
        super(Giccler, self).__init__()
        
        locale.setlocale(locale.LC_ALL, "")
        self.icc = ICC()
        
        self.set_smoothing(self.smoothing)
        
        signal.signal(signal.SIGINT, self.ctrlC)
        signal.signal(signal.SIGHUP, self.ctrlC)
        signal.signal(signal.SIGQUIT, self.ctrlC)
        signal.signal(signal.SIGABRT, self.ctrlC)
        signal.signal(signal.SIGSEGV, self.ctrlC)
        signal.signal(signal.SIGTERM, self.ctrlC)
        
        self.create_window()
        
        self.canvasses = {"r" : self.red, "g" : self.green, "b" : self.blue}
        self.toggles = {"r" : self.toggleRed, "g" : self.toggleGreen, "b" : self.toggleBlue}
        
        self.color_cb()
        self.colorstrip_cb()
        
        if len(args) > 1:
            self.load_profile(args[1])
            
    def load_profile(self, profile=None):
        if profile:
            self.profile = self.icc.open_profile(profile)
        else:
            self.profile = self.icc.from_scratch()
        profile = self.profile[1]
        self.set_title("Giccler - %s" % os.path.basename(profile))
        self.status.remove_all(self._stat)
        
        if self.profile[1] and self.icc.has_vcgt():
            self.status.push(self._stat, "Profile %s loaded." % profile)
        elif self.profile[1]:
            self.status.push(self._stat, "Profile %s has no VCGT data, aborting." % profile)
            self.profile = None
        else:
            self.status.push(self._stat, "Loading Profile %s failed!" % profile)
        
        for c in ("r", "g", "b"):
            self.ramps[c] = self.icc.get_color_ramp(c)
            self.reset_dots(c)
            self.canvasses[c].queue_draw()
    
    def apply_profile(self):
        for c in ("r", "g", "b"):
            if self.toggles[c].get_active() and not self.buttonBypass.get_active():
                self.icc.write_color(c, self.transform(c, self.smooth(self.ramps[c])))
            else:
                self.icc.write_color(c)
        self.icc.apply()
        
        #for i in self.colors:
            #self.reset_dots(i)
            #self.canvasses[i].queue_draw()
    
    def transform(self, color, ramp):
        dot = 0
        last = 0
        diff = 0
        stop = 0
        curve = self.curves[color]
        l = len(ramp)
        ld = len(curve)
        trans = []
        for i in range(0, l):
            x = float(i) / l
            while x > curve[dot][0] and not stop:
                last = dot
                d2 = min(ld - 1, dot + 1)
                if dot != d2 and (curve[d2][0] - curve[dot][0]):
                    diff = (curve[d2][1] - curve[dot][1]) / (curve[d2][0] - curve[dot][0])
                else:
                    diff = 0
                if dot == d2:
                    stop = 1
                else:
                    dot = d2
            y = diff * x + curve[last][1] - diff * curve[last][0]
            trans.append(ramp[i] + (y - 0.5))
        return trans
    
    # CALLBACKS #
    def size_gradient(self, widget, alloc):
        self.create_gradient()
    
    def ramp_enter(self, widget, event, color):
        if not self.profile: return
        if self.hovered[0] >= 0:
            return
        self.in_color = color
        self.gradient.queue_draw()
        
    def ramp_leave(self, widget, event, color):
        if not self.profile: return
        if self.hovered[0] >= 0:
            return
        self.in_color = None
        self.gradient.queue_draw()
    
    def ramp_motion(self, widget, event, color):
        if not self.profile: return
        alloc = widget.get_allocation()
        w = alloc.width
        h = alloc.height
        self.mouse = (event.x / w, event.y / h)
        
        self.gradient.queue_draw()
        if self.hovered[0] < 0 or self.hovered[1] != color:
            return
        x = max(0, min(1, event.x / w - self.clickdist[0]))
        y = max(0, min(1, 1 - event.y / h - self.clickdist[1]))
        i = self.hovered[0]
        c = self.curves[color]
        if self.hovered[2] == 3:
            x = c[i][0]
        e = c[i] = (x, y)
        
        # check order
        p = i - 1
        while p > -1 and c[p][0] > x: p -= 1
        p += 2
        while p < len(c) and c[p][0] < x: p += 1
        p -= 1
        if p != i:
            r = c.pop(i)
            c.insert(p, r)
            self.hovered = (p, self.hovered[1], self.hovered[2])
        if self.checkUpdate.get_active():
            self.apply_profile()
        self.canvasses[color].queue_draw()
        
    def ramp_down(self, widget, event, color):
        if not self.profile: return
        alloc = widget.get_allocation()
        w = alloc.width
        h = alloc.height
        x = event.x / w
        y = 1 - event.y / h
        if event.type == gtk.gdk._2BUTTON_PRESS:
            # double click
            if self.hovered[0] >= 0:
                self.remove_dot(self.curves[color], self.hovered[0])
                self.hovered = (-1, "", 0)
            else:
                self.add_dot(self.curves[color], x, y)
                self.canvasses[color].queue_draw()
            if self.checkUpdate.get_active():
                self.apply_profile()
            return
        ho = self.check_hover(x, y, w, h, self.curves[color])
        if ho != self.hovered[0]:
            self.hovered = (ho, color, event.button)
            self.canvasses[color].queue_draw()
        if self.hovered[0] >= 0:
            if event.button == 2:
                v = self.curves[color][self.hovered[0]]
                self.curves[color][self.hovered[0]] = (self.curves[color][self.hovered[0]][0], 0.5)
                if self.checkUpdate.get_active():
                    self.apply_profile()
                self.canvasses[color].queue_draw()
                return
            e = self.curves[color][self.hovered[0]]
            self.clickdist = (x - e[0], y - e[1])
        self.gradient.queue_draw()
    
    def ramp_up(self, widget, event, color):
        if not self.profile: return
        self.hovered = (-1, "", 0)
        self.clickdist = (0, 0)
        self.canvasses[color].queue_draw()
        self.gradient.queue_draw()
    
    def add_dot(self, curve, x, y):
        p = 0
        for i in range(0, len(curve)):
            if curve[i][0] > x:
                curve.insert(i, (x, y))
                return
        curve.append((x, y))
    
    def remove_dot(self, curve, i):
        if len(curve) > 2:
            curve.pop(i)
    
    def reset_dots(self, color):
        self.curves[color] = [(0,0.5), (1,0.5)]
        if self.checkUpdate.get_active():
            self.apply_profile()
    
    def reset_cb(self, widget, color):
        self.reset_dots(color)
        self.canvasses[color].queue_draw()
    
    def toggle_cb(self, widget, color):
        if self.checkUpdate.get_active():
            self.apply_profile()
        self.canvasses[color].queue_draw()
    
    def bypass_cb(self, widget):
        self.apply_profile()
        for c in ("r", "g", "b"):
            self.canvasses[c].queue_draw()
            
    def save_cb(self, widget):
        if not self.profile:
            self.status.remove_all(self._stat)
            self.status.push(self._stat, "Nothing to save.")
            return
        fc = gtk.FileChooserDialog("Select a file to save the profile to",
                                   self,
                                   gtk.FILE_CHOOSER_ACTION_SAVE,
                                   (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OK,gtk.RESPONSE_OK))
        if self.profile and self.profile[1] != "[Default Profile]":
            profile = self.profile[1]
            fc.set_current_folder(os.path.dirname(profile))
            fc.set_current_name(os.path.basename(profile))
        elif self.profile:
            fc.set_current_folder(os.path.join(os.path.expanduser("~"), ".local", "share", "icc"))
            fc.set_current_name("default.icm")
        response = fc.run()
        write = False
        if response == gtk.RESPONSE_OK:
            write = True
            f = os.path.join(fc.get_current_folder(), fc.get_filename());
            if os.path.isfile(f):
                write = False
                d = gtk.Dialog("Confirm overwrite", self, 0,
                               (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OK,gtk.RESPONSE_OK))
                response = d.run()
                if response == gtk.RESPONSE_OK:
                    write = True
                d.destroy()
        if write and (os.access(f, os.W_OK) or os.access(os.path.dirname(f), os.W_OK)):
            self.icc.write(f)
        fc.destroy()
        
    def apply_cb(self, widget=None):
        self.apply_profile()
    
    def color_cb(self, widget=None):
        self.create_gradient()
        
    def colorstrip_cb(self, widget=None, event=None):
        self.create_color_gradient()
        
    def smoothing_cb(self, widget):
        self.set_smoothing(int(widget.get_value()))
        self.apply_profile()
        for c in ("r", "g", "b"):
            self.canvasses[c].queue_draw()
    
    def new_cb(self, widget):
        self.load_profile()
    
    
    def open_cb(self, widget):
        fc = gtk.FileChooserDialog("Choose a Color Profile",
                                   self,
                                   gtk.FILE_CHOOSER_ACTION_OPEN,
                                   (gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_OPEN,gtk.RESPONSE_OK))
        flt = gtk.FileFilter()
        flt.set_name("Color Profiles")
        flt.add_pattern("*.icc")
        flt.add_pattern("*.icm")
        fc.add_filter(flt)
       
        flt = gtk.FileFilter()
        flt.set_name("All Files")
        flt.add_pattern("*")
        fc.add_filter(flt)
        
        if self.profile and self.profile[1] != "[Default Profile]":
            fc.set_uri("file://%s" % self.profile[1])
        else:
            fc.set_current_folder(os.path.join(os.path.expanduser("~"), ".local", "share", "icc"))
            
        response = fc.run()
        if response == gtk.RESPONSE_OK:
            self.load_profile(fc.get_uri())
            
        fc.destroy()
    
    # SMOOTHING #
    
    def set_smoothing(self, smoothing):
        # smoothing is int and sets the size of one half of a window
        # function
        self.smoothing = max(0, smoothing)
        self.window = self.get_window(self.smoothing * 2)
            
    def smooth(self, ramp):
        size = len(self.window)
        if size < 2:
            return ramp
        win = self.get_windows(ramp, size)
        r = range(len(ramp))
        s = float(size)
        c = 0
        for l in win:
            n = 0
            for i in range(0, size):
                d = ramp[c] - l[i]
                d = d * self.window[i]
                n += ramp[c] - d
            r[c] = n / s
            c += 1
        return r
    
    def get_window(self, size=10, order=1):
        # build a quadratic second order window
        r = []
        for i in range(0, size):
            r.append(
                pow(
                    1 - pow((  (float(i) - (size - 1) / 2.0)  /  ((size + 1) / 2.0)  ), 2),
                    order
                )
            )
        return r
    
    def get_windows(self, ramp, size):
        #num = ((len(sequence) - size) / step) + 1
        #for i in range(0, num * step, step):
            #yield sequence[i : i + size]
        size  = int(size)
        l     = len(ramp)
        lower = size / 2
        upper = size - lower
        r = range(size)
        for i in range(0, l):
            # fill values below 0 with first val
            b = i - lower
            while b < 0:
                r[b + lower - i] = ramp[i]
                b += 1
            # fill existing valuse
            while b < l and b < i + upper:
                r[b + lower - i] = ramp[b]
                b += 1
            # fill overhanging values with last val
            while b >= l - 1 and b < i + upper:
                r[b + lower - i] = ramp[i]
                b += 1
            yield r
    
    # GRADIENT #
    def create_gradient(self):
        alloc = self.gradient.get_allocation()
        w = alloc.width
        l = self.leftColor.get_color()
        r = self.rightColor.get_color()
        self.grad = cairo.LinearGradient(0, 0, w, 0)
        self.grad.add_color_stop_rgb(0, l.red_float, l.green_float, l.blue_float)
        self.grad.add_color_stop_rgb(1, r.red_float, r.green_float, r.blue_float)
        self.gradient.queue_draw()
        
    def expose_gradient(self, widget, event):
        alloc = widget.get_allocation()
        w = alloc.width
        h = alloc.height
        cr = widget.window.cairo_create()
        cr.rectangle(0, 0, w, h)
        cr.set_source(self.grad)
        cr.fill()
        if self.in_color or self.hovered[0] >= 0:
            if self.hovered[2] == 3:
                x = (self.curves[self.hovered[1]][self.hovered[0]][0]) * w
            elif self.hovered[0] >= 0:
                 x = (self.mouse[0] - self.clickdist[0]) * w
            else:
                x = self.mouse[0] * w
            cr.set_source_rgba(1, 1, 1, 0.2)
            cr.rectangle(int(x) - 4, 0, 9, h)
            cr.fill()
            cr.set_source_rgb(*self.colors[self.in_color])
            cr.set_line_width(1)
            cr.move_to(int(x) + 0.5, 0)
            cr.line_to(int(x) + 0.5, h)
            cr.stroke()
    
    
    # COLOR STRIP
    def create_color_gradient(self):
        alloc = self.colorstrip.get_allocation()
        w = alloc.width
        s = self.colorSaturation.get_value()
        v = self.colorValue.get_value()
        self.colorGrad = cairo.LinearGradient(0, 0, w, 0)
        for i in range(36):
            r, g, b = colorsys.hsv_to_rgb(float(i) / 36, s, v)
            self.colorGrad.add_color_stop_rgb(float(i) / 36, r, g, b)
        self.colorstrip.queue_draw()
    
    def expose_colorstrip(self, widget, event):
        alloc = widget.get_allocation()
        w = alloc.width
        h = alloc.height
        cr = widget.window.cairo_create()
        cr.rectangle(0, 0, w, h)
        cr.set_source(self.colorGrad)
        cr.fill()
        
    # RAMP CANVASSES #
    def size_allocate(self, widget, a):
        #widget.set_allocation(gtk.gdk.Rectangle(a.x, a.y, a.width, a.width))
        widget.set_size_request(a.width, a.width)
        self._grid = 2
        while a.width / self._grid > 40: self._grid += 2
        
    def expose_ramp(self, widget, event, color):
        alloc = widget.get_allocation()
        w = alloc.width
        h = alloc.height
        x = alloc.x
        y = alloc.y
        if self.hovered[2] != 3:
            mx = (self.mouse[0] - self.clickdist[0]) * w
        else:
            mx = self.curves[self.hovered[1]][self.hovered[0]][0] * w
        my = (self.mouse[1] + self.clickdist[1]) * h
            
        
        # context
        cr = widget.window.cairo_create()
        cr.rectangle(0, 0, w, h)
        cr.clip()
        
        # background
        cr.set_source_rgb(0, 0, 0)
        cr.rectangle(0, 0, w, h)
        cr.fill()
        
        # grid
        _w = float(w) / self._grid
        _h = float(h) / self._grid
        cr.set_source_rgb(0.25, 0.25, 0.25)
        cr.set_line_width(1)
        cr.set_dash([2], 0)
        for i in range(0, self._grid - 1):
            cr.move_to(0, int(h - _h * (i + 1)) + 0.5)
            cr.line_to(w, int(h - _h * (i + 1)) + 0.5)
            cr.stroke()
            cr.move_to(int(_w * (i + 1)) + 0.5, 0)
            cr.line_to(int(_w * (i + 1)) + 0.5, h)
            cr.stroke()
        
        # diagonal
        cr.set_dash([], 0)
        cr.move_to(0, h)
        cr.line_to(w, 0)
        cr.stroke()
        
        if not self.profile: return
        
        # horizontal
        cr.set_source_rgba(1, 0, 0, 0.3)
        cr.move_to(0, h / 2 + 0.5)
        cr.line_to(w, h / 2 + 0.5)
        cr.stroke()
        
        # crosshair 
        if self.hovered[0] >= 0:
            cr.set_source_rgb(0.33, 0.33, 0.33)
            cr.move_to(0, my + 0.5)
            cr.line_to(w, my + 0.5)
            cr.move_to(mx + 0.5, 0)
            cr.line_to(mx + 0.5, h)
            cr.stroke()
            
        # ramp
        if self.icc.has_color(color):
            l = self.icc.get_color_length()
            e = self.smooth(self.ramps[color])
            for i in range(0, l):
                _x = float(i) / l * w
                _y = h - e[i] * h
                if not i:
                    cr.move_to(_x, _y)
                else:
                    cr.line_to(_x, _y)
            if self.toggles[color].get_active() and not self.buttonBypass.get_active():
                cr.set_source_rgba(*(self.colors[color] + (0.33,)))
            else:
                cr.set_source_rgb(*self.colors[color])
            cr.stroke()
        
        # transform
        if self.icc.has_color(color):
            t = self.transform(color, e)
            for i in range(0, l):
                _x = float(i) / l * w
                _y = h - max(0, min(1, t[i])) * h
                if not i:
                    cr.move_to(_x, _y)
                else:
                    cr.line_to(_x, _y)
            if self.toggles[color].get_active() and not self.buttonBypass.get_active():
                cr.set_source_rgb(*self.colors[color])
            else:
                cr.set_source_rgba(*(self.colors[color] + (0.33,)))
            cr.stroke()
            
        # handles
        dots = self.curves[color]
        for i in range(0, len(dots)):
            if i == self.hovered[0]:
                cr.set_source_rgba(1, 1, 1, 0.9)
            else:
                cr.set_source_rgba(1, 1, 1, 0.33)
            cr.arc(w * dots[i][0], h - h * dots[i][1] + 0.5, self.handlesize, 0, 2 * math.pi)
            cr.fill()
            
        # curve
        if self.hovered[0] >= 0:
            cr.set_source_rgba(1, 1, 1, 0.9)
        else:
            cr.set_source_rgba(1, 1, 1, 0.33)
        cr.move_to(0, h - dots[0][1] * h + 0.5)
        cr.line_to(dots[0][0] * w, h - dots[0][1] * h + 0.5)
        for i in range(1, len(dots)):
            cr.line_to(dots[i][0] * w, h - dots[i][1] * h + 0.5)
        cr.line_to(w, h - dots[len(dots) - 1][1] * h + 0.5)
        cr.stroke() 
        
        # label
        if self.hovered[0] >= 0:
            val = "%+.2f%%" % (100 - max(0, min(1, self.mouse[1] + self.clickdist[1])) * 200)
            cr.select_font_face("sans" , cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
            cr.set_font_size(11)
            x_off, y_off, tw, th = cr.text_extents(val)[:4]
            if mx + tw + 4 + 20 > w:
                vx = mx - tw - 20
            else:
                vx = mx + 20
            rx = max(18, min(w - tw - 18, vx))
            ry = max(2 + th, min(h - 2, my + 4))
            cr.set_source_rgb(0, 0, 0)
            cr.move_to(rx - 1, ry - 1),
            cr.show_text(val);
            cr.move_to(rx + 1, ry + 1),
            cr.show_text(val);
            cr.move_to(rx - 1, ry + 1),
            cr.show_text(val);
            cr.move_to(rx + 1, ry - 1),
            cr.show_text(val);
            cr.set_source_rgb(1, 1, 1)
            cr.move_to(rx, ry)
            cr.show_text(val);
            
    # HELPERS #
    def check_hover(self, x, y, w, h, curve):
        c = 0
        rx = float(self.handlesize) / w
        ry = float(self.handlesize) / h
        for i in curve:
            if (x > (i[0] - rx) and x < (i[0] + rx)
            and y > (i[1] - ry) and y < (i[1] + ry)):
                return c
            c += 1
        return -1
        
    # WINDOW STUFF #
    def create_window(self):
        self.connect("destroy", self.destroy)
        self.set_position(gtk.WIN_POS_CENTER)
        self.set_title("Giccler")
        self.set_size_request(960, 600)
        self.set_icon_from_file(os.path.join(sys.path[0], "giccler.svg"))
        
        # MAIN CONTAINER
        self.mainContainer = gtk.VBox(False, 5)
        self.add(self.mainContainer)
        
        # PANED
        self.paned = gtk.VPaned()
        self.mainContainer.pack_start(self.paned, True)
        self.paned.set_position(430)
        
        # UPPER CONTAINER
        self.upperContainer = gtk.VBox(False, 5)
        self.paned.pack1(self.upperContainer, True, True)
        
        # TOOLBAR
        self.toolbar = gtk.Toolbar()
        self.toolbar.set_orientation(gtk.ORIENTATION_HORIZONTAL)
        self.toolbar.set_style(gtk.TOOLBAR_BOTH)
        self.upperContainer.pack_start(self.toolbar, False)
        
        #  OPEN BUTTON
        self.buttonOpen = gtk.ToolButton(gtk.STOCK_OPEN)
        self.toolbar.insert(self.buttonOpen, -1)
        self.buttonOpen.connect("clicked", self.open_cb)
        self.buttonOpen.set_tooltip_text("Open an existing profile")
        
        # SAVE BUTTON
        self.buttonSave = gtk.ToolButton(gtk.STOCK_SAVE)
        self.toolbar.insert(self.buttonSave, -1)
        self.buttonSave.connect("clicked", self.save_cb)
        self.buttonSave.set_tooltip_text("Save the actual settings to a new profile")
        
        # NEW BUTTON
        self.buttonNew = gtk.ToolButton(gtk.STOCK_NEW)
        self.toolbar.insert(self.buttonNew, -1)
        self.buttonNew.connect("clicked", self.new_cb)
        self.buttonNew.set_tooltip_text("Start from scratch")
        
        
        # EXPANDER
        ex = gtk.SeparatorToolItem()
        ex.set_expand(True)
        ex.set_draw(False)
        self.toolbar.insert(ex, -1)
        
        
        # APPLY BUTTON
        self.buttonApply = gtk.ToolButton(gtk.STOCK_APPLY)
        #self.toolbar.insert(self.buttonApply, -1)
        self.buttonApply.connect("clicked", self.apply_cb)
        
        # UPDATE CHECKBOX
        self.checkUpdate = gtk.ToggleToolButton("Auto Apply")
        #self.toolbar.insert(self.checkUpdate, -1)
        self.checkUpdate.set_active(True)
        
        # SMOOTHING
        ti = gtk.ToolItem()
        self.toolbar.insert(ti, -1)
        h = gtk.HBox(False, 5)
        ti.add(h)
        l = gtk.Label("Smoothing")
        h.pack_start(l, False, False)
        adj = gtk.Adjustment(self.smoothing, 0, self.smoothmax, 1)
        self.smoothingSpin = gtk.SpinButton(adj)
        h.pack_start(self.smoothingSpin, False, False)
        self.smoothingSpin.set_value(self.smoothing)
        self.smoothingSpin.connect("value_changed", self.smoothing_cb)
        
        # BYPASS BUTTON
        self.buttonBypass = gtk.ToggleToolButton(gtk.STOCK_STOP)
        self.toolbar.insert(self.buttonBypass, -1)
        self.buttonBypass.connect("toggled", self.bypass_cb)
        self.buttonBypass.set_tooltip_text("Bypass all changes for comparison")
        
        
        # CANVAS CONTAINER
        self.canvasContainer = gtk.HBox(True, 5)
        self.upperContainer.pack_start(self.canvasContainer)
        
        # CANVASSES
        self.red = gtk.DrawingArea()
        self.green = gtk.DrawingArea()
        self.blue = gtk.DrawingArea()
        
        self.canvasContainer.pack_start(self.red)
        self.canvasContainer.pack_start(self.green)
        self.canvasContainer.pack_start(self.blue)
        
        mask = gtk.gdk.EXPOSURE_MASK | gtk.gdk.LEAVE_NOTIFY_MASK | gtk.gdk.ENTER_NOTIFY_MASK | gtk.gdk.BUTTON_PRESS_MASK | gtk.gdk.POINTER_MOTION_MASK | gtk.gdk.BUTTON_RELEASE_MASK
        
        self.red.add_events(mask)
        self.green.add_events(mask)
        self.blue.add_events(mask)
        
        self.red.connect("size-allocate", self.size_allocate)
        self.green.connect("size-allocate", self.size_allocate)
        self.blue.connect("size-allocate", self.size_allocate) 
        
        self.red.connect("expose_event", self.expose_ramp, "r")
        self.green.connect("expose_event", self.expose_ramp, "g")
        self.blue.connect("expose_event", self.expose_ramp, "b")
        
        self.red.connect("motion_notify_event", self.ramp_motion, "r")
        self.green.connect("motion_notify_event", self.ramp_motion, "g")
        self.blue.connect("motion_notify_event", self.ramp_motion, "b")
        
        self.red.connect("button_press_event", self.ramp_down, "r")
        self.green.connect("button_press_event", self.ramp_down, "g")
        self.blue.connect("button_press_event", self.ramp_down, "b")
        
        self.red.connect("button_release_event", self.ramp_up, "r")
        self.green.connect("button_release_event", self.ramp_up, "g")
        self.blue.connect("button_release_event", self.ramp_up, "b")
        
        self.red.connect('enter-notify-event', self.ramp_enter, "r")
        self.green.connect('enter-notify-event', self.ramp_enter, "g")
        self.blue.connect('enter-notify-event', self.ramp_enter, "b")
        
        self.red.connect('leave-notify-event', self.ramp_leave, "r")
        self.green.connect('leave-notify-event', self.ramp_leave, "g")
        self.blue.connect('leave-notify-event', self.ramp_leave, "b")
        
        # BUTTONS
        self.toolContainer = gtk.HBox(True, 5)
        self.upperContainer.pack_start(self.toolContainer, False)
        
        # BUTTON CONTAINER
        self.buttonsRed = gtk.HBox(False, 5)
        self.buttonsGreen = gtk.HBox(False, 5)
        self.buttonsBlue = gtk.HBox(False, 5)
        
        self.toolContainer.pack_start(self.buttonsRed)
        self.toolContainer.pack_start(self.buttonsGreen)
        self.toolContainer.pack_start(self.buttonsBlue)
        
        # ACTIVE BUTTONS
        img = gtk.image_new_from_stock(gtk.STOCK_APPLY, gtk.ICON_SIZE_BUTTON)
        self.toggleRed = gtk.ToggleButton("")
        self.toggleRed.set_property("image", img)
        self.toggleRed.set_tooltip_text("Apply changes to red curve")
        
        img = gtk.image_new_from_stock(gtk.STOCK_APPLY, gtk.ICON_SIZE_BUTTON)
        self.toggleGreen = gtk.ToggleButton("")
        self.toggleGreen.set_property("image", img)
        self.toggleGreen.set_tooltip_text("Apply changes to green curve")
        
        img = gtk.image_new_from_stock(gtk.STOCK_APPLY, gtk.ICON_SIZE_BUTTON)
        self.toggleBlue = gtk.ToggleButton("")
        self.toggleBlue.set_property("image", img)
        self.toggleBlue.set_tooltip_text("Apply changes to blue curve")
        
        self.buttonsRed.pack_end(self.toggleRed, False)
        self.buttonsGreen.pack_end(self.toggleGreen, False)
        self.buttonsBlue.pack_end(self.toggleBlue, False)
        
        self.toggleRed.set_active(True)
        self.toggleGreen.set_active(True)
        self.toggleBlue.set_active(True)
        
        self.toggleRed.connect("toggled", self.toggle_cb, "r")
        self.toggleGreen.connect("toggled", self.toggle_cb, "g")
        self.toggleBlue.connect("toggled", self.toggle_cb, "b")
        
        # RESET BUTTONS
        img = gtk.image_new_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_BUTTON)
        self.resetRed = gtk.Button("")
        self.resetRed.set_property("image", img)
        self.resetRed.set_tooltip_text("Reset red curve")
        
        img = gtk.image_new_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_BUTTON)
        self.resetGreen = gtk.Button("")
        self.resetGreen.set_property("image", img)
        self.resetGreen.set_tooltip_text("Reset green curve")
        
        img = gtk.image_new_from_stock(gtk.STOCK_CLEAR, gtk.ICON_SIZE_BUTTON)
        self.resetBlue = gtk.Button("")
        self.resetBlue.set_property("image", img)
        self.resetBlue.set_tooltip_text("Reset blue curve")
        
        self.buttonsRed.pack_end(self.resetRed, False)
        self.buttonsGreen.pack_end(self.resetGreen, False)
        self.buttonsBlue.pack_end(self.resetBlue, False)
        
        self.resetRed.connect("clicked", self.reset_cb, "r")
        self.resetGreen.connect("clicked", self.reset_cb, "g")
        self.resetBlue.connect("clicked", self.reset_cb, "b")
        
        # LOWER CONTAINER
        self.lowerContainer = gtk.VBox(False, 5)
        self.paned.pack2(self.lowerContainer, True, True)
        
        # GRADIENT AND COLOR BUTTONS
        self.gradientContainer = gtk.HBox(False, 5)
        self.lowerContainer.pack_start(self.gradientContainer, True, True)
        
        self.gradient = gtk.DrawingArea()
        self.gradient.connect("expose_event", self.expose_gradient)
        
        self.leftColor = gtk.ColorButton(gtk.gdk.Color(0, 0, 0))
        self.rightColor = gtk.ColorButton(gtk.gdk.Color(65535, 65535, 65535))
        
        self.leftColor.connect("color-set", self.color_cb)
        self.rightColor.connect("color-set", self.color_cb)
        
        self.leftColor.set_tooltip_text("Set the left color of the gradient")
        self.rightColor.set_tooltip_text("Set the right color of the gradient")
        
        self.gradientContainer.pack_start(self.leftColor, False)
        self.gradientContainer.pack_start(self.gradient, True)
        self.gradientContainer.pack_start(self.rightColor, False)
        
        self.gradient.connect("size-allocate", self.size_gradient)
        
        # COLOR BAND
        self.colorTable = gtk.Table(3, 2, False)
        self.lowerContainer.pack_start(self.colorTable, True, True)
        self.colorstrip = gtk.DrawingArea()
        self.colorstrip.connect("expose_event", self.expose_colorstrip)
        
        self.colorSaturation = gtk.HScale(gtk.Adjustment(1.0, 0., 1., 0.05, 0.2))
        self.colorValue = gtk.HScale(gtk.Adjustment(1.0, 0., 1., 0.05, 0.2))
        
        self.colorSaturation.connect("value-changed", self.colorstrip_cb)
        self.colorValue.connect("value-changed", self.colorstrip_cb)
        
        self.colorSaturation.set_value_pos(gtk.POS_RIGHT)
        self.colorValue.set_value_pos(gtk.POS_RIGHT)
        
        self.colorTable.attach(self.colorstrip, 0, 2, 0, 1, gtk.EXPAND|gtk.FILL, gtk.EXPAND|gtk.FILL)
        self.colorTable.attach(self.colorSaturation, 0, 1, 2, 3, gtk.EXPAND|gtk.FILL, 0)
        self.colorTable.attach(self.colorValue, 1, 2, 2, 3, gtk.EXPAND|gtk.FILL, 0)
        
        self.colorTable.attach(gtk.Label("Saturation"), 0, 1, 1, 2, gtk.EXPAND|gtk.FILL, 0)
        self.colorTable.attach(gtk.Label("Value"), 1, 2, 1, 2, gtk.EXPAND|gtk.FILL, 0)
        
        self.colorstrip.connect("size-allocate", self.colorstrip_cb)
        
        # STATUS BAR
        self.status = gtk.Statusbar()
        self.status.set_has_resize_grip(True)
        self.mainContainer.pack_start(self.status, False, False)
        
        self._stat = self.status.get_context_id("loading")
        
        self.show_all()
        
    def destroy(self, widget):
        """wtf?!1"""
        self.icc.destroy()
        gtk.main_quit()

    def ctrlC(self, signum, frame):
        self.destroy(None)
        
if __name__ == "__main__":
    giccler = Giccler(sys.argv)
    gtk.main()
