# see http://www.color.org/specification/ICC1v43_2010-12.pdf
# for a full description of the protocol specification

import os
import sys
import struct
import math
import datetime
import locale
import tempfile
#from scipy import interpolate

class ICC():
    
    profile   = None
    header    = {} # all header entries in a dict
    tags      = {} # List containing all tags with position and offset in the data section
    data      = {} # dict containing all neccessary data entries
    tempfile  = None
    
    def __init__(self, profile=None):
        locale.setlocale(locale.LC_ALL, "")
        
        if profile:
            self.open_profile(profile)
        else:
            self.from_scratch()
        
    def from_scratch(self):
        d = datetime.datetime.now()
        self.header = {
            "preferred"    : 0,
            "versionMajor" : 4,
            "versionMinor" : 3 << 4,
            "class"        : "mntr",
            "colorspace"   : "RGB",
            "pcs"          : "XYZ",
            "dateYear"     : d.year,
            "dateMonth"    : d.month,
            "dateDay"      : d.day,
            "dateHour"     : d.hour,
            "dateMinute"   : d.minute,
            "dateSecond"   : d.second,
            "acsp"         : "acsp",
            "platform"     : "",
            "flags"        : 0,
            "manufacturer" : "",
            "model"        : "",
            "attributes"   : 0,
            "intent"       : 0,
            "ciex"         : self.to_s15Fixed16Number(63190),
            "ciey"         : self.to_s15Fixed16Number(65536),
            "ciez"         : self.to_s15Fixed16Number(54061),
            "creator"      : "",
            "id"           : "",
            "__spare0"     : 0,
            "__spare1"     : 0
        }
        self.tags = {
            "desc" : {
                "tagoff" : 32,
                "signature" : "desc"
            },
            "cprt" : {
                "tagoff" : 132 + 12,
                "signature" : "cprt"
            },
            "wtpt" : {
                "tagoff" : 132 + 50,
                "signature" : "wtpt"
            },
            "vcgt" : {
                "tagoff" : 132 + 36,
                "signature" : "vcgt"
            }
        }
        
        self.data = {
            "desc" : {
                "signature" : "desc",
                "data"      : "Giccler default profile",
            },
            "cprt" : {
                "signature" : "text",
                "data"      : "(c) Markus Schmidt 2014 | GPL - GNU Public License", 
            },
            "wtpt" : {
                "signature" : "XYZ ",
                "data"      : {'y': 1.0, 'x': 0.95, 'z': 1.09}
            },
            "vcgt" : {
                "signature" : "vcgt",
                "data"      : {
                    "entries" : 256,
                    "length"  : 2,
                    "r_orig"  : list(range(256)),
                    "g_orig"  : list(range(256)),
                    "b_orig"  : list(range(256)),
                    "r"       : [float(x) / 256 for x in range(256)],
                    "g"       : [float(x) / 256 for x in range(256)],
                    "b"       : [float(x) / 256 for x in range(256)]
                }
            }
        }
        tags = self.tags
        lst = [i for i in tags]
        lst.sort(key=lambda x: tags[x]["tagoff"])
        off = 128 + 4 + len(tags) * 12
        c = 0
        for t in lst:
            l = self.get_entry_length(self.data[t])
            
            tags[t]["tagoff"] = 132 + 12 * c
            tags[t]["length"] = l
            tags[t]["offset"] = off
            self.data[t]["offset"] = off
            
            self._split_entry(tags[t], "signature", 4)
            
            c += 1
            off += l
        self.header["size"] = off
        self.destroy_tempfile()
        self.create_tempfile()
        self.profile = None
        self._profile = "[Default Profile]"
        
        self.destroy_tempfile()
        self.create_tempfile()
        
        return (self.profile, self._profile)
    
    def open_profile(self, profile):
        if profile[:7] == "file://":
            profile = profile[7:]
        profile = os.path.abspath(profile)
        try:
            self.profile = open(profile, "r")
            self._profile = profile
        except:
            print "File not found or not readable"
            return (self.profile, self._profile)
        
        self.header = self.parse_header()
        self.tags   = self.parse_tags()
        self.data   = self.parse_data()
        
        #print self.header
        #print self.tags
        #print self.data
        
        self.destroy_tempfile()
        self.create_tempfile()
        
        if not self.has_vcgt():
            self.profile = None
            self._profile = None
        
        return (self.profile, self._profile)
    
    def close_profile(self):
        if self.profile:
            self.profile = None
    
    def write(self, fname):
        if fname == self._profile:
            self.close_profile()
        targ = open(fname, "w")
        self.tempfile[0].seek(0)
        targ.write(self.tempfile[0].read())
        targ.close()
        if fname == self._profile:
            self.open_profile(fname)
    
    def apply(self):
        os.system("xcalib '%s'" % self.tempfile[1])
    
    def has_vcgt(self):
        return "vcgt" in self.data
        
    def has_color(self, color):
        return self.has_vcgt() and color in self.data["vcgt"]["data"]
    
    def get_color_length(self):
        if self.has_vcgt():
            return self.data["vcgt"]["data"]["entries"]
        else:
            return 0
        
    def get_color_ramp(self, color):
        if self.has_vcgt() and color in self.data["vcgt"]["data"]:
            return self.data["vcgt"]["data"][color]
        else:
            return None
    
    def set_color_ramp(self, color, ramp):
        if self.has_vcgt() and color in self.data["vcgt"]["data"]:
            data = self.data["vcgt"]["data"]
            data[color] = ramp
            orig = data["%s_orig" % color]
            for i in range(0, len(orig)):
                orig[i] = int(ramp[i] * (math.pow(2, data["length"] * 8) - 1))
                
    def write_color(self, color, ramp=None):
        if not self.has_color(color):
            return
        if ramp:
            r = ramp
        else:
            r = self.get_color_ramp(color)
        d = self.data["vcgt"]["data"]
        o = self.data["vcgt"]["offset"]
        l = d["length"]
        e = d["entries"]
        m = pow(2, l * 8)
        s = ""
        for j in range(0, e):
            val = max(0, min(m - 1, round(r[j] * m)))
            s = "%s%s" % (s, struct.pack(("", ">B", ">H", ">I", ">L", ">Q")[l], val))
        tmp = self.tempfile[0]
        tmp.seek(o + 18 + ("r", "g", "b").index(color) * e * l)
        tmp.write(s)
        tmp.flush()
    
    # TEMPFILE #
    
    def create_tempfile(self):
        self.tempfile = tempfile.mkstemp(".icm", "giccler_")
        self.tempfile = (os.fdopen(self.tempfile[0], "r+b", 0), self.tempfile[1])
        self.restore_tempfile()
            
    def restore_tempfile(self):
        if self.profile:
            self.profile.seek(0)
            self.tempfile[0].write(self.profile.read())
        else:
            self.write_header()
            self.write_tags()
            self.write_data()
    
    def destroy_tempfile(self):
        if self.tempfile:
            self.tempfile[0].close()
            os.remove(self.tempfile[1])
            self.tempfile = None
            
    def resize_tag(self, tag, b):
        # expand or shrink a tempfile by the given amount of bytes (b)
        tmp = self.tempfile[0]
        if not tag in self.tags: return
        tag = self.tags[tag]
        l = [(i,self.tags[i]) for i in self.tags]
        
        # reverse if expanding, normal if shrinking
        rev = True
        if b < 0:
            rev = False
            
        l.sort(key=lambda x: x[1]["offset"], reverse=rev)
        for t in l:
            t = t[1]
            off = t["offset"]
            if off > tag["offset"]:
                # move all data after the expanding tag to make space
                new = off + b
                tmp.seek(off)
                d = tmp.read(t["length"])
                tmp.seek(new)
                tmp.write(d)
                tmp.flush()
                # set the new offset of the tag in the header
                tmp.seek(t["tagoff"])
                tmp.write(struct.pack(">I", new))
                tmp.flush()
                t["offset"] = off
            else:
                # stop if we reached the expanding tag
                break
        # write the new length to the tag
        tag["length"] = tag["length"] + b
        tmp.seek(tag["tagoff"] + 8)
        tmp.write(struct.pack(">I", tag["length"]))
        # write the new length to the header
        self.header["size"] = self.header["size"] + b
        tmp.seek(0)
        tmp.write(struct.pack(">I", self.header["size"]))
        
        tmp.flush()
        
        if b < 0:
            os.ftruncate(tmp.fileno(), self.header["size"])
        
        os.fsync(tmp.fileno())
        
        
            
    # DATA STUFF #
        
    def parse_data(self, profile=None, tags=None):
        if not profile:
            profile = self.profile
        if not tags:
            tags = self.tags
        data = {}
        for tag in tags:
            if tags[tag]["signature"] in data_entries:
               data[tags[tag]["signature"]] = self.parse_data_entry(tags[tag])
        return data
    
    def parse_data_entry(self, tag, profile=None):
        if not profile:
            profile = self.profile
        
        # determine type of data entry and length
        profile.seek(tag["offset"])
        sig = "".join(map(str, struct.unpack('>4c', profile.read(4))))
        l = int(tag["length"])
        data = None
        
        # handle data types
        if sig == "desc":
            profile.seek(tag["offset"] + 8)
            _l = struct.unpack(">I", profile.read(4))[0]
            raw = struct.unpack(">%dc" % _l, profile.read(_l))
            data = "".join(map(str, raw)) 
        
        if sig == "text":
            profile.seek(tag["offset"] + 8)
            raw = struct.unpack(">%dc" % (l - 8), profile.read(l - 8))
            data = "".join(map(str, raw)) 
            
        if sig == "XYZ ":
            pos = tag["offset"] + 8
            end = tag["offset"] + tag["length"]
            profile.seek(pos)
            data = []
            while pos < end:
                raw = struct.unpack(">iii", profile.read(12))
                dat = dict(zip(("x", "y", "z"), raw))
                for i in dat:
                    dat[i] = self.from_s15Fixed16Number(dat[i])
                data.append(dat)
                pos += 12
            
        if sig == "curv":
            pos = tag["offset"] + 8
            profile.seek(pos)
            __l = struct.unpack(">I", profile.read(4))[0]
            data = []
            while pos < tag["offset"] + tag["length"]:
                raw = struct.unpack(">H", profile.read(2))[0]
                if __l == 1:
                    data.append(self.from_u8Fixed8Number(raw))
                else:
                    data.append(raw)
                pos += 2
                
        if sig == "vcgt":
            pos = tag["offset"] + 8
            end = tag["offset"] + tag["length"]
            profile.seek(pos)
            gt = struct.unpack(">I", profile.read(4))[0]
            if gt == 1:
                return
            if not gt:
                data = {"r" : [], "g" : [], "b" : [], "r_orig" : [], "g_orig" : [], "b_orig" : [], "entries" : 0, "length" : 0 }
                if tag["length"] == 1584:
                    # work-around for AdobeGamma-Profiles
                    length   = 2;
                    entries  = 256;
                    channels = 3;
                else:
                    channels = struct.unpack(">H", profile.read(2))[0]
                    entries  = struct.unpack(">H", profile.read(2))[0]
                    length   = struct.unpack(">H", profile.read(2))[0]
                data["entries"] = entries
                data["length"]  = length
                start = pos = pos + 10
                targs = ("r", "g", "b")
                utype = ("", ">B", ">H", ">I", ">L", ">Q")
                while pos < end:
                    t = targs[int((pos - start) / (entries * length))]
                    raw = struct.unpack(utype[length], profile.read(length))[0]
                    data["%s_orig" % t].append(raw)
                    data[t].append(float(raw) / math.pow(2, length * 8))
                    pos += length
        return {
            "data"      : data,
            "signature" : sig,
            "offset"    : tag["offset"]
        }
    
    def get_entry_length(self, data):
        
        if data["signature"] == "text":
            return 8 + len(data["data"])
            
        if data["signature"] == "desc":
            return 12 + len(data["data"])
            
        if data["signature"] == "XYZ ":
            return 8 + 12
            
        if data["signature"] == "vcgt":
            return 8 + 10 + data["data"]["length"] * data["data"]["entries"] * 3
            
    def write_data(self):
        data = self.data
        lst = [i for i in data]
        lst.sort(key=lambda x: data[x]["offset"])
        tmp = self.tempfile[0]
        for _d in lst:
            d = data[_d]
            tmp.seek(d["offset"])
            tmp.write(struct.pack(">4cI", *(tuple(d["signature"]) + (0,))))
            
            if d["signature"] == "desc":
                tmp.write(struct.pack(">I%dc" % len(d["data"]), len(d["data"]), *tuple(d["data"])))
                
            if d["signature"] == "text":
                tmp.write(struct.pack(">%dc" % len(d["data"]), *tuple(d["data"])))
            
            if d["signature"] == "XYZ ":
                tmp.write(struct.pack(">iii", self.to_s15Fixed16Number(d["data"]["x"]),
                                              self.to_s15Fixed16Number(d["data"]["y"]),
                                              self.to_s15Fixed16Number(d["data"]["z"])))
            
            if d["signature"] == "vcgt":
                tmp.write(struct.pack(">I", 0))
                tmp.write(struct.pack(">3H", 3, 256, 2))
                for c in ("r", "g", "b"):
                    self.write_color(c)
            
    # TAGS STUFF #
    
    def parse_tags(self, profile=None):
        if not profile:
            profile = self.profile
        profile.seek(128)
        amount = struct.unpack('>I', profile.read(4))[0]
        tags = {}
        for i in range(0, amount):
            off = 132 + i * 12
            profile.seek(off)
            raw = struct.unpack('>4c2I', profile.read(12))
            tag = dict(zip(tag_entries, raw))
            self._join_entry(tag, "signature", 4)
            tag["tagoff"] = off
            tags[tag["signature"]] = tag
        return tags
            
    def write_tags(self):
        tags = self.tags
        tmp = self.tempfile[0]
        tmp.seek(128)
        tmp.write(struct.pack(">I", len(tags)))
        for t in tags:
            tmp.write(struct.pack(">4c2I", *tuple([tags[t][x] for x in tag_entries])))
        
    # HEADER STUFF #
    
    def parse_header(self, profile=None):
        if not profile:
            profile = self.profile
        profile.seek(0)
        raw = struct.unpack('>IIBB2B4c4c4c6h4c4cI4c4cqI3f4c16c', profile.read(100))
        header = dict(zip(header_entries, raw))
        return self._build_header(header)
    
    def _build_header(self, header=None):
        if not header:
            header = self.header
        for i in header_joins:
            self._join_entry(header, i, header_joins[i])
        for i in readable_relations:
            self._to_readable(header, i, readable_relations[i])
        header["date"] = datetime.datetime(header["dateYear"],
                                           header["dateMonth"],
                                           header["dateDay"],
                                           header["dateHour"],
                                           header["dateMinute"],
                                           header["dateSecond"])
        header["dateH"] = header["date"].strftime("%c")
        return header
    
    def prepare_header(self, header=None):
        if not header:
            header = self.header
        for i in header_joins:
            self._split_entry(header, i, header_joins[i])
            
    def write_header(self, header=None):
        if not header:
            header = self.header
        l = []
        for e in header_entries:
            try:
                l.append(header[e])
            except:
                l.append('\x00')
        self.tempfile[0].seek(0)
        self.tempfile[0].write(struct.pack('>IIBB2B4c4c4c6h4c4cI4c4cqI3f4c16c', *(tuple(l))))
        
        
    # OTHER #
    
    def destroy(self):
        self.destroy_tempfile()
    
    # HELPERS #
    
    def _join_entry(self, header, key, amount):
        header[key] = ""
        for i in range(amount):
            if header["%s%d" % (key, i)] != '\x00':
                header[key] += header["%s%d" % (key, i)]
            #del header["%s%d" % (key, i)]
    
    def _split_entry(self, header, key, amount):
        l = len(header[key])
        s = ""
        for i in range(amount):
            if i < l:
                header["%s%d" % (key, i)] = header[key][i]
            else:
                header["%s%d" % (key, i)] = '\x00'
        #del header[key]
            
    
    def _to_readable(self, header, key, lookup):
        try:
            header["%sH" % key] = lookup[header[key]]
        except:
            header["%sH" % key] = header[key]
    
    # TYPES #
    
    def from_s15Fixed16Number(self, val):
        return ((val >> 16) & 32767) + float(val & 65535) / 65536 * ((val >> 31) * -2 + 1) 
        
    def to_s15Fixed16Number(self, val):
        return math.copysign((int(val) << 16) + (val - int(val)) * 65536, val)
    
    def from_u8Fixed8Number(self, val):
        return (val >> 8) + float(val & 255) / 256
        
    def to_u8Fixed8Number(self, val):
        return (int(val) << 8) + (val - int(val)) * 256
        
data_entries = {
    "desc" : "Description",
    "cprt" : "Copyright",
    "wtpt" : "White Point",
    #"rXYZ" : "XYZ Red",
    #"gXYZ" : "XYZ Green",
    #"bXYZ" : "XYZ Blue",
    #"rTRC" : "TRC Red",
    #"gTRC" : "TRC Green",
    #"bTRC" : "TRC Blue",
    "vcgt" : "Video Card Gamma Table",
}

tag_entries = (
    "signature0",
    "signature1",
    "signature2",
    "signature3",
    "offset",
    "length"
)

header_entries = (
    "size",
    "preferred",
    "versionMajor",
    "versionMinor",
    "__spare0",
    "__spare1",
    "class0",
    "class1",
    "class2",
    "class3",
    "colorspace0",
    "colorspace1",
    "colorspace2",
    "colorspace3",
    "pcs0",
    "pcs1",
    "pcs2",
    "pcs3",
    "dateYear",
    "dateMonth",
    "dateDay",
    "dateHour",
    "dateMinute",
    "dateSecond",
    "acsp0",
    "acsp1",
    "acsp2",
    "acsp3",
    "platform0",
    "platform1",
    "platform2",
    "platform3",
    "flags",
    "manufacturer0",
    "manufacturer1",
    "manufacturer2",
    "manufacturer3",
    "model0",
    "model1",
    "model2",
    "model3",
    "attributes",
    "intent",
    "ciex",
    "ciey",
    "ciez",
    "creator0",
    "creator1",
    "creator2",
    "creator3",
    "id0",
    "id1",
    "id2",
    "id3",
    "id4",
    "id5",
    "id6",
    "id7",
    "id8",
    "id9",
    "id10",
    "id11",
    "id12",
    "id13",
    "id14",
    "id15"
)

header_joins = {
    "class" : 4,
    "colorspace" : 4,
    "pcs" : 4,
    "acsp" : 4,
    "platform" : 4,
    "manufacturer" : 4,
    "model" : 4,
    "creator" : 4,
    "id" : 16
}
        
manufacturers = {
    "4d2p" : "Erdt Systems GmbH & Co KG / Germany",
    "AAMA" : "Aamazing Technologies, Inc. / USA",
    "ACER" : "Acer Peripherals / Taiwan",
    "ACLT" : "Acolyte Color Research / USA",
    "ACTI" : "Actix Sytems, Inc. / USA",
    "ADAR" : "Adara Technology, Inc. / USA",
    "ADBE" : "Adobe Systems Incorporated / USA",
    "ADI" : "ADI Systems, Inc. / USA",
    "AGFA" : "Agfa Graphics N.V. / BELGIUM",
    "ALMD" : "Alps Electric USA, Inc. / USA",
    "ALPS" : "Alps Electric USA, Inc. / USA",
    "ALWN" : "Alwan Color Expertise / France",
    "AMTI" : "Amiable Technologies, Inc. / USA",
    "AOC" : "AOC International (U.S.A), Ltd. / USA",
    "APAG" : "Apago / USA",
    "APPL" : "Apple Computer, Inc. / USA",
    "AST" : "AST / USA",
    "AT&T" : "AT&T Computer Systems / USA",
    "BAEL" : "BARBIERI electronic / Italy",
    "berg" : "bergdesign incorporated / USA",
    "bICC" : "basICColor GmbH / Germany",
    "BRCO" : "Barco NV / BELGIUM",
    "BRKP" : "Breakpoint Pty Limited / Australia",
    "BROT" : "Brother Industries, LTD / Japan",
    "BULL" : "Bull / USA",
    "BUS" : "Bus Computer Systems / USA",
    "C-IT" : "C-Itoh / USA",
    "CAMR" : "Intel Corporation / USA",
    "CANO" : "Canon, Inc. (Canon Development Americas, Inc.) / USA",
    "CARR" : "Carroll Touch / USA",
    "CASI" : "Casio Computer Co., Ltd. / Japan",
    "CBUS" : "Colorbus PL / Australia",
    "CEL" : "Crossfield / USA",
    "CELx" : "Crossfield / USA",
    "ceyd" : "Integrated Color Solutions, Inc. / USA",
    "CGS" : "CGS Publishing Technologies International GmbH / Germany",
    "CHM" : "Rochester Robotics / USA",
    "CIGL" : "Colour Imaging Group, London College of Communication / UK",
    "CITI" : "Citizen / USA",
    "CL00" : "Candela, Ltd. / USA",
    "CLIQ" : "Color IQ / USA",
    "clsp" : "MacDermid ColorSpan, Inc. / USA",
    "CMCO" : "Chromaco, Inc. / USA",
    "CMiX" : "CHROMiX / USA",
    "COLO" : "Colorgraphic Communications Corporation / USA",
    "COMP" : "COMPAQ Computer Corporation / USA",
    "COMp" : "Compeq USA/Focus Technology / USA",
    "CONR" : "Conrac Display Products / USA",
    "CORD" : "Cordata Technologies, Inc. / USA",
    "CPQ" : "Compaq Computer Corporation / USA",
    "CPRO" : "ColorPro / Germany",
    "CRN" : "Cornerstone / USA",
    "CTX" : "CTX International, Inc. / USA",
    "CVIS" : "ColorVision / USA",
    "CWC" : "Fujitsu Laboratories, Ltd. / JAPAN",
    "DARI" : "Darius Technology, Ltd. / USA",
    "DATA" : "Dataproducts / USA",
    "DCP" : "Dry Creek Photo / USA",
    "DCRC" : "Digital Contents Resource Center, Chung-Ang University / Republic of Korea",
    "DELL" : "Dell Computer Corporation / USA",
    "DIC" : "Dainippon Ink and Chemicals / USA",
    "DICO" : "Diconix / USA",
    "DIGI" : "Digital / USA",
    "DL&C" : "Digital Light & Color / USA",
    "DPLG" : "Doppelganger, LLC / USA",
    "DS" : "Dainippon Screen / USA",
    "ds" : "Dainippon Screen / USA",
    "DSOL" : "DOOSOL / Korea",
    "DUPN" : "DuPont / USA",
    "dupn" : "DuPont / USA",
    "Eizo" : "EIZO NANAO CORPORATION / Japan",
    "EPSO" : "Epson /",
    "ESKO" : "Esko-Graphics / BELGIUM",
    "ETRI" : "Electronics and Telecommunications Research Institute / Republic of Korea",
    "EVER" : "Everex Systems, Inc. / USA",
    "EXAC" : "ExactCODE GmbH / Germany",
    "FALC" : "Falco Data Products, Inc. / USA",
    "FF" : "Fuji Photo Film Co.,LTD / JAPAN",
    "FFEI" : "FujiFilm Electronic Imaging, Ltd. / USA",
    "ffei" : "FujiFilm Electronic Imaging, Ltd. / USA",
    "flux" : "FluxData Corporation / USA",
    "FNRD" : "fnord software / USA",
    "FORA" : "Fora, Inc. / USA",
    "FORE" : "Forefront Technology Corporation / USA",
    "FP" : "Fujitsu / JAPAN",
    "FPA" : "WayTech Development, Inc. / TAIWAN",
    "FUJI" : "Fujitsu / JAPAN",
    "FX" : "Fuji Xerox Co., Ltd. / JAPAN",
    "GCC" : "GCC Technologies, Inc. / USA",
    "GGSL" : "Global Graphics Software Limited / USA",
    "GMB" : "Gretagmacbeth / USA",
    "GMG" : "GMG GmbH & Co. KG / Germany",
    "GOLD" : "GoldStar Technology, Inc. / USA",
    "GPRT" : "Giantprint Pty Ltd / Australia",
    "GTMB" : "Gretagmacbeth / USA",
    "GVC" : "WayTech Development, Inc. / TAIWAN",
    "GW2K" : "Sony Corporation / USA",
    "HCI" : "HCI / USA",
    "HDM" : "Heidelberger Druckmaschinen AG / GERMANY",
    "HERM" : "Hermes / USA",
    "HITA" : "Hitachi America, Ltd. / USA",
    "HiTi" : "HiTi Digital, Inc. / Taiwan",
    "HP" : "Hewlett-Packard / USA",
    "HTC" : "Hitachi, Ltd. / Japan",
    "IBM" : "IBM Corporation / USA",
    "IDNT" : "Scitex Corporation, Ltd. / ISRAEL",
    "Idnt" : "Scitex Corporation, Ltd. / ISRAEL",
    "IEC" : "Hewlett-Packard / USA",
    "IIYA" : "Iiyama North America, Inc. / USA",
    "IKEG" : "Ikegami Electronics, Inc. / USA",
    "IMAG" : "Image Systems Corporation / USA",
    "IMI" : "Ingram Micro, Inc. / USA",
    "Inca" : "Inca Digital Printers Ltd. / UK",
    "INTC" : "Intel Corporation / USA",
    "INTL" : "N/A / N/A",
    "INTR" : "Intra Electronics USA, Inc. / USA",
    "IOCO" : "Iocomm International Technology Corporation / USA",
    "IPS" : "InfoPrint Solutions Company / USA",
    "IRIS" : "Scitex Corporation, Ltd. / ISRAEL",
    "Iris" : "Scitex Corporation, Ltd. / ISRAEL",
    "iris" : "Scitex Corporation, Ltd. / ISRAEL",
    "ISL" : "Ichikawa Soft Laboratory / Japan",
    "ITNL" : "N/A / N/A",
    "IVM" : "IVM / USA",
    "IWAT" : "Iwatsu Electric Co., Ltd. / JAPAN",
    "JSFT" : "Jetsoft Development / USA",
    "JVC" : "JVC Information Products Co. / USA",
    "KART" : "Scitex Corporation, Ltd. / ISRAEL",
    "Kart" : "Scitex Corporation, Ltd. / ISRAEL",
    "kart" : "Scitex Corporation, Ltd. / ISRAEL",
    "KFC" : "KFC Computek Components Corporation / USA",
    "KLH" : "KLH Computers / USA",
    "KMHD" : "Konica Minolta Holdings, Inc. / Japan",
    "KNCA" : "Konica Corporation / Japan",
    "KODA" : "Kodak / USA",
    "KYOC" : "Kyocera / JAPAN",
    "LCAG" : "Leica Camera AG / Germany",
    "LCCD" : "Leeds Colour / UK",
    "LDAK" : "Left Dakota / USA",
    "LEAD" : "Leading Technology, Inc. / USA",
    "LEXM" : "Lexmark International, Inc. / USA",
    "LINK" : "Link Computer, Inc. / USA",
    "LINO" : "Linotronic / USA",
    "LITE" : "Lite-On, Inc. / USA",
    "MAGC" : "Mag Computronic (USA) Inc. / USA",
    "MAGI" : "MAG Innovision, Inc. / USA",
    "MANN" : "Mannesmann / USA",
    "MICN" : "Micron Technology, Inc. / USA",
    "MICR" : "Microtek / USA",
    "MICV" : "Microvitec, Inc. / USA",
    "MINO" : "Minolta / USA",
    "MITS" : "Mitsubishi Electronics America, Inc. / USA",
    "MITs" : "Mitsuba Corporation / USA",
    "Mits" : "MITSUBISHI ELECTRIC CORPORATION KYOTO WORKS / JAPAN",
    "MNLT" : "Minolta / USA",
    "MODG" : "Modgraph, Inc. / USA",
    "MONI" : "Monitronix, Inc. / USA",
    "MONS" : "Monaco Systems Inc. / USA",
    "MORS" : "Morse Technology, Inc. / USA",
    "MOTI" : "Motive Systems / Finland",
    "MSFT" : "Microsoft Corporation / USA",
    "MUTO" : "MUTOH INDUSTRIES LTD. / JAPAN",
    "NANA" : "NANAO USA Corporation / USA",
    "NEC" : "NEC Corporation / JAPAN",
    "NEXP" : "NexPress Solutions LLC / USA",
    "NISS" : "Nissei Sangyo America, Ltd. / USA",
    "NKON" : "Nikon Corporation / Japan",
    "ob4d" : "Erdt Systems GmbH & Co KG / Germany",
    "obic" : "Medigraph GmbH / Germany",
    "OCE" : "Oce Technologies B.V. / The Netherlands",
    "OCEC" : "OceColor / USA",
    "OKI" : "Oki / USA",
    "OKID" : "Okidata / USA",
    "OKIP" : "Okidata / USA",
    "OLIV" : "Olivetti / USA",
    "OLYM" : "OLYMPUS OPTICAL CO., LTD / JAPAN",
    "ONYX" : "Onyx Graphics / USA",
    "OPTI" : "Optiquest / USA",
    "PACK" : "Packard Bell / USA",
    "PANA" : "Matsushita Electric Industrial Co., Ltd. / JAPAN",
    "PANT" : "Pantone, Inc. / USA",
    "PBN" : "Packard Bell / USA",
    "PFU" : "PFU Limited / JAPAN",
    "PHIL" : "Philips Consumer Electronics Co. / Netherlands",
    "PNTX" : "HOYA Corporation PENTAX Imaging Systems Division / Japan",
    "POne" : "Phase One A/S / Denmark",
    "PREM" : "Premier Computer Innovations / USA",
    "PRIN" : "Princeton Graphic Systems / USA",
    "PRIP" : "Princeton Publishing Labs / USA",
    "QLUX" : "  Hong Kong, China",
    "QMS" : "QMS, Inc. / USA",
    "QPCD" : "QPcard AB / Sweden",
    "QUAD" : "QuadLaser / USA",
    "quby" : "Qubyx Sarl / FRANCE",
    "QUME" : "Qume Corporation / USA",
    "RADI" : "Radius, Inc. / USA",
    "RDDx" : "Integrated Color Solutions, Inc. / USA",
    "RDG" : "Roland DG Corporation / Japan",
    "REDM" : "REDMS Group, Inc. / USA",
    "RELI" : "Relisys / USA",
    "RGMS" : "Rolf Gierling Multitools / Germany",
    "RICO" : "Ricoh Corporation / USA",
    "RNLD" : "Edmund Ronald / FRANCE",
    "ROYA" : "Royal / USA",
    "RPC" : "Ricoh Printing Systems,Ltd. / Japan",
    "RTL" : "Royal Information Electronics Co., Ltd. / TAIWAN",
    "SAMP" : "Sampo Corporation of America / USA",
    "SAMS" : "Samsung, Inc. / USA",
    "SANT" : "Jaime Santana Pomares / SPAIN",
    "SCIT" : "Scitex Corporation, Ltd. / ISRAEL",
    "Scit" : "Scitex Corporation, Ltd. / ISRAEL",
    "scit" : "Scitex Corporation, Ltd. / ISRAEL",
    "SCRN" : "Dainippon Screen / USA",
    "scrn" : "Dainippon Screen / USA",
    "SDP" : "Scitex Corporation, Ltd. / ISRAEL",
    "Sdp" : "Scitex Corporation, Ltd. / ISRAEL",
    "sdp" : "Scitex Corporation, Ltd. / ISRAEL",
    "SEC" : "SAMSUNG ELECTRONICS CO.,LTD / Korea",
    "SEIK" : "Seiko Instruments U.S.A., Inc. / USA",
    "SEIk" : "Seikosha / USA",
    "SGUY" : "ScanGuy.com / USA",
    "SHAR" : "Sharp Laboratories / USA",
    "SICC" : "International Color Consortium / USA",
    "siwi" : "SIWI GRAFIKA CORPORATION / Indonesia",
    "SONY" : "SONY Corporation / JAPAN",
    "Sony" : "Sony Corporation / JAPAN",
    "SPCL" : "SpectraCal / USA",
    "STAR" : "Star / USA",
    "STC" : "Sampo Technology Corporation / USA",
    "TALO" : "Talon Technology Corporation / USA",
    "TAND" : "Tandy / USA",
    "TATU" : "Tatung Co. of America, Inc. / USA",
    "TAXA" : "TAXAN America, Inc. / USA",
    "TDS" : "Tokyo Denshi Sekei K.K. / Japan",
    "TECO" : "TECO Information Systems, Inc. / USA",
    "TEGR" : "Tegra / USA",
    "TEKT" : "Tektronix, Inc. / USA",
    "TI" : "Texas Instruments / USA",
    "TMKR" : "TypeMaker Ltd. / UK",
    "TOSB" : "TOSHIBA corp. / JAPAN",
    "TOSH" : "Toshiba, Inc. / USA",
    "TOTK" : "TOTOKU ELECTRIC Co., LTD / Japan",
    "TRIU" : "Triumph / USA",
    "TSBT" : "TOSHIBA TEC CORPORATION / JAPAN",
    "TTX" : "TTX Computer Products, Inc. / USA",
    "TVM" : "TVM Professional Monitor Corporation / USA",
    "TW" : "TW Casper Corporation / USA",
    "ULSX" : "Ulead Systems / Taiwan",
    "UNIS" : "Unisys / USA",
    "UTZF" : "Utz Fehlau & Sohn / Germany",
    "VARI" : "Varityper / USA",
    "VIEW" : "Viewsonic / USA",
    "VISL" : "Visual communication / ITALIA",
    "WANG" : "Wang / USA",
    "WLBR" : "Wilbur Imaging / UK",
    "WTG2" : "Ware To Go / The Netherlands",
    "WYSE" : "WYSE Technology / USA",
    "XERX" : "Xerox Corporation / USA",
    "XRIT" : "X-Rite / USA",
    "yxym" : "YxyMaster GmbH / Germany",
    "Z123" : "Lavanya's test Company / USA",
    "Zebr" : "Zebra Technologies Inc / France",
    "ZRAN" : "Zoran Corporation / USA"
}

models = {
    "0005" : "DPP-EX5",
    "0007" : "DPP-EX7",
    "000B" : "Samsung, Inc. CSA-7571",
    "0010" : "UP-DP10",
    "0015" : "UP-CR15L",
    "0016" : "UP-CX2",
    "0021" : "UP-D21MD",
    "0030" : "DPP-FP30",
    "0039" : "NEC Pinwriter CP7",
    "0050" : "EX-50",
    "0055" : "UP-D55",
    "0057" : "Brother HL-4",
    "008A" : "Digital PrintServer 32",
    "00B1" : "Kyocera FS-400/FS-400A",
    "00DE" : "Princeton Graphic Systems Ultra-1600",
    "00E5" : "TAXAN UltraVision_1000",
    "0100" : "UP-DR100",
    "0129" : "DPP-MP1",
    "0148" : "Fujistu DL 1200",
    "0190" : "ADI Microscan 2E SM-5514B",
    "01B8" : "Fujistu DL 1100",
    "01C5" : "Xerox WorkCentre 7132 PCL 6",
    "01DA" : "Star XB24-200",
    "0201" : "UP-CR20L",
    "020A" : "Okidata ML 93-IBM",
    "020A" : "Okidata ML 93-IBM",
    "0234" : "Star XR-1020",
    "02DC" : "NEC Pinwriter P3300",
    "0309" : "HP LaserJet 4ML PostScript",
    "0324" : "Star XR-1520",
    "034A" : "FUJITSU XL-C2000",
    "036A" : "Epson FX-86e",
    "03F0" : "Mitsubishi FA-3415",
    "043D" : "",
    "0461" : "Oki ML 182 Elite (IBM)",
    "04C2" : "Star ZA-250",
    "04DF" : "Canon LBP-4 Lite",
    "04E2" : "HP LaserJet 4ML",
    "0506" : "HP LaserJet IIID PostScript+",
    "0557" : "Brother HL-8",
    "0557" : "Brother HL-8",
    "0584" : "Philips 9CM082",
    "05C3" : "Xerox WorkCentre Pro C232 PCL 6",
    "05DF" : "Olivetti DM 95",
    "060C" : "Epson FX-1170",
    "06E9" : "GVC 17 Monitor 1",
    "06FD" : "HP 7580A",
    "0700" : "UP-D700",
    "0709" : "FX ApeosPort C3626 I PS",
    "072E" : "Epson LQ-1070 ESC/P 2",
    "077F" : "FX DocuColor 5065 PSS6 PS J5 v3017.101",
    "07BD" : "HP 7580B",
    "07D1" : "FX Xerox DocuColor 1632 PS",
    "07E7" : "",
    "0805" : "FX DocuCentre-III C4100 Scan",
    "0806" : "HP DeskJet Portable",
    "0836" : "Varityper VT-600",
    "0852" : "Star NX-1500",
    "0856" : "FX ApeosPort-III 6000 Scan",
    "086B" : "COMPAQ 151FS Color Monitor",
    "0874" : "Epson SQ-850",
    "08B7" : "Star LC-10",
    "091D" : "Seikosha SP-1900+",
    "092C" : "FX DocuCentre Color 240 PS",
    "0930" : "Mag Computronic PMV-1531",
    "0931" : "FX Document Centre C450 Scan",
    "0940" : "Star NX-1000",
    "0984" : "Oki ML 391 Elite",
    "0A2F" : "FX DocuPrint C3530",
    "0A3B" : "Iiyama VisionMaster MF-8217",
    "0A4F" : "Epson ActionLaser II",
    "0A6C" : "IBM 4029 LaserPrinter PS17",
    "0A8F" : "Oki ML 520 Elite (Microline)",
    "0AA1" : "FX DocuCentre-III 6000 Scan",
    "0AC8" : "Darius Technology, Ltd. TSM-1431",
    "0B0A" : "FX DocuCentre-III C5500 Scan",
    "0B12" : "FX DocuCentre-III C7500 Scan",
    "0B77" : "Star LC-15",
    "0B89" : "FX Document Centre C250 PCL 6",
    "0B94" : "Iocomm CM-7126",
    "0BFB" : "HP DeskJet 560C Printer",
    "0C09" : "Fujitsu DL 4600",
    "0C13" : "CTX International, Inc. CPS-1760",
    "0CB0" : "Star LaserPrinter 4III",
    "0CE3" : "CTX International, Inc. CPS-1460",
    "0CX2" : "UP-CX2",
    "0D34" : "HP LaserJet 2000",
    "0DA5" : "Mannesmann Tally T7010",
    "0DA9" : "HP LaserJet IIID PS Cartridge",
    "0DF1" : "Panasonic KX-P3634",
    "0E19" : "FX DocuCentre C6550 I",
    "0E36" : "KFC Computek CA-17",
    "0E49" : "Oki ML 521 Elite (IBM)",
    "0E77" : "Okidata ML 391",
    "0E8D" : "NEC Pinwriter P6200",
    "0EC6" : "Epson LQ-570 ESC/P 2",
    "0EDC" : "FX DocuCentre-II C3000 PCL 6",
    "0EE2" : "FX DocuCentre Color a450 PS",
    "0F57" : "Okidata ML 193",
    "0F95" : "Star SJ-48",
    "0F97" : "Okidata ML 591",
    "0FA7" : "Okidata ML 293",
    "0FBA" : "Brother HL-10V",
    "0FEB" : "XL-C7200",
    "1000" : "DS 1000 PS Large Format Inkjet Printer",
    "1000" : "DS 1000 PS Large Format Inkjet Printer",
    "102D" : "FX ApeosPort-II C5400",
    "104B" : "Lexmark WinWriter 600",
    "109C" : "OceColor G5242 PS",
    "10A5" : "Monitronix, Inc. MX-240EZ",
    "10EA" : "Adara Technology, Inc. AML-1402",
    "1100" : "UP-DR100",
    "1102" : "Okidata OL-400",
    "113C" : "HP LaserJet IIIP PostScript+",
    "1149" : "Conrac 9250",
    "1196" : "Sharp JX-9700E",
    "11D8" : "QMS 4525 Print System",
    "11DE" : "FX ApeosPort C4535 I PS",
    "11E7" : "Relisys RE-5155",
    "1221" : "Tatung CM-1495G",
    "128C" : "Optiquest 3000",
    "1294" : "Stylus COLOR 300",
    "12C2" : "Okidata OL-800",
    "12E5" : "QMS ColorScript 210",
    "12F6" : "Oki OL-840",
    "1301" : "Canon Bubble-Jet BJ-10e",
    "1302" : "FX Xerox DocuColor 1632",
    "1304" : "FX DocuCentre Color 400 E",
    "1322" : "Apple LaserWriter II NTX",
    "1334" : "Relisys RE-1420",
    "135A" : "Panasonic KX-P4450i",
    "1384" : "Stylus COLOR 600",
    "13CC" : "HP DraftPro",
    "141C" : "HP LaserJet Series II",
    "1450" : "Brother HJ-770",
    "1451" : "FX DocuCentre-II C2200",
    "14A5" : "FX ApeosPort C5540 I PS",
    "14A8" : "Bull Compuprint PageMaster 815",
    "14B6" : "Panasonic KX-P1695",
    "14B7" : "Star XB-2425",
    "1504" : "UP-DR150",
    "1520" : "HP ThinkJet (2225 C-D)",
    "1537" : "FS-1200/FS-1300",
    "1554" : "Fujitsu 15 Monitor",
    "1564" : "Relisys RE-1528",
    "1568" : "Model 1568G1 15 inch Monitor",
    "1571" : "HP LaserJet IIP",
    "1594" : "TAXAN MultiVision_795",
    "15E8" : "Bull Compuprint PageMaster 413",
    "16CD" : "FX DocuCentre Color a250",
    "170D" : "Okidata ML 395C",
    "1710" : "",
    "1726" : "Star LaserPrinter 8 DB",
    "172D" : "FX DocuCentre Color a450",
    "175D" : "NEC Silentwriter2 Model 90",
    "1764" : "",
    "1765" : "Mitsubishi FHL-6115STK",
    "1769" : "Model 1769G 17 inch Monitor",
    "1777" : "Star XB-2420",
    "17D5" : "NEC Silentwriter LC 890XL",
    "17D6" : "QMS-PS 825 MR",
    "17E8" : "IBM, Inc. 8506",
    "1806" : "Olivetti DM 109",
    "188A" : "FX ApeosPort-II C3300 PCL 6",
    "189b" : "RICOH IPSiO CX3000",
    "18D7" : "IBM Proprinter II",
    "1910" : "",
    "1925" : "FX DocuCentre Color a250 TAB",
    "1942" : "Epson LQ-1070+ ESC/P 2",
    "1943" : "FX DocuCentre Color a450 TAB",
    "1946" : "Citizen Swift 240 ESC/P 2",
    "194B" : "TECO TE1591",
    "198b" : "RICOH Aficio CL3500N, RICOH IPSiO CX3500",
    "19D6" : "EPSON_Printer1",
    "1A51" : "Panasonic KX-P4410",
    "1A56" : "Epson EPL-4300",
    "1A71" : "HP LaserJet IID",
    "1A78" : "AT&T 435",
    "1A92" : "Panasonic KX-P4451",
    "1a97" : "RICOH imagio Neo C200",
    "1AA6" : "Epson EPL-4000",
    "1AB2" : "Epson AP-5500 ESC/P 2",
    "1AE7" : "Mag Computronic Colorview/15",
    "1B09" : "Citizen PN48",
    "1B30" : "Digital DECcolorwriter 1000",
    "1B43" : "Compaq PageMarq 15",
    "1B54" : "MJ-810C/Stylus COLOR 500",
    "1b6d" : "RICOH imagio Neo C285/355/455/246",
    "1BB5" : "FX ApeosPort-II C6500 Scan",
    "1BEE" : "AT&T 473/478",
    "1C00" : "Star NX-2410",
    "1C62" : "Canon Bubble-Jet BJ-330",
    "1C9E" : "HP PaintJet XL300 PostScript",
    "1D08" : "Okidata ML 184 Turbo",
    "1D1A" : "COMPAQ VGA Color Monitor, or Compatible",
    "1D2D" : "Mannesmann Tally MT 130/24",
    "1D60" : "TI microLaser 600",
    "1D62" : "Canon Bubble-Jet BJC-600",
    "1DA5" : "Mannesmann Tally MT 150/24",
    "1DAF" : "Nissei Sangyo CM2086A",
    "1DCE" : "Okidata OL830 PostScript",
    "1e21" : "RICOH IPSiO Color 6000/6500, RICOH Aficio CL5000",
    "1E7C" : "FX DocuPrint C4450",
    "1F48" : "FX ApeosPort-III C2200",
    "1F64" : "Star LC24-15 II",
    "1F72" : "NANAO USA Corporation 9065S",
    "1FBF" : "Kyocera FS-5900C",
    "1FC0" : "Star NX-2415",
    "1FE1" : "Mannesmann Tally MT 83",
    "2000" : "A2000",
    "2009" : "DPP-M1",
    "2011" : "DPP-M55",
    "2020" : "P-300",
    "203U" : "TekBright 700PM (PV2003U)",
    "2040" : "CVP-P77",
    "205U" : "TekBright 500V (PV2005U)",
    "206U" : "TekBright 700P(PV2006U)",
    "2071" : "Tatung MM-1295",
    "2092" : "FX ApeosPort C7550 I PCL 6",
    "2100" : "NexPress 2100 digital production color press",
    "2100" : "NexPress 2100 digital production color press",
    "215F" : "FX ApeosPort-II 6000 Scan",
    "21E1" : "FX DocuCentre C6550 I PCL 6",
    "2200" : "M2200",
    "230C" : "FX DocuCentre C2100 PS",
    "2316" : "FX ApeosPort C6550 I PCL 6",
    "2318" : "FX ApeosPort-III C3300",
    "2335" : "Okidata ML 521-IBM",
    "2336" : "TAXAN MultiVision_770+",
    "2343" : "Microtek TrueLaser",
    "2353" : "Okidata ML 321-IBM",
    "237D" : "Seikosha SL-80 IP",
    "2386" : "Hewlett-Packard Co. D1188A",
    "23B1" : "FX Document Centre C250 Scan",
    "23B9" : "TI 850/855",
    "23BA" : "NEC Pinwriter P6",
    "23EC" : "HP LaserJet III PS Cartidge",
    "23P" : "hp P930 color monitor",
    "23P" : "hp 1825 flat panel monitor",
    "2417" : "FX DocuCentre Color 160 Scan",
    "2487" : "CTX International, Inc. CVS-3450",
    "2488" : "Acer America Corp. 35",
    "24A1" : "FX ApeosPort C6550 I PS",
    "24A2" : "Brother HJ-400",
    "24C1" : "QMS 860+ Print System",
    "24F2" : "Olivetti DM 324 L",
    "24F9" : "Epson MX-100",
    "2500" : "NexPress 2500 digital production color press",
    "2508" : "NEC Silentwriter S102",
    "2537" : "Dataproducts LZR-2665",
    "2597" : "FX DocuCentre-II C5400 Scan",
    "25B2" : "Brother HJ-100",
    "25C3" : "Panasonic KX-P1124",
    "2603" : "Panasonic KX-P1121",
    "2604" : "Epson EPL-5200",
    "2608" : "Acer America Corp. 33",
    "2623" : "FX DocuCentre-II C2200 PS",
    "2679" : "Everex Eversync_SVGA",
    "269C" : "FX DocuCentre Color a360",
    "2760" : "FX ApeosPort-II C5400 Scan",
    "2794" : "Philips 20CM64",
    "27AD" : "Ikegami C/DM-2060",
    "27D1" : "Panasonic KX-P5410",
    "27E6" : "Mannesmann Tally T9017",
    "27EB" : "QMS-PS 1700",
    "2862" : "Hitachi America, Ltd. 20-AS",
    "2879" : "Olivetti ETV 5000",
    "28B8" : "Kyocera W52-08C",
    "291B" : "Fujistu DL 3350",
    "2922" : "Hitachi America, Ltd. 20-AP",
    "2949" : "Microvitec, Inc. 604/FST",
    "2965" : "QMS-PS 820 Turbo",
    "2966" : "FX DocuPrint C2220 PS",
    "2976" : "FX DocuCentre-II C7500 PS",
    "29A3" : "ES-8000",
    "29C1" : "FX DocuPrint C3250 PS",
    "29F7" : "CTX International, Inc. CPS-2180",
    "2A1C" : "Mannesmann Tally MT 230/9",
    "2A58" : "Mannesmann Tally MT 130/9",
    "2A5E" : "HP LaserJet 4/4M PostScript",
    "2A62" : "Monitronix, Inc. MX-200MC",
    "2AAC" : "IBM 4070 IJ",
    "2AC5" : "IBM 4019 LaserPrinter",
    "2ACO" : "Ricoh LP-1200",
    "2AE5" : "Epson LQ-2500",
    "2B62" : "Toshiba ExpressWriter 440",
    "2BD0" : "HP QuietJet Plus",
    "2C1E" : "FX DocuCentre-III 3007 Scan",
    "2C33" : "Canon Bubble-Jet BJ-200",
    "2C33" : "Canon Bubble-Jet BJ-130e",
    "2C48" : "AOC CM-325",
    "2C90" : "Brother M-1809",
    "2CB8" : "Apple LaserWriter Pro 810",
    "2CD7" : "Olivetti DM 309 SL",
    "2D02" : "Brother HL-10DV",
    "2D08" : "AOC CM-326",
    "2D9D" : "FX ApeosPort-II C4300",
    "2DD7" : "FX ApeosPort-II C2200 PCL 6",
    "2DFB" : "Citizen 200GX",
    "2E2D" : "Mannesmann Tally MT 230/24",
    "2E3D" : "QMS-PS 800 Plus",
    "2E9B" : "NEC Colormate PS/80",
    "2E9E" : "NEC Colormate PS/40",
    "2EBC" : "FX DocuCentre C3626 I",
    "2EC2" : "FX Document Centre C360 Scan",
    "2EE4" : "IBM Personal Printer II 2391",
    "2F14" : "Dell Computer Corporation GPD-19C",
    "2F3F" : "Microvitec, Inc. 4015/FST",
    "2F4F" : "Oki ML 321 Elite (IBM)",
    "2F70" : "Oki ML 320 Elite (Microline)",
    "2FC0" : "FX ApeosPort-II C7500 PS",
    "2FCB" : "Mag Computronic PMV-14AC/plus",
    "2FD9" : "Digital DEClaser 3250",
    "3000" : "HP Indigo Series 2 Digital Press",
    "3022" : "FX ApeosPort 750 I Scan",
    "302D" : "NEC Silentwriter2 990",
    "304B" : "Cordata CMC-141M",
    "3056" : "MAG Innovision, Inc. MX17F/S",
    "30B5" : "MAG Innovision, Inc. MX21NT",
    "30D4" : "Mannesmann Tally MT Lite",
    "3117" : "FX ApeosPort-II 7000K Scan",
    "3137" : "Image Systems Corporation M24LMAX",
    "3182" : "Colorgraphic EG2040",
    "3188" : "QMS 860 Print System",
    "3188" : "QMS 860 Print System",
    "31D2" : "FX DocuPrint C2220 ART EX",
    "31FE" : "Canon LBP-430",
    "3200" : "FX DocuColor 1257 PSS70 PS J2 v3017.102",
    "3226" : "GT-5000",
    "3248" : "Oki ML 3410 Elite (IBM)",
    "324A" : "Kyocera FS-1500/FS-1500A",
    "326D" : "NEC MultiSync 5FG",
    "329D" : "NEC MultiSync 6FG",
    "3336" : "GT-5500",
    "337B" : "QMS-PS 2210",
    "33A4" : "Cordata CMC-1500TF",
    "33CB" : "IBM Portable Printer 5183",
    "33D9" : "Star NX-2420 Rainbow",
    "341B" : "Digital PrintServer 17/600",
    "3465" : "Digital DEClaser 2100/plus",
    "3479" : "Epson LX-100",
    "34B5" : "Epson LQ-400",
    "34D1" : "Epson LQ-150 ESC/P 2",
    "34F0" : "FX DocuCentre-III C3010 Scan",
    "34FC" : "IBM Proprinter X24e",
    "352A" : "Star FR-10",
    "352D" : "Radius PrecisionColor Display/19",
    "3537" : "TVM SuperSync_5A",
    "3555" : "Epson LQ-200",
    "3569" : "Epson LW-400",
    "3570" : "Rapid film scanner 3570 Plus",
    "3571" : "Panasonic C1381",
    "35B2" : "IBM Personal Page Printer II-30",
    "35BC" : "Sampo AlphaScan 17",
    "361D" : "TTX TTX3435AG",
    "3682" : "Citizen Swift 24x",
    "368A" : "Sharp JX-9460",
    "36A1" : "TI microLaser Pro 600 2014 PS23",
    "36A8" : "Star LaserPrinter 5",
    "36A9" : "Epson LX-800",
    "36EA" : "Star FR-15",
    "36ED" : "TTX TTX3436AG",
    "371E" : "icUlnt32Number header.model",
    "3730" : "Digital LA424",
    "3751" : "QMS 420 Print System",
    "3772" : "IBM 2390 PS/1",
    "3775" : "Epson LQ-800",
    "377A" : "NEC Color MultiWriter 7500C",
    "37A3" : "NEC Pinwriter P70",
    "37D3" : "FX DocuCentre C7550 I Scan",
    "37F9" : "Tatung CM-2000",
    "3821" : "FX DocuCentre-III C3100 Scan",
    "3840" : "Hermes H 606",
    "3854" : "FX DocuCentre-II C5400 PS",
    "3870" : "Citizen PROLaser 6000",
    "3885" : "Digital DEClaser 2250 plus",
    "3890" : "HP DeskJet 520 Printer",
    "38B4" : "FX DocuPrint C4350 PS",
    "38B7" : "FX ApeosPort C4535 I",
    "38F7" : "IBM 4039 plus PS",
    "38FA" : "Conrac 7550",
    "3933" : "Oki ML 591C Elite",
    "3944" : "CTX International, Inc. CVP-5439",
    "396B" : "NEC Silentwriter LC 890",
    "39CA" : "Samsung, Inc. MF-4771",
    "39E4" : "Seikosha LS-95 Color",
    "39EB" : "IBM Personal Pageprinter",
    "3A28" : "Epson AP-2000",
    "3A2D" : "FX DocuPrint C3540",
    "3A8A" : "PrintPartner GL-8300A",
    "3A8A" : "PrintPartner GL-8300A",
    "3AFA" : "FX ApeosPort 550 I Scan",
    "3B1E" : "Kyocera FS-5500/FS-5500A",
    "3B38" : "Epson AP-2500",
    "3B49" : "QMS 1725 Print System",
    "3B69" : "Mannesmann Tally MT 730/735",
    "3B95" : "FX ApeosPort-II 5000K Scan",
    "3BDE" : "Dell Computer Corporation Dell_VGA",
    "3BE1" : "IBM QuickWriter 5204",
    "3C25" : "QMS-PS 810 Turbo",
    "3C79" : "QMS ColorScript 100 Model 10",
    "3C97" : "Ikegami CT-20",
    "3C9D" : "GT-9000 TPU/ES-1200C TPU",
    "3CC8" : "GT-9500 TPU/GT-9500 TPU",
    "3CD8" : "Philips CM9214",
    "3D11" : "Kyocera LS-8000C",
    "3D70" : "IBM 4019 LaserPrinter PS39",
    "3D98" : "Philips CM9217",
    "3DB2" : "FX DocuPrint C2221 ART EX",
    "3DC4" : "FX ApeosPort-II C2200 Scan",
    "3E00" : "Olivetti PG 208 M2",
    "3E2B" : "FX Panasonic DP-CF78",
    "3E3A" : "Star LC24-100",
    "3E48" : "FX DocuCentre C2521 I",
    "3E70" : "Okidata ML 321",
    "3E75" : "Packard Bell PB8510SV",
    "3E8C" : "NEC Pinwriter P2200",
    "3EAC" : "Canon Bubble-Jet BJ-200e",
    "3EAD" : "Mannesmann Tally MT 350",
    "3ECA" : "Star LC24-200",
    "3ED7" : "FX DocuCentre Color 400",
    "3EE0" : "FX ApeosPort-II C5400 PS",
    "3F1A" : "FUJITSU XL-C3100",
    "3F42" : "Citizen Swift 24e",
    "3F72" : "Compeq CT-1958",
    "3F90" : "Okidata ML 521",
    "3FBE" : "FX DocuCentre C2100",
    "3FEA" : "FUJITSU XL-C3200",
    "3FED" : "FX DocuCentre C2101 Scan",
    "3FF6" : "Epson LQ-1050",
    "403E" : "Digital LA75",
    "4050" : "Kodak Professional 4050 PCD film scanner ",
    "406D" : "FX DocuPrint C2221 ART EX E",
    "4087" : "FX ApeosPort-III C4000 Scan",
    "4091" : "Kyocera FS-8000C",
    "409D" : "Sampo AlphaScan LC",
    "40BE" : "Mitsubishi HL-6605",
    "40C1" : "Okidata OL-850",
    "40F5" : "Oki OL-810",
    "4122" : "Olivetti JP 350s",
    "4168" : "Nissei Sangyo CM2085MU",
    "4168" : "Nissei Sangyo CM2085MU",
    "4189" : "COMPAQ QVision 200 Color Monitor",
    "4189" : "COMPAQ QVision 200 Color Monitor",
    "41F4" : "Nissei Sangyo CM2187MU",
    "4206" : "Toshiba P17CM00",
    "4210" : "HITACHI PK4210",
    "4220" : "HITACHI PK4220",
    "4263" : "Star LaserPrinter 8 II",
    "426C" : "GoldStar 1423",
    "42AC" : "Olivetti DM 342 SL",
    "4303" : "FX DocuCentre 650 I Scan",
    "4329" : "HP DeskJet 510",
    "4335" : "Oki OL-410",
    "4349" : "HP PaintJet XL",
    "4371" : "RICOH imagio Neo C380",
    "43FE" : "Digital LA70",
    "4456" : "Panasonic KX-P1081",
    "44C4" : "Panasonic KX-P1180",
    "4500" : "HP Color LaserJet 4500",
    "452E" : "Modgraph, Inc. MG-3200",
    "4530" : "FI-4530C",
    "4547" : "Digital turbo PrintServer 20",
    "4550" : "HP Color LaserJet 4550",
    "45F3" : "NEC MultiSync 3FGx",
    "460E" : "Seikosha SpeedJET 200",
    "462F" : "FX SII LS-3310 PS",
    "463E" : "Olivetti JP 360 (Monochrome)",
    "4648" : "ADI Microscan 3E+ SM-5514E",
    "4663" : "Oki ML 193 Elite (IBM)",
    "4678" : "FX DocuCentre-II C4300 PCL 6",
    "4700" : "Photo Printer",
    "4720" : "HITACHI Prinfina CX4720",
    "4730" : "HITACHI Prinfina CX4730",
    "4736" : "Citizen 9x",
    "473E" : "Princeton Graphic Systems Ultra-2000",
    "473x" : "HITACHI Prinfina CX4730",
    "4755" : "Forefront Technology MTS-9608S",
    "4788" : "Fujistu DL 2600",
    "47A8" : "IBM, Inc. 8511",
    "47F2" : "Canon LBP-4i",
    "47FB" : "Citizen PROjet II (Mono)",
    "483d" : "RICOH imagio MP C2500/C3000",
    "4856" : "CTX International, Inc. CVP-5468NI",
    "4915" : "Image Systems Corporation C21LMAX",
    "4995" : "QMS-PS 810",
    "49C5" : "FX DocuCentre Color f250 Scan",
    "49D0" : "Iiyama MF-5015A",
    "49F1" : "FX ApeosPort-II C4300 PS",
    "49F3" : "CTX International, Inc. CPS-2160",
    "49F6" : "Epson Stylus 800 ESC/P 2",
    "4A18" : "PrintPartner GL-8300",
    "4A52" : "Panasonic KX-P4440",
    "4A55" : "QMS-PS 410",
    "4A66" : "Star LC24-20",
    "4A8D" : "NEC Pinwriter P5200",
    "4AA5" : "Epson EPL-8000",
    "4AC9" : "PM-750C",
    "4B12" : "ViewSonic 8",
    "4B1B" : "IBM Proprinter XL",
    "4B21" : "Brother M-1324",
    "4B36" : "COMPAQ Internal VGA Panel",
    "4B96" : "CTX International, Inc. CVP-5468NL",
    "4BA4" : "Actix Systems, Inc. CX1557",
    "4BD9" : "PM-700C/Stylus Photo",
    "4C06" : "Star NX-2480",
    "4C07" : "Oki ML 280 (IBM)",
    "4C30" : "Philips 7CM329",
    "4C82" : "NEC MultiSync 3D",
    "4C87" : "Citizen GSX-220 ESC/P 2",
    "4C97" : "Ikegami C/DM-2010A",
    "4CC3" : "Okidata ML 391 Plus",
    "4CC8" : "FX ApeosPort-III C5500 Scan",
    "4CD0" : "FX ApeosPort-III C7500 Scan",
    "4D40" : "GT-12000 TPU",
    "4D6A" : "ViewSonic 6",
    "4DA1" : "Mannesmann Tally MT 94",
    "4DAF" : "Epson Stylus 1000 ESC/P 2",
    "4DE4" : "Tatung CM-1498R",
    "4E12" : "ViewSonic 4",
    "4E40" : "Linotronic 530",
    "4E57" : "Tektronix Phaser 300i",
    "4E61" : "Mannesmann Tally MT 91",
    "4e9b" : "RICOH IPSiO G707",
    "4EE1" : "Nissei Sangyo CM2186AF",
    "4F21" : "Mannesmann Tally MT 92",
    "4F45" : "FX DocuCentre-II C4300 PS",
    "4F52" : "ViewSonic 7",
    "4F64" : "Tatung CM-1498T",
    "4F71" : "NANAO USA Corporation 9060S",
    "4FA2" : "Linotronic 330",
    "4FA5" : "FX DocuPrint C5450 PS",
    "4fbb" : "RICOH IPSiO G505",
    "4FEA" : "Oki ML 520 Elite (IBM)",
    "5000" : "HITACHI Prinfina CX5000",
    "503A" : "GoldStar 1460 Plus VGA",
    "5053" : "Iiyama MF-5315",
    "506F" : "Citizen GSX-130",
    "509F" : "Citizen GSX-230",
    "50A8" : "FX DocuCentre C6550 I PS",
    "50AB" : "Fujitsu DX 2400",
    "50DF" : "FX DocuColor 1251 PLW",
    "5117" : "EPSON_Printer2",
    "5128" : "Intra Electronics USA, Inc. CM-1403",
    "512C" : "FX ApeosPort-II C4300 Scan",
    "514B" : "Fujistu DL 1250",
    "5167" : "FX DocuCentre-II C6500 PS",
    "5173" : "Iiyama MF-5117",
    "5183" : "Iiyama MF-5217",
    "518E" : "Toshiba PageLaser12",
    "51BB" : "Fujistu DL 1150",
    "51D9" : "Star XB24-250",
    "5222" : "Mitsubishi FL-6615ATK",
    "5228" : "C-Itoh 8510",
    "529D" : "FX DocuCentre Color f360",
    "52D9" : "Digital PrintServer 40 Plus",
    "5308" : "HP PaintJet XL 300",
    "5323" : "TAXAN UltraVision_1095",
    "534B" : "FX ApeosPort-II 5000 Scan",
    "5361" : "FX DocuCentre Color a450 Scan",
    "5367" : "Citizen GSX-240 ESC/P 2",
    "5370" : "Monitronix, Inc. MX240",
    "53A6" : "FX ApeosPort C6550 I",
    "53AA" : "Cordata CMC-1500BF",
    "53DB" : "FX DocuCentre-II C4300 Scan",
    "5451" : "Epson Compatible 9 Pin",
    "549C" : "OceColor G5241 PS",
    "54C1" : "Star ZA-200",
    "54E7" : "Epson LQ-560",
    "54F0" : "Apple LaserWriter Select 360",
    "54F2" : "Canon LBP-4U",
    "5536" : "TVM SuperSync_7A",
    "55F2" : "Tektronix Phaser 840",
    "5628" : "Sharp JX-9600",
    "5637" : "Tektronix Phaser 480",
    "5691" : "Premier PM14V-S-1",
    "56A9" : "Digital DEClaser 1152",
    "56C2" : "Tektronix Phaser 740",
    "56C7" : "Tektronix Phaser 780",
    "56D8" : "Sharp JX-9500",
    "56FE" : "HP 7585A",
    "5736" : "FX DocuCentre Color 500 PLW",
    "5738" : "Sharp JX-9300",
    "574D" : "FX ApeosPort-II C5400 PCL 6",
    "57A7" : "NEC Pinwriter P90",
    "57BE" : "HP 7585B",
    "57C3" : "Olivetti PG 308 HS",
    "5808" : "Okidata ML 193-IBM",
    "583B" : "Okidata ML 293-IBM",
    "5840" : "Triumph Adler SDR 7706",
    "590F" : "Epson LQ-1060+",
    "5933" : "TI microLaser PS35",
    "599C" : "FX ApeosPort-II C3300",
    "59B9" : "Philips CM9039",
    "59FF" : "Epson LQ-1050+",
    "5A14" : "NANAO USA Corporation F550i",
    "5A1A" : "HP DeskJet",
    "5A3C" : "IBM 4037 5E",
    "5A69" : "Epson ActionLaser 1000",
    "5A86" : "Princeton Publishing Labs MultiView_II",
    "5A89" : "Seiko CM-1450",
    "5A95" : "KLH Computers MN275",
    "5AA7" : "Seikosha SP-2400",
    "5AE3" : "Seiko ColorPoint PSX",
    "5B22" : "PM-2000C",
    "5B30" : "Philips 6CM321",
    "5B65" : "Brother HJ-100i",
    "5B79" : "Epson ActionLaser 1500",
    "5B89" : "Epson ActionLaser 1600",
    "5BB1" : "IBM Proprinter XL II",
    "5C0E" : "Epson FX-286",
    "5C43" : "Panasonic KX-P3124",
    "5C47" : "Kyocera FS-1500T",
    "5C78" : "QMS ColorScript 100 Model 30",
    "5CB3" : "Star LaserPrinter 8III",
    "5D44" : "Cordata CMC-2100H",
    "5DBE" : "Epson FX-185",
    "5E84" : "Cordata CMC-2100M",
    "5EA6" : "Epson EPL-7000",
    "5EB7" : "Okidata ML 380",
    "5EFF" : "FX DocuPrint C3540 PS",
    "5F0F" : "Okidata ML 591C",
    "5F19" : "FX DocuCentre-III C4400",
    "5F38" : "FX DocuColor 1257 PSS70 PS J5 v3017.102",
    "5F62" : "Olivetti DM 309 L",
    "5F75" : "KFC Computek CM-14",
    "5FB2" : "Epson DFX-5000",
    "5FB6" : "Epson EPL-7500",
    "606D" : "Citizen GSX-140",
    "60A6" : "Epson LX-850+",
    "60AC" : "FX DocuCentre C5540 I PS",
    "610A" : "FX ApeosPort-II C3300 Scan",
    "615C" : "FX ApeosPort-III C6500 Scan",
    "6167" : "FX Document Centre C360 PS",
    "6174" : "Apple LaserWriter IIg",
    "61D0" : "Iiyama MF-5214A",
    "61F1" : "Panasonic KX-P2624",
    "6201" : "MJ-6000C/Stylus COLOR 1520",
    "6203" : "Panasonic KX-P2123",
    "6209" : "Mannesmann Tally MT 151/9",
    "6225" : "GT-9000/ES-1200C",
    "6228" : "Olivetti JP 150",
    "6235" : "Star XR-1000",
    "623D" : "Canon LBP-860",
    "6242" : "Iiyama MF-5621",
    "6282" : "HP LaserJet 4L",
    "62B8" : "Star LC-200",
    "62CC" : "FX DocuCentre Color f250",
    "62D6" : "Citizen Prodot 9",
    "62D8" : "Olivetti JP 250",
    "62FF" : "FX DocuColor 4055 PSS6 PS J5 v3017.101",
    "630D" : "NEC Colormate PS",
    "6325" : "Star XR-1500",
    "632C" : "FX DocuCentre Color f450",
    "6335" : "GT-9500/GT-9500",
    "6345" : "FX DocuCentre Color f450 Scan",
    "634B" : "Digital PrintServer 17",
    "6352" : "Iiyama MF-5321",
    "63A2" : "Iiyama MF-5021",
    "63AD" : "Citizen GSX-145",
    "63DB" : "QMS-PS 2000",
    "63F1" : "Mitsubishi FA-3435",
    "63F7" : "FX ApeosPort C2521 I",
    "63FD" : "FX DocuCentre-II C3300 Scan",
    "6443" : "Mannesmann Tally MT 904 Plus",
    "64B6" : "Epson LQ-450",
    "64E5" : "Epson LQ-510",
    "6517" : "NEC SuperScript 4650",
    "6580" : "Philips 9CM062",
    "65CC" : "FX ApeosPort-II C2200",
    "65DB" : "NEC SuperScript 4600N",
    "6671" : "Panasonic C1395",
    "668D" : "Optiquest 4000",
    "66A1" : "Oki OL-840/PS",
    "66AA" : "Epson LX-850",
    "66B3" : "Star NX-2420 Rainbow II",
    "66E5" : "Oki OL-870/PS",
    "6776" : "Epson LQ-850",
    "67A0" : "NEC Pinwriter P20",
    "67C0" : "FX Xerox DocuColor 2240",
    "67DC" : "Tektronix Phaser II PX",
    "67E9" : "Olivetti JP 450 (color)",
    "686A" : "Mitsubishi HC-3905ATK",
    "687D" : "FX ApeosPort-II C7500",
    "68A8" : "Carroll Touch CT1381A",
    "68C4" : "TW Casper Corporation TM-5156H",
    "68D3" : "FX ApeosPort C5540 I Scan",
    "68E2" : "FX DocuCentre Color a250 PS",
    "6947" : "Epson MX-80",
    "695d" : "RICOH IPSiO CX8800/9800, RICOH Aficio CL7200/7300",
    "696F" : "NEC Jetmate 400",
    "6986" : "Mannesmann Tally MT 98/99",
    "699A" : "AT&T Computer Systems CRT-365",
    "69BD" : "Oki ML 590 Elite",
    "69BE" : "Philips CM9089",
    "69F3" : "Star XB24-15",
    "6A1F" : "Microvitec, Inc. 2012/LP",
    "6A33" : "Star XB24-10",
    "6AAF" : "NEC Jetmate 800",
    "6AE8" : "IBM 2380 Plus",
    "6B37" : "Okidata LaserLine 6",
    "6B8D" : "Digital PrintServer 17 12mb/L2",
    "6B9D" : "FX DocuPrint C3250",
    "6BA0" : "FP**S M33201C",
    "6BB2" : "FX DocuCentre Color 320 E",
    "6BB7" : "FX DocuCentre-II C2200 PCL 6",
    "6BBE" : "Fujitsu RX7100PS",
    "6BBE" : "Fujitsu RX7100PS",
    "6C39" : "Radius PrecisionColor Pivot",
    "6C56" : "Sharp JX-9500H",
    "6C6D" : "FX DocuCentre-III C2201 Scan",
    "6C9C" : "Microvitec, Inc. 2014/SVGA",
    "6CBE" : "Philips CM9085",
    "6D10" : "NANAO USA Corporation 9400i",
    "6D63" : "Fujitsu Breeze 200",
    "6D8E" : "FX DocuCentre Color 500 PLW E",
    "6D93" : "Fujitsu Breeze 100",
    "6DD3" : "Epson Stylus 300 ESC/P 2",
    "6DF2" : "Vacant",
    "6E0E" : "ViewSonic 5E",
    "6E2F" : "FX ApeosPort-III C2205 Scan",
    "6E5C" : "FX DocuCentre Color 400 PS",
    "6EC3" : "Cordata CMC-1500M",
    "6EE5" : "Epson LQ-1500",
    "6FF5" : "Epson LQ-1000",
    "7004" : "NEC PC-IN700/4C",
    "7006" : "NEC PC-IN700/6C",
    "7008" : "FilmScan 200",
    "701F" : "FX Document Centre C240 PS",
    "7034" : "Oki ML 193 Elite (Microline)",
    "704R" : "NEC PC-IN700/4CR (MultiReader400)",
    "705E" : "IBM Proprinter XL24",
    "705F" : "Epson AP-5500+ ESC/P 2",
    "706R" : "NEC PC-IN700/6CR (MultiReader600)",
    "709A" : "LP-8200CPD",
    "7108" : "",
    "711" : "",
    "711f" : "Vacant",
    "712" : "",
    "712B" : "GoldStar 1490",
    "714D" : "Olivetti PG 404",
    "7150" : "Display Model 7150",
    "717D" : "GoldStar 1510",
    "717D" : "GoldStar 1510",
    "7233" : "Epson MX-80 F/T",
    "725F" : "HP ColorPro with GEC",
    "7275" : "HP LaserJet 500+",
    "72B8" : "Epson DLQ-2000",
    "72E4" : "QMS ColorScript 230",
    "72F7" : "Tektronix Phaser 220i",
    "7301" : "FX ApeosPort C3626 I",
    "7336" : "Citizen Swift 90",
    "735F" : "Canon Bubble-Jet BJ-100",
    "735F" : "Canon Bubble-Jet BJ-20",
    "738C" : "Toshiba P21CM00",
    "73A0" : "Canon LBP-8 II",
    "73E6" : "MAG Innovision, Inc. MX15F",
    "7447" : "Epson ActionLaser Plus",
    "744D" : "Olivetti PG 408",
    "7483" : "Epson APT-750",
    "74AA" : "Oki ML 521 Elite (Microline)",
    "74FD" : "HP DeskJet Plus",
    "74K" : "74 Karat Printer",
    "7523" : "Iiyama MF-5121A",
    "755D" : "Olivetti PG 108",
    "7568" : "Star NX-1000 Rainbow",
    "75BF" : "HP DraftPro DXL",
    "7622" : "HP DraftMaster I",
    "7651" : "HP QuietJet",
    "7652" : "HP LaserJet 4Si/4SiMX PS",
    "7666" : "Mannesmann Tally T9005",
    "768B" : "Citizen Swift 9",
    "76A0" : "TAXAN MultiVision_875",
    "76A1" : "Epson APL-750",
    "76BD" : "FX DocuCentre-II C3000 Scan",
    "7700" : "UP-D70A",
    "773F" : "Olivetti JP 450",
    "7743" : "Okidata ML 193 Plus",
    "7768" : "Stylus Pro 5000",
    "776B" : "Mitsubishi FHL-6115SBK",
    "779E" : "Tektronix Phaser 840 Plus",
    "7808" : "Fujitsu DL 3600",
    "78E9" : "Nissei Sangyo CM1483M",
    "7916" : "Kyocera FS-2600/FS-2600A",
    "7918" : "Fujistu DL 3300",
    "7940" : "Epson AP-3260 ESC/P 2",
    "79D1" : "FX DocuCentre Color f360 PS",
    "79E1" : "FX DocuCentre Color a250 Scan",
    "79E5" : "Citizen Prodot 24",
    "79PL" : "Lexmark 4079 Plus",
    "7a41" : "RICOH imagio Neo C240/C320",
    "7A50" : "Panasonic KX-P4430",
    "7A5B" : "FX SII LS-3310",
    "7A61" : "HP PaintJet",
    "7A69" : "NEC Pinwriter P6plus",
    "7AE6" : "Epson LQ-2550",
    "7B23" : "Samsung, Inc. CT-4581",
    "7BF9" : "IBM 2391 Plus",
    "7C01" : "Star NX-2430",
    "7C17" : "Color PageWorks/Pro Ex",
    "7C2B" : "IBM Proprinter X24",
    "7C50" : "Brother M-1818",
    "7C53" : "Epson AP-5000+ ESC/P 2",
    "7C77" : "Olivetti DM 624",
    "7C80" : "NEC Multisync 4D",
    "7CF5" : "Citizen 180D",
    "7D63" : "HP DeskJet 1200C/PS",
    "7D67" : "Olivetti DM 324",
    "7DC5" : "FX Document Centre C320 PCL 6",
    "7DE1" : "Epson SQ-870 ESC/P 2",
    "7E15" : "Microvitec, Inc. 2019/SP",
    "7E24" : "IBM Personal Printer II 2380",
    "7ED5" : "Citizen 120D",
    "7EDC" : "FX DocuCentre Color 500 PS",
    "7F01" : "Linotronic 100",
    "7F2A" : "HP LaserJet 4Si",
    "7F5D" : "HP DeskJet 310 Printer",
    "7FA5" : "Panasonic KX-P1124i",
    "7FB0" : "Star NX-102 Rainbow",
    "7FD8" : "Apple LaserWriter Pro 600",
    "7FDA" : "Digital DEClaser 3200",
    "7FF0" : "FUJI XEROX SCANNER2",
    "7FF3" : "Linotronic 200",
    "800S" : "",
    "805A" : "IBM Proprinter XL III",
    "808F" : "ViewSonic 5+",
    "80A7" : "FX ApeosPort C7550 I",
    "80C3" : "Okidata OL-810",
    "80DC" : "Canon Bubble-Jet BJ-10sx",
    "80F7" : "Oki OL-850",
    "811 " : "",
    "812B" : "Digital DEClaser 2100",
    "81B6" : "Star LC-10 Colour",
    "81C9" : "Nissei Sangyo CM2087MU",
    "81DB" : "Digital DEClaser 2200",
    "8230" : "Citizen Swift 24",
    "82C7" : "Toshiba P17CM01",
    "82E6" : "Stylus Color 850",
    "82FF" : "Citizen 120D+",
    "8303" : "Okidata OL-410",
    "830L" : "NEC PC-PR830L Printer",
    "838B" : "WYSE Technology WY-890N",
    "838D" : "GoldStar 1620",
    "83BC" : "Citizen ABC ESCP/2",
    "83C7" : "Okidata OL850 PostScript",
    "83ED" : "FX DocuCentre C2521 I PS",
    "8404" : "CTX International, Inc. CVS-3436",
    "8444" : "TW Casper Corporation TM-5414",
    "84A5" : "Toshiba P17CS01",
    "84A9" : "IBM, Inc. 8515",
    "84B0" : "Star LC-100 Colour",
    "84C8" : "HP LaserJet IIISi",
    "84D4" : "TVM MG-11",
    "8500" : "HP Color LaserJet 8500",
    "8547" : "Toshiba P17CU01",
    "8550" : "HP Color LaserJet 8550",
    "8572" : "Canon LBP-8 IIT",
    "85DA" : "NEC SuperScript 4400, 4400N",
    "85DE" : "HP LaserJet IIID",
    "8650" : "Linotronic 630_630P",
    "8650" : "Linotronic 630_630P",
    "8652" : "FX DocuCentre 750 I Scan",
    "8660" : "Kodak Professional 8660 Thermal Printer",
    "8670" : "Kodak Professional 8670 - Thermal printer",
    "8678" : "Toshiba P351",
    "8691" : "Iiyama MR-5314",
    "86C7" : "Mannesmann Tally T7040 (Color)",
    "86D3" : "Apple LaserWriter",
    "8729" : "Fujistu DL 2400",
    "8735" : "FX DocuCentre Color f360 Scan",
    "8748" : "NANAO USA Corporation 6300",
    "87A5" : "Tatung CM-1498M",
    "87F2" : "Canon LBP-8 IIR",
    "8800" : "UP-D8800",
    "8807" : "Olivetti DM 119",
    "888F" : "Canon LBP-8 IIIR",
    "88CE" : "Seiko Personal ColorPoint PS",
    "88DE" : "HP LaserJet IIIP",
    "894F" : "FX DocuCentre-II C7500 Scan",
    "8987" : "FX ApeosPort-II C3300 PS",
    "8A0F" : "Canon LBP-8 IIIT",
    "8A31" : "Philips 7CM321",
    "8A50" : "Panasonic KX-P4400",
    "8A7A" : "Epson RX-100",
    "8ADC" : "NEC Pinwriter P5300",
    "8AF4" : "Epson EPL-8100",
    "8B40" : "CTX International, Inc. Multiscan 3436",
    "8B61" : "Toshiba ExpressWriter 420",
    "8BA2" : "FX DocuCentre-II C7500 PCL 6",
    "8BE7" : "Star LC24-22",
    "8C01" : "Star NX-2400",
    "8CF8" : "NEC Pinwriter P5XL",
    "8DA0" : "NANAO USA Corporation 9070U",
    "8DB9" : "Sampo AlphaScan Plus",
    "8DCD" : "Oki ML 320 Elite (IBM)",
    "8E17" : "Compaq PageMarq 20 PostScript",
    "8EA0" : "Mannesmann Tally MT 90",
    "8EB2" : "Canon LBP-8 III",
    "8EC3" : "Tektronix Phaser 220e 17",
    "8EC4" : "FX Document Centre C360 PCL 6",
    "8ED0" : "FX DocuCentre-II C6500 PCL 6",
    "8ED1" : "Seikosha SL-92",
    "8ED3" : "ViewSonic 5",
    "8F33" : "FX DocuCentre-II C3300 PS",
    "8F38" : "NEC Pinwriter P9XL",
    "8F72" : "FX DocuCentre 550 I Scan",
    "8FA6" : "Toshiba P1351",
    "8FB5" : "FX DocuPrint C4450 PS",
    "8FCC" : "Mitsuba Corporation 710MH",
    "8FD8" : "Apple LaserWriter Pro 630",
    "8FE0" : "Mannesmann Tally MT 93",
    "9000" : "YP-D9500",
    "9000" : "YP-D9500",
    "90A1" : "FX DocuPrint C1250 PLW E",
    "90AB" : "NANAO USA Corporation 9500",
    "90B7" : "TAXAN UltraVision_1150",
    "90F2" : "Iiyama MF-5115",
    "911A" : "Fujitsu DX 2300",
    "9122" : "Iiyama MF-5017",
    "91D2" : "Iiyama MF-5317",
    "924D" : "Digital DECmultiJET 2000",
    "9277" : "FX DocuColor 5065 PSS6 Scan v3017.101",
    "92CB" : "NEC Color MultiWriter 9500C",
    "92E2" : "Royal CJP 450",
    "9346" : "ES-8000 TPU",
    "9375" : "KFC Computek CH-14",
    "9387" : "HP LaserJet IIISi PostScript",
    "93DE" : "IBM ExecJet 4072",
    "9462" : "Seiko ColorPoint PSN",
    "947C" : "FX ApeosPort-II C6500",
    "9490" : "FX DC8000AP PSPX21 PS J7 v3018.101",
    "94A9" : "NEC SuperScript 4650NX",
    "94EB" : "Adara Technology, Inc. AML-2001",
    "9500" : "UP-D9500",
    "9521" : "",
    "953F" : "Olivetti DM 600 S",
    "964F" : "Seiko Professional ColorPoint PS=CPPRO518.SPD",
    "9670" : "Wang LDP8",
    "9679" : "Sharp JX-9700",
    "96A8" : "FX ApeosPort-III C4400",
    "96CA" : "Epson LQ-570+ ESC/P 2",
    "9723" : "Olivetti DM 309 S",
    "9728" : "Digital DEClaser 1150",
    "9776" : "Epson LQ-860",
    "977B" : "IBM ExecJet 4076 II",
    "97E9" : "Epson FX-80+",
    "9804" : "Okidata ML 292-IBM",
    "9835" : "Okidata ML 192-IBM",
    "985B" : "FX ApeosPort-III 7000 Scan",
    "988E" : "Seikosha LT-20",
    "9896" : "FX ApeosPort-II C2200 PS",
    "98A6" : "Toshiba GX-400",
    "98F5" : "IBM PS/1 2205",
    "993a" : "RICOH imagio Neo C600/C600Pro, RICOH Aficio 3260C/C5560",
    "996F" : "Qume Corporation QM835",
    "999F" : "AT&T Computer Systems CRT-395",
    "99BB" : "Philips CM9079",
    "99F0" : "IBM 4019 LaserPrinter PS17",
    "99F4" : "Okidata ML Pacemark 3410",
    "9A87" : "Acer America Corp. 15P",
    "9A90" : "COMPAQ 1024 Color Monitor",
    "9aa0" : "RICOH Aficio CL4000DN/4000HDN",
    "9AAC" : "FX DocuCentre-III 7000 Scan",
    "9ABF" : "Epson RX-80 F/T",
    "9B1F" : "FX DocuCentre-III C6500 Scan",
    "9BE6" : "Seikosha SP-2000",
    "9C0A" : "TECO TE2191",
    "9C46" : "NANAO USA Corporation T660",
    "9C8E" : "Digital DECwriter 95",
    "9CA7" : "FX ApeosPort C5540 I",
    "9CA9" : "Epson FX-800",
    "9D24" : "Canon LBP-8 III Plus",
    "9D81" : "FX DocuCentre-II C4300",
    "9DAA" : "Mannesmann Tally T7118C (Mono)",
    "9DB9" : "Epson FX-105",
    "9DC2" : "Okidata ML 390 Plus",
    "9E02" : "Panasonic KX-P3123",
    "9E4A" : "FX DocuPrint C3530 PS",
    "9E4C" : "Tektronix Phaser 840 Extended",
    "9E79" : "Epson FX-100",
    "9E7D" : "icUlnt32Number header.model",
    "9EA6" : "Triumph Adler SDR 7706 PS35",
    "9EAE" : "Mannesmann Tally MT 330",
    "9EC9" : "FX DocuCentre-II C3300 PCL 6",
    "9EF7" : "Epson EPL-7100",
    "9F1D" : "FX Panasonic DP-CF78 PS",
    "9F34" : "GT-8500/ES-1000C",
    "9F5F" : "Olivetti DM 209 L",
    "9F67" : "FX DocuCentre Color 320",
    "9F90" : "NANAO USA Corporation 9080i",
    "9FC4" : "FX DocuCentre Color 160",
    "9FF2" : "GoldStar 1470_Plus",
    "_R22" : "R22",
    "A001" : "Color PagePro",
    "A002" : "Color PagePro PS or Color PageWorks PS",
    "A003" : "Color PageWorks/Pro-ps",
    "A030" : "Citizen HSP-500",
    "A031" : "FX DocuCentre-II C5400",
    "A03C" : "HP ColorPro",
    "A042" : "Panasonic KX-P2124",
    "A0C0" : "Brother HL-6V",
    "A0FF" : "Star NX-2415 II",
    "A11G" : "A101GT/102GT",
    "A18C" : "MJ-5100C,MJ-910C/Stylus Pro XL+,Stylus Pro+",
    "A196" : "FX Document Centre C320 PS",
    "A1B5" : "Apple LaserWriter IIf",
    "A243" : "HP LaserJet 4M",
    "A250" : "Panasonic KX-P2023",
    "A258" : "Mannesmann Tally MT 150/9",
    "A262" : "Apple LaserWriter II NT",
    "A265" : "KOKAK ColorEase PS Printer",
    "A266" : "FX DocuCentre-III C4405 Scan",
    "A289" : "Olivetti JP 350",
    "A2A7" : "Epson EPL-6000",
    "A2E3" : "Iiyama MF-5421",
    "A2FF" : "Epson LQ-870 ESC/P 2",
    "A303" : "Iiyama MF-5221",
    "A37A" : "QMS-PS 2200",
    "A489" : "FX DocuCentre C4535 I",
    "A4BA" : "Tektronix Phaser 840 Graphics",
    "A4E7" : "Epson LQ-550",
    "A536" : "TVM SuperSync_4A",
    "A551" : "EPL",
    "A570" : "Panasonic C1391",
    "A601" : "TXA3601GT",
    "A614" : "Oki OL-830/PS",
    "A631" : "TSA4631HT",
    "A632" : "TSA4632HT",
    "A642" : "Okidata ML 192 Plus",
    "A65C" : "Epson FX-1050",
    "A6A8" : "Epson LX-810",
    "A6C3" : "Tektronix Phaser 200i(4)",
    "A6C4" : "GoldStar 1453 Plus",
    "A6F3" : "FX DocuCentre-III C2200 PS",
    "A6F6" : "Epson LX-1050",
    "A71G" : "A701G/GT",
    "A727" : "Epson LQ-950",
    "A730" : "Panasonic C1795",
    "A750" : "HCI Maxiscan",
    "A750" : "HCI Maxiscan",
    "A7A2" : "NEC Pinwriter P60",
    "A7BE" : "HP 7586B",
    "A811" : "TXA3811HT/3611HT",
    "A84F" : "HP LaserJet IIP Plus",
    "A852" : "QuadLaser I",
    "A884" : "Star NB25-15",
    "A894" : "FX DocuCentre Color f250 PS",
    "A898" : "Unisys AP9210",
    "A899" : "IBM Proprinter III",
    "A89E" : "Toshiba P351SX",
    "A8E0" : "Epson FX-80",
    "A91H" : "A901H/HT",
    "A931" : "TSA3931HT",
    "A978" : "Epson LX-80",
    "A986" : "CTX International, Inc. CVP-5468",
    "A98B" : "Conrac 7241",
    "A997" : "Sharp JX-9500E",
    "A999" : "Epson Stylus Color",
    "A9AD" : "Oki ML 591 Elite",
    "A9CF" : "HP 7475A",
    "A9F0" : "Epson JX-80",
    "AA0B" : "Digital LA75 Plus",
    "AA1F" : "Star LC24-200 Colour",
    "aa46" : "RICOH Afico CL3100/2000",
    "AA8A" : "Epson AP-2250",
    "AA8D" : "Optiquest 1000",
    "AA8F" : "Mannesmann Tally MT 908",
    "AAB3" : "Fujitsu DL 900",
    "AAB8" : "Unisys AP9415",
    "AAF8" : "IBM 2390 Plus",
    "AB20" : "Epson FX-85",
    "AB44" : "Star NB24-10",
    "AB75" : "Olivetti JP 50",
    "AB83" : "HP LaserJet 4P",
    "ABA2" : "FX Document Centre C450 PCL 6",
    "ABD0" : "Epson RX-80",
    "ABF8" : "Epson LX-86",
    "ACAB" : "Epson FX-870",
    "AD27" : "Panasonic TX-2103MAA",
    "AD7F" : "HP LaserJet 4/4M Plus PS",
    "ADA2" : "Acer America Corp. 7015",
    "ADC8" : "Mitsubishi AUM-1381A",
    "AE4A" : "IBM Graphics",
    "AE4C" : "COMPAQ SVGA Color Monitor",
    "AE5E" : "GoldStar 1423 Plus VGA",
    "AEA1" : "IBM QuietWriter III",
    "AEAC" : "Mannesmann Tally MT 340",
    "AEC2" : "Okidata ML 393 Plus",
    "AEEC" : "IBM 4029 LaserPrinter PS39",
    "AF9B" : "Epson RX-80 F/T+",
    "AFA9" : "Epson EX-800",
    "AFD6" : "Olivetti JP 150 WS",
    "B001" : "Quick Scan 35",
    "B001" : "Quick Scan 35",
    "B002" : "DimageScanMulti",
    "B003" : "DimageScanSpeed",
    "B008" : "DiMAGE Scan MultiPRO",
    "B022" : "FX Document Centre C250 PS",
    "B023" : "DiMAGE Scan Dual3",
    "B024" : "DiMAGE F300",
    "B025" : "DiMAGE S414",
    "B026" : "DiMAGE F200",
    "B027" : "DiMAGE Xt",
    "B028" : "DiMAGE Scan Elite5400",
    "B029" : "DiMAGE A1",
    "B030" : "DiMAGE X20",
    "B032" : "DiMAGE Z1",
    "B0C8" : "QMS ColorScript Laser 1000",
    "B0DD" : "Nissei Sangyo CM1785MU",
    "B0F5" : "Nissei Sangyo CM1584MU",
    "B152" : "FX ApeosPort-II 7000 Scan",
    "B160" : "BJC-880J",
    "B18E" : "Mitsubishi HL-6935",
    "B1DC" : "GoldStar 1710",
    "B228" : "Epson AP-4000",
    "B248" : "Tatung CM-1700",
    "B270" : "BJC-680J",
    "B29A" : "Canon LBP-4",
    "B2B3" : "FX ApeosPort-III C3010 Scan",
    "B2C6" : "HP LaserJet",
    "B300" : "HP Business InkJet 3000",
    "B338" : "Epson AP-4500",
    "B350" : "BJC-455J",
    "B3A1" : "FX DocuCentre C3626 I PS",
    "B40A" : "BJC-4000",
    "B41A" : "BJC-4100",
    "B4A0" : "FX DocuCentre-III C3305 Scan",
    "B4FD" : "Toshiba P21CR01",
    "B513" : "FX DocuCentre Color a360 Scan",
    "B5EE" : "HP DraftPro EXL",
    "B5F9" : "Packard Bell PB8528SVG",
    "B5FC" : "Olivetti PG 308",
    "B60A" : "BJC-600",
    "B60B" : "BJC-600e",
    "B643" : "GT-12000",
    "B6C1" : "Panasonic KX-P1170",
    "B70A" : "BJC-70",
    "B70E" : "Okidata ML 393C Plus",
    "B731" : "Epson AP-3250 ESC/P 2",
    "B793" : "FX ApeosPort-III C4400 PS",
    "B7A6" : "Tektronix Phaser II PXi",
    "B7D0" : "Panasonic KX-P5400",
    "B7D8" : "EPSON_Printer3",
    "B7E2" : "FX DocuCentre-III C3300 PS",
    "B80A" : "BJC-800",
    "B899" : "icUlnt32Number header.model",
    "B89F" : "Princeton Publishing Labs MultiView",
    "B8A9" : "Fujistu DL 3400",
    "B8AC" : "Digital LN03R ScriptPrinter",
    "B910" : "BJC F620",
    "B995" : "QMS-PS 820",
    "B9A6" : "Star LC24-15",
    "B9A7" : "FX DocuCentre Color a360 PS",
    "BA3F" : "Compaq PageMarq 15 PostScript",
    "BA54" : "NEC Pinwriter P7plus",
    "BA66" : "Star LC24-10",
    "BA98" : "NEC Pinwriter P2plus",
    "BAB4" : "TVM SuperSync_3+",
    "BB08" : "Epson SQ-2550",
    "BB13" : "MJ-8000C/Stylus COLOR 3000",
    "BB59" : "Citizen GSX-245 ESC/P 2",
    "BBC1" : "Brother HL-4Ve",
    "BBE1" : "Canon LBP-8 IV",
    "BBE9" : "IBM 2381 Plus",
    "BC03" : "Brother M-1918",
    "BC13" : "FX DocuCentre-III 2007 Scan",
    "BC19" : "BARCO Calibrator 20",
    "BC1B" : "Panasonic TX-2013MAA",
    "BC22" : "Tektronix Phaser IISDX",
    "BC29" : "BARCO MegaCalibrator 29\" (27V)",
    "BC33" : "FX DocuCentre-II C3000 PS",
    "BCCC" : "Star LaserPrinter 5EX",
    "BCD1" : "FX ApeosPort C6550 I Scan",
    "BCE3" : "Citizen Prodot 9x",
    "BD36" : "Olivetti DM 224",
    "BDC6" : "Olivetti DM 124",
    "BE40" : "Linotronic 500",
    "BE47" : "HP LaserJet IIIP PS Cartridge",
    "BE62" : "Bus Computer Systems Bus_VGA",
    "BED7" : "Citizen 124D",
    "BEE5" : "IBM Personal Printer II 2381",
    "BF0D" : "TTX TTX3450AG",
    "BFA2" : "Linotronic 300",
    "BFB0" : "Digital DECcolorwriter 1000 17",
    "BI21" : "BARCO Imaging Display 21\" (20V) FST",
    "BI29" : "BARCO Megagraphics 29\" (27V)",
    "BILP" : "BARCO Imaging Displays 20\" (19V) LP Phosph.",
    "BINP" : "BARCO Imaging Displays 20\" (19V)",
    "BM14" : "BARCO Medical Display 14 (13V) xx=OEM",
    "BM15" : "BARCO Medical Display 15 (14V) xx=OEM",
    "BM21" : "BARCO Medical Workst Display 21\" (20V)",
    "BP21" : "BARCO Personal Calibrator 21 FST (20V)",
    "BR20" : "BARCO Reference Calibrator 20 (20V) Trinitron",
    "BR21" : "BARCO Reference Calibrator 21 (20V) FST",
    "BT01" : "magicolor 2450",
    "BT02" : "magicolor 5450",
    "BT03" : "magicolor 7450",
    "BT04" : "magicolor 5550",
    "BT05" : "magicolor 5570",
    "BT06" : "magicolor 5570CK",
    "BT07" : "bizhub C30P",
    "BT08" : "Color LP25-1",
    "BT09" : "Color LP30-1",
    "BT10" : "magicolor 4650",
    "BT11" : "bizhub C20P",
    "BT12" : "magicolor 4650CK",
    "BT13" : "magicolor 5650",
    "BT14" : "magicolor 5670",
    "BT15" : "magicolor 4695MF",
    "BT16" : "bizhub C31P",
    "BT17" : "magicolor 1650",
    "BT18" : "bizhub C20",
    "BT19" : "Color LP24-1P",
    "BT20" : "Color LP35-1P",
    "BT21" : "magicolor 4750",
    "BT22" : "bizhub C35P",
    "BT23" : "AcuLaser CX28",
    "C000" : "Standard CRT",
    "C001" : "CRT COLOR SENSOR SOFTWARE",
    "C001" : "CRT COLOR SENSOR SOFTWARE",
    "C023" : "Star SJ-48",
    "C07F" : "Princeton Graphic Systems Ultra-1400",
    "C080" : "Citizen Swift 200",
    "C095" : "FX DocuCentre-III C4400 PS",
    "C097" : "Apple Personal LaserWriter NTR",
    "C0A5" : "FX DocuCentre C7550 I PS",
    "C0C1" : "Brother HL-4V",
    "C0C4" : "Brother HL-8V",
    "C0E4" : "FX ApeosPort-III C3300 PS",
    "C0EF" : "COMPAQ QVision 150-170 Color Monitor",
    "C0F8" : "NEC Pinwriter CP6",
    "C110" : "",
    "C118" : "FX DocuCentre C5540 I",
    "C15C" : "IBM 4226 Model 302",
    "C19F" : "Princeton Graphic Systems Ultra-1200",
    "C1D6" : "Brother HL-6",
    "C1DC" : "Citizen Notebook Printer II",
    "C220" : "",
    "C237" : "Okidata ML 92-IBM",
    "C23B" : "FX ApeosPort-II C4300 PCL 6",
    "c25c" : "RICOH IPSiO CX7000/9000, RICOH Aficio CL7100",
    "C28D" : "NEC Pinwriter P3200",
    "C2CB" : "HP LaserJet 4",
    "C315" : "DCS 315 Digital Camera",
    "C330" : "",
    "C330" : "",
    "C345" : "Panasonic KX-P2180",
    "C347" : "Princeton Graphic Systems MAX-15",
    "C37B" : "QMS-PS 2220",
    "C3ED" : "Radius PrecisionColor Display/20",
    "C3F7" : "EPSON_Printer4",
    "C40F" : "Canon LBP-8sx",
    "C420" : "DCS 420 Digital Camera",
    "C440" : "",
    "C460" : "DCS 460 Digital Camera",
    "C496" : "Citizen Swift 240x ESC/P 2",
    "C4C4" : "FX DocuCentre-III C4000 Scan",
    "C520" : "DCS 520 Digital Camera",
    "C522" : "Okidata ML 184-IBM Turbo",
    "C52C" : "Digital DEClaser 1152 43 fonts",
    "C537" : "TVM SuperSync_6A",
    "C550" : "",
    "C55A" : "Diconix 150 Plus",
    "C560" : "DCS 560 Digital Camera",
    "C561" : "Oki ML 192 Elite (IBM)",
    "C56C" : "HP 7550A",
    "C582" : "Digital LA310",
    "C587" : "Bull Compuprint PageMaster 1025",
    "C600" : "",
    "C620" : "Eastman Kodak DCS620 Digital camera",
    "C629" : "Epson AP-3000",
    "C660" : "",
    "C689" : "Star LaserPrinter 4 StarScript",
    "C698" : "HP LaserJet Plus",
    "C69D" : "Oki OL-850/PS",
    "C710" : "Lexmark Optra C710",
    "C72B" : "Digital DEClaser 1100",
    "C748" : "FX Document Centre C240 PCL 6",
    "C770" : "",
    "C7AF" : "HP LaserJet 4 Plus",
    "C7CF" : "Canon LBP-4sx",
    "C880" : "",
    "C8B0" : "FX ApeosPort-II C6500 PCL 6",
    "C966" : "Seikosha Sp-2415",
    "C981" : "Star NX-1001",
    "C988" : "Brother M-1824L",
    "C990" : "",
    "C996" : "Oki ML 390 Elite",
    "C9A5" : "Oki ML 393 Elite",
    "C9C3" : "Oki ML 395 Elite",
    "CA28" : "QMS 3225 Print System",
    "CA6A" : "Iiyama VisionMaster MF-8317",
    "CA88" : "Seiko CM-1440",
    "CAF3" : "FX DocuColor 4055 PSS6 Scan v3017.101",
    "CB14" : "Panasonic TX-1703MAA",
    "CB14" : "Panasonic TX-1703MAA",
    "CB39" : "Conrac 7126",
    "CB3A" : "Seikosha SL-92",
    "CB48" : "Canon LBP-4 Plus",
    "CBA4" : "Mannesmann Tally T7018",
    "CBD7" : "FX DocuCentre C6550 I Scan",
    "CC13" : "NANAO USA Corporation F340iW",
    "CC42" : "Panasonic KX-P3134",
    "CCA8" : "Fujitsu DL 4400",
    "CCA9" : "Iiyama DR-3114",
    "CCAA" : "Epson FX-850",
    "CCB2" : "CTX International, Inc. CPS-1560",
    "CD40" : "FX ApeosPort-II C7500 PCL 6",
    "CD44" : "Brother HL-8D",
    "CD76" : "Okidata ML 395",
    "CDA8" : "MJ-500C/Stylus Pro",
    "CDE3" : "HP LaserJet 4MP",
    "CDT" : "Cathode Display Tube Monitor",
    "CE5A" : "JVC GD-H4220US",
    "CE94" : "FX DocuCentre Color f450 PS",
    "CEAD" : "Mannesmann Tally MT 360",
    "CEB6" : "Okidata ML 390",
    "CEDC" : "NEC Pinwriter P6300",
    "CF0E" : "Okidata ML 590C",
    "CF25" : "Tektronix Phaser III PXi",
    "CF52" : "ADI Microscan 4A SM-5515",
    "CF56" : "Okidata ML 590",
    "CF66" : "Okidata ML 292",
    "CF96" : "Okidata ML 192",
    "CFF6" : "Epson LQ-1060",
    "CFF6" : "Epson LQ-1060",
    "CFF9" : "FX DocuCentre C1101 Scan",
    "CG18" : "CG18",
    "CG21" : "CG21",
    "CM09" : "CM77*",
    "CM10" : "CM82*",
    "CM11" : "W20-LC3000",
    "CQ00" : "Compaq V40 Color Monitor",
    "CQ01" : "Compaq V50 Color Monitor",
    "CQ02" : "Compaq V70 Color Monitor",
    "CQ03" : "Compaq V90 Color Monitor",
    "CQ04" : "Compaq P50 Color Monitor",
    "CQ05" : "Compaq P70 Color Monitor",
    "CQ06" : "Compaq P110 Color Monitor",
    "CQ07" : "Compaq P1610 Color Monitor",
    "CQ08" : "Compaq TFT500 Flat Panel Monitor",
    "CQ08" : "Compaq TFT500 Flat Panel Monitor",
    "CQ09" : "Compaq V45 Color Monitor",
    "CQ09" : "Compaq V45 Color Monitor",
    "CQ10" : "Compaq V55 Color Monitor",
    "CQ10" : "Compaq V55 Color Monitor",
    "CQ11" : "Compaq V75 Color Monitor",
    "CQ11" : "Compaq V75 Color Monitor",
    "CQ12" : "Compaq P75 Color Monitor",
    "CQ12" : "Compaq P75 Color Monitor",
    "CQ13" : "Compaq TFT450 Flat Panel Monitor",
    "CQ13" : "Compaq TFT450 Flat Panel Monitor",
    "CQ14" : "Compaq V450 Color Monitor",
    "CQ14" : "Compaq V450 Color Monitor",
    "CQ15" : "Compaq V1000 Color Monitor",
    "CQ15" : "Compaq V1000 Color Monitor",
    "CQ16" : "Compaq TFT8000 Flat Panel Monitor",
    "CQ16" : "Compaq TFT8000 Flat Panel Monitor",
    "CQ17" : "Compaq S700 Color Monitor",
    "CQ17" : "Compaq S700 Color Monitor",
    "CQ18" : "Compaq S900 Color Monitor",
    "CQ18" : "Compaq S900 Color Monitor",
    "CQ19" : "Compaq V900 Color Monitor",
    "CQ19" : "Compaq V900 Color Monitor",
    "CQ20" : "Compaq V500 Color Monitor",
    "CQ21" : "Compaq TFT5000 Flat Panel Monitor",
    "CQ22" : "Compaq V700 Color Monitor",
    "CQ23" : "Compaq S500 Color Monitor",
    "CQ24" : "Compaq TFT5000S Flat Panel Monitor",
    "CQ25" : "Compaq MP1600 Microportable Projector",
    "CQ26" : "Compaq V410b Color Monitor",
    "CQ27" : "Compaq V510b Color Monitor",
    "CQ28" : "Compaq TFT7000 Flat Panel Monitor",
    "CQ29" : "Compaq P700 Color Monitor",
    "CQ30" : "Compaq S710 Color Monitor",
    "CQ31" : "Compaq S910 Color Monitor",
    "CQ32" : "Compaq P900 Color Monitor",
    "CQ33" : "Compaq P1100 Color Monitor",
    "CQ34" : "Compaq S410c Color Monitor",
    "CQ35" : "Compaq TFT150e Flat Panel Monitor",
    "CQ36" : "Compaq TFT8010 Flat Panel Monitor",
    "CQ37" : "Compaq TFT8020 Flat Panel Monitor",
    "CQ38" : "Compaq TFT5010 Flat Panel Monitor",
    "CQ39" : "Compaq V1100 Color Monitor",
    "CQ40" : "Compaq S510 Color Monitor",
    "CQ42" : "Compaq V710 Color Monitor",
    "CQ44" : "Compaq TFT5004/5005 Flat Panel Monitor",
    "CQ45" : "Compaq P710 Color Monitor",
    "CQ46" : "Compaq P910 Color Monitor",
    "CQ47" : "Compaq P1210 Color Monitor",
    "CQ50" : "Compaq Presario V410 Color Monitor",
    "CQ51" : "Compaq Presario V510 Color Monitor",
    "CQ52" : "Compaq Presario 1725 Color Monitor",
    "CQ53" : "Compaq Presario FX500 Color Monitor",
    "CQ54" : "Compaq Presario FX700 Color Monitor",
    "CQ55" : "PointView V710 Color Monitor",
    "CQ56" : "Compaq Presario MV400 color monitor",
    "CQ57" : "Compaq Presario MV500 color monitor",
    "CQ58" : "Compaq Presario MV700 color monitor",
    "CQ59" : "Compaq Presario MV900 color monitor",
    "CQ60" : "Compaq V910 color monitor",
    "CQ61" : "Compaq V720 color monitor",
    "CQ62" : "Compaq B400 color monitor",
    "CQ63" : "Compaq CV715 color monitor",
    "CQ64" : "Compaq Dawncom MV520 color monitor",
    "CQ65" : "Compaq Dawncom MV720 color monitor",
    "CQ66" : "Compaq MV520 color monitor",
    "CQ67" : "Compaq MV720 color monitor",
    "CQ68" : "Compaq MV920 color monitor",
    "CQ69" : "Compaq CV915 color monitor",
    "CQ70" : "Compaq B500 color monitor",
    "CQ71" : "Compaq MV420 color monitor",
    "CQ72" : "Compaq CV115 color monitor",
    "CQ73" : "Compaq B420 color monitor",
    "CQ74" : "Compaq B520 color monitor",
    "CQ75" : "Compaq CV515 color monitor",
    "CQ81" : "Compaq CV1130 color monitor",
    "CQ82" : "Compaq 700T color monitor",
    "CQ83" : "Compaq 900T color monitor",
    "CQ84" : "Compaq FP725D Digital Flat Panel Monitor",
    "CQ85" : "Compaq FP730A Analog Flat Panel Monitor",
    "CQ86" : "Compaq MV925 color monitor",
    "CQ87" : "Compaq MV730i color monitor",
    "CQ88" : "Compaq FP730D Digital Flat Panel Monitor",
    "CQ89" : "Compaq MV525 color monitor",
    "CQ90" : "Compaq FS700 color monitor",
    "D0E5" : "MJ-930C/Stylus COLOR 800",
    "D10E" : "FX DocuCentre-II C5400 PCL 6",
    "D128" : "HP DeskJet 500",
    "D134" : "Oki OL-400",
    "D1AA" : "Link Computer, Inc. CM-3",
    "D1BC" : "COMPAQ Advanced Graphics Color Monitor",
    "D1F5" : "FX ApeosPort-III C2200 PS",
    "D269" : "Microvitec, Inc. 1020/LP",
    "D2C0" : "Okidata OL-840",
    "D2F4" : "Oki OL-800",
    "D325" : "MJ-830C/Stylus COLOR 400",
    "D328" : "Digital DEClaser 2150",
    "D331" : "IBM Proprinter XL24e",
    "D365" : "Relisys RE-1520",
    "D369" : "IBM, Inc. 8508",
    "D383" : "Hewlett-Packard CO. D1187A",
    "D3D8" : "Digital DEClaser 2250",
    "D3F0" : "IBM 4039 LaserPrinter PS",
    "D46A" : "Link Computer, Inc. CE-8",
    "D472" : "Panasonic KX-P1654",
    "D4AD" : "FX ApeosPort C7550 I PS",
    "D523" : "Hitachi America, Ltd. 21-AP",
    "D535" : "Oki ML 321 Elite (Microline)",
    "D567" : "FX DocuPrint C2221 PS",
    "D57B" : "HP DeskJet 1200C",
    "D584" : "Brother HL-8e",
    "D5D2" : "Oki ML 395C Elite",
    "D600" : "PowerShot",
    "D605" : "Minolta SP 3500",
    "D61C" : "Citizen 224",
    "D622" : "FX Document Centre C450 PS",
    "D64D" : "Digital DECmultiJET 1000",
    "D669" : "IBM, Inc. 8504",
    "D6A3" : "Epson AP-5000 ESC/P 2",
    "D6AD" : "IBM 4079 Color Jetprinter PS",
    "D6C0" : "Panasonic KX-P1150",
    "D6C2" : "Cordata CMC-1700M",
    "D6EE" : "FX Document Centre C400 PS",
    "D6F9" : "FX DocuCentre-III C2200",
    "D717" : "Minolta SP 3000",
    "D75D" : "Digital DECmultiJET 1500",
    "D82A" : "FX JDLLP22COLOR",
    "D851" : "HP LaserJet 4M Plus",
    "D861" : "FX DocuCentre-II C7500",
    "D8A5" : "FX DocuCentre Color 320 PS",
    "D8A7" : "Olivetti DM 309",
    "D91A" : "TECO TE1491",
    "D993" : "Panasonic KX-P4455",
    "D994" : "QMS-PS 410",
    "D9D1" : "Iiyama MF-5014A",
    "D9EA" : "TECO TE1791",
    "DA05" : "Epson EPL-4200",
    "DA53" : "Panasonic KX-P4450",
    "DA67" : "Star LC24-30",
    "DA67" : "Star LC24-30",
    "DA79" : "Okidata ML 393C",
    "DADF" : "NEC Pinwriter P9300",
    "DAE0" : "FX DocuCentre Color 320/400 Scan",
    "DAE5" : "MJ-510/Stylus COLOR 200",
    "DAE8" : "Morse Technology, Inc.",
    "DAF4" : "FX DocuColor 4055 PSS6 PS J7 v3017.101",
    "DAF7" : "Epson EPL-4100",
    "DAFE" : "FX DocuPrint C3140 PS",
    "DB05" : "Citizen PROjet",
    "DB2D" : "Mannesmann Tally MT 230/18",
    "DC02" : "Star NX-2450",
    "DC33" : "Canon Bubble-Jet BJ-230",
    "DCA5" : "Monitronix, Inc. MX-210EZ",
    "DCA7" : "Star LaserPrinter 8 DX",
    "DCC1" : "Canon Bubble-Jet BJ-130",
    "DCCD" : "Star NL-10",
    "DCDD" : "NANAO USA Corporation T660i",
    "DCF5" : "Tegra Genesis",
    "DD30" : "FX DocuCentre-II C2200 Scan",
    "DD36" : "Seikosha SP-1900",
    "DD7A" : "Digital Colormate PS",
    "DD80" : "Olivetti JP 360 (Color)",
    "DDA0" : "Mannesmann Tally MT 84",
    "DDD6" : "FX DocuCentre C4535 I PS",
    "DE03" : "Canon Bubble-Jet BJC-800",
    "DE54" : "FX DocuCentre C5540 I Scan",
    "DE60" : "Mannesmann Tally MT 81",
    "DE6B" : "AT&T 470/475",
    "DE77" : "FX DocuColor 5065 PSS6 PS J7 v3017.101",
    "DEB9" : "Star LaserPrinter 5 TT/UK",
    "DF0D" : "FX DocuCentre C2101 PS",
    "DF11" : "Dell Computer Corporation GPD-16C",
    "DF18" : "FX DocuCentre C7550 I",
    "DF20" : "Mannesmann Tally MT 82",
    "DF3B" : "Brother HL-10h",
    "DF77" : "Olivetti DM 600",
    "DF9F" : "Oki OL-830 (PCL)",
    "DFB0" : "HP LaserJet III",
    "DFC8" : "Seiko CM-2050",
    "DFCD" : "FX DocuPrint C4350",
    "DIC1" : "DIC Standard Color Offset",
    "DIC2" : "DIC Standard Gravure",
    "DIC3" : "DIC Standard Color Offset Coated",
    "DIC4" : "Uncoated",
    "DP11" : "Inkjet 2011",
    "DP84" : "Model 15 inch 1024x768 Color CRT",
    "DP97" : "Model 17 inch1280x1024 Color CRT",
    "DP98" : "1280x1024 19 inch CRT",
    "DP99" : "1280x1024 21 inch CRT",
    "DPA7" : "1600x1200 17 inch CRT",
    "DPA8" : "1600x1200 19 inch CRT",
    "DPA9" : "1600x1200 21 inch CRT",
    "DR80" : "UP-DR80",
    "DR8M" : "UP-DR80MD",
    "E016" : "FX DocuColor 5000 PSPX1 PS J7 v3017.101",
    "E045" : "Stylus COLOR 640",
    "E047" : "Stylus COLOR 440",
    "E049" : "Tektronix Phaser 780 Graphics",
    "E049" : "Tektronix Phaser 780 Graphics",
    "E050" : "PM-770C",
    "E051" : "Stylus Photo 750",
    "E052" : "PM-3000C",
    "E054" : "PM-670C",
    "E056" : "PT-100",
    "E057" : "IP-100",
    "E058" : "PM-9000C",
    "E059" : "Stylus Pro 9000",
    "E060" : "CTM-950C",
    "E061" : "Stylus COLOR 900",
    "E062" : "PM-680C",
    "E064" : "PM-700C UG",
    "E066" : "EM-900C",
    "E069" : "Stylus COLOR 660",
    "E071" : "Stylus Scan 2000",
    "E073" : "Stylus Scan 2500",
    "E075" : "Stylus COLOR 460",
    "E077" : "Stylus Photo 710",
    "E079" : "Stylus Photo EX2",
    "E081" : "Stylus COLOR 760",
    "E083" : "Stylus COLOR 860",
    "E085" : "Stulus COLOR 1160",
    "E086" : "PM-800C",
    "E087" : "Stylus Photo 870",
    "E088" : "PM-3300C",
    "E089" : "Stylus Photo 1270",
    "E090" : "PM-800DC",
    "E092" : "PM-760C",
    "E098" : "PM-7000C",
    "E0B4" : "FX DocuCentre C5540 I PCL 6",
    "E0CB" : "Olivetti DM 124 C",
    "E106" : "MC-2000",
    "E107" : "Stylus Photo 2000P",
    "E122" : "MC-5000",
    "E123" : "Stylus Pro 5500",
    "E12C" : "Mannesmann Tally MT 131/24",
    "E130" : "PM-780C",
    "E131" : "Stylus Photo 790",
    "E132" : "PM-720C",
    "E134" : "PM-900C",
    "E136" : "PM-880C",
    "E136" : "PM-880C",
    "E137" : "Stylus Photo 890",
    "E138" : "PM-3500C",
    "E139" : "Stylus Photo 1290",
    "E140" : "MC-10000",
    "E141" : "Stylus Pro 10000CF",
    "E142" : "PM-10000",
    "E143" : "Stylus Pro 10000",
    "E144" : "CC-500L",
    "E146" : "PM-790PT",
    "E147" : "Stylus Photo 895",
    "E149" : "Stylus Photo 780",
    "E151" : "Stylus Photo 1280",
    "E153" : "Stylus Photo 785EPX",
    "E154" : "CL-750",
    "E155" : "Stylus C40/C20 Series",
    "E157" : "Stylus C60 Series",
    "E158" : "PM-730C",
    "E159" : "Stylus Photo 810",
    "E160" : "PM-920C",
    "E163" : "Stylus Photo 820",
    "E166" : "NEC Silentwriter 95",
    "E169" : "Stylus C80/C70 Series",
    "E170" : "PM-830C",
    "E172" : "PM-950C",
    "E174" : "PM-890C",
    "E176" : "PM-4000PX",
    "E177" : "Stylus Photo 2100/2200",
    "E178" : "PM-850PT",
    "E179" : "Stylus Photo 925",
    "E180" : "CC-550L",
    "E183" : "Stylus Pro 9600-DYE",
    "E184" : "PX-9000",
    "E185" : "Stylus Pro 9600",
    "E186" : "Digital DEClaser 2200/plus",
    "E187" : "Stylus Pro 7600-DYE",
    "E188" : "PX-7000",
    "E189" : "Stylus Pro 7600",
    "E191" : "1000 ICS",
    "E193" : "Stylus C41/C42 Seriese",
    "E195" : "Stylus C61/C62 Series",
    "E196" : "PM-840C",
    "E199" : "Stylus Photo 830",
    "E1A4" : "Mannesmann Tally MT 151/24",
    "E201" : "Stylus Photo 815",
    "E203" : "Stylus Photo 915",
    "E204" : "PX-V700",
    "E205" : "Stylus C82 Seriese",
    "E206" : "PX-10000",
    "E207" : "Stylus Pro10600UC/CF/DYE",
    "E208" : "PM-930C",
    "E210" : "PM-970C",
    "E212" : "PM-870C",
    "E213" : "Stylus Photo 900",
    "E214" : "PM-860PT",
    "E215" : "NANAO USA Corporation F750i",
    "E215" : "NANAO USA Corporation F750i",
    "E216" : "CC-600PX",
    "E217" : "Stylys CX5100 5200",
    "E218" : "CC-570L",
    "E219" : "Stylus CX3100 3200",
    "E21C" : "FX DocuCentre C7550 I PCL 6",
    "E21F" : "Microvitec, Inc. 2014/LP",
    "E222" : "PM-3700C",
    "E229" : "Stylus Photo 960",
    "E231" : "Stylus Photo 2200",
    "E232" : "PX-6000",
    "E233" : "Stylus Pro 4000",
    "E234" : "PM-740DU",
    "E235" : "Stylus Photo 830U",
    "E239" : "Stylus C43 C44 Series",
    "E241" : "Stylus C63 C64 Series",
    "E242" : "PX-V600",
    "E243" : "Stylus C83 C84 Series",
    "E244" : "PM-980C",
    "E246" : "PM-940C",
    "E253" : "Stylus CX5300 CX5400",
    "E254" : "PM-G700",
    "E256" : "PX-G900",
    "E257" : "Stylus Photo R800",
    "E258" : "PM-G800",
    "E260" : "PM-D750",
    "E261" : "Microvitec, Inc. 1020/SP",
    "E261" : "Microvitec, Inc. 1020/SP",
    "E263" : "Stylus Photo R300 Series",
    "E265" : "Stylus Photo RX500 RX510",
    "E267" : "Stylus Photo RX500",
    "E269" : "Stylus CX6300 CX6400",
    "E270" : "PM-A850",
    "E273" : "Stylus Photo RX600",
    "E274" : "PM-D1000",
    "E277" : "Stylus C85 C86 Series",
    "E279" : "Stylus C65 C66 Series",
    "E27D" : "FX DocuPrint C5450",
    "E281" : "Stylus C45 C46 Series",
    "E283" : "Stylus CX4500 CX4600 Series",
    "E284" : "PX-A550",
    "E285" : "Stylus CX3500 CX3600 Series",
    "E287" : "Stylus CX1500 Series",
    "E289" : "Stylus CX6500 CX6600 Series",
    "E28F" : "Star LaserPrint 8 LincPage",
    "E290" : "PM-A700",
    "E291" : "Stylus Photo RX420 RX430 Series",
    "E292" : "PM-G720",
    "E294" : "PM-D770",
    "E295" : "Stylus Photo R320 Series",
    "E296" : "PM-A870",
    "E2C2" : "Okidata OL-830",
    "E2C4" : "Okidata OL840 PostScript",
    "E2D2" : "Canon Bubble-Jet BJ-10ex",
    "E2F6" : "Oki OL-870",
    "E300" : "PX-G920",
    "E302" : "PM-G820",
    "E304" : "PM-A900",
    "E308" : "Okidata ML 520-IBM",
    "E309" : "ME1",
    "E311" : "ME 100",
    "E312" : "PX-6500",
    "E313" : "Stylus Pro 4800",
    "E314" : "PX-6200S",
    "E315" : "Stylus Pro 4400",
    "E316" : "PX-7500",
    "E317" : "Stylus Pro 7800",
    "E318" : "PX-7500S",
    "E319" : "Stylus Pro 7400",
    "E320" : "PX-9500",
    "E321" : "Stylus Pro 9800",
    "E322" : "PX-9500S",
    "E323" : "Stylus Pro 9400",
    "E324" : "PX-5500",
    "E325" : "Stylus Photo R2400",
    "E336" : "PM-A750",
    "E337" : "Stylus Photo RX520 RX530 Series",
    "E340" : "PM-D600",
    "E341" : "Stylus Photo R240 R250 Series",
    "E342" : "PM-G730",
    "E343" : "Stylus Photo R220 R230 Series",
    "E345" : "Stylus Photo R220 Series",
    "E346" : "PM-D800",
    "E347" : "Stylus Photo R340 R350 Series",
    "E349" : "Stylus Photo R340 Series",
    "E350" : "PM-A890",
    "E354" : "PM-A950",
    "E356" : "PX-G930",
    "E358" : "PX-G5100",
    "E360" : "PX-5800",
    "E361" : "Stylus Pro 3800",
    "E36E" : "Okidata ML 320-IBM",
    "E37B" : "NEC Pinwriter P7",
    "E380" : "Seiko ColorPoint PS",
    "E397" : "Talon Tuff/CRT",
    "E3A1" : "FX Document Centre C240 Scan",
    "E3BE" : "Kyocera FS-5800C",
    "E3E4" : "HP DeskJet 500C Printer",
    "E3FE" : "Fora, Inc. MON-7C5",
    "E426" : "Epson APL-1000",
    "E452" : "IBM 4039 LaserPrinter Plus",
    "E460" : "Epson LQ-100 ES/P 2",
    "E470" : "Panasonic KX-P1624",
    "E486" : "FX ApeosPort-III C4405 Scan",
    "E48B" : "Olivetti DM 124 L",
    "E4A8" : "Bull Compuprint PageMaster 825",
    "E4B7" : "Star XB-2415",
    "E4CF" : "Olivetti DM 224 L",
    "E500" : "LP-8000C",
    "E501" : "LP-501CR",
    "E501" : "LP-501CR",
    "E502" : "LP-8200C",
    "E503" : "EPLs",
    "E511" : "Ikegami CN-20",
    "e58a" : "RICOH IPSiO CX2500, RICOH Aficio CL1000N",
    "E5E1" : "FX DocuCentre-II C6500",
    "E6A7" : "Epson EPL-5000",
    "E745" : "Epson EPL-5600",
    "E777" : "Star XB-2410",
    "E782" : "Panasonic KX-P1123",
    "E86C" : "FX DocuCentre-III C2205 Scan",
    "E883" : "Compaq PageMarq 20",
    "E8AA" : "Fujitsu DL 3450",
    "E8AF" : "Nissei Sangyo CM2085M",
    "E8CE" : "Seiko ColorPoint2 PSF",
    "E959" : "Microvitec, Inc. 704/FST",
    "E980" : "FX DocuCentre-II C3300",
    "E9CE" : "Mannesmann Tally MT 92",
    "E9D6" : "WYSE Technology WY-670",
    "E9DA" : "Ikegami C/CDE-165VB",
    "EA03" : "Tandy LP-1000",
    "EA09" : "Mannesmann Tally MT 131/9",
    "EA1B" : "Epson SQ-2000",
    "EA2E" : "FX ApeosPort-III C2201 Scan",
    "EA50" : "Okidata OL-400e",
    "EA51" : "Panasonic KX-P4420",
    "EA59" : "Tektronix Phaser 740 Extended",
    "EAA9" : "FX DocuCentre-III C3300",
    "EAAF" : "REDMS Group, Inc. SRC-1401",
    "EAC6" : "AST TurboLaser-PS",
    "EADB" : "Tektronix Phaser 200e 17(4)",
    "EB0B" : "Epson SQ-2500",
    "EB28" : "Hitachi America, Ltd. 20-APF",
    "EBB9" : "FX ApeosPort-II C7500 Scan",
    "EBEF" : "REDMS Group, Inc. SRC-1402",
    "EC00" : "Star NX-2420",
    "EC08" : "Oki ML 192 Elite (Microline)",
    "EC62" : "Canon Bubble-Jet BJ-300",
    "EC7D" : "IBM 4029 LaserPrinter",
    "EC81" : "NEC MultiSync 5D",
    "EC89" : "AOC CM-324",
    "ECB3" : "Olivetti DM 324 S",
    "ECBC" : "IBM 4039 LaserPrinter",
    "ECC3" : "Brother M-1909",
    "ED4F" : "Philips 7BM749",
    "ED64" : "Digital DEClaser 2150 plus",
    "EE25" : "IBM Personal Printer II 2390",
    "EE88" : "Leading Technology, Inc. 1730S",
    "EEE0" : "HP LaserJet IID PS Cartridge",
    "EEE1" : "Brother M-1309",
    "EEEC" : "FX DocuCentre C2100 Scan",
    "EEEO" : "EPSON_Printer54",
    "EEF1" : "CWC M33201CCII",
    "EEFD" : "Oki OL-400ex",
    "EF1D" : "Epson FX-286e",
    "EF37" : "HP DraftMaster II",
    "EF88" : "Citizen 200GX/15",
    "EFD2" : "FX ApeosPort-II C6500 PS",
    "ES00" : "GT-7000",
    "ES01" : "GT-7000 TPU",
    "ES02" : "GT-2200",
    "ES03" : "GT-9600",
    "ES04" : "GT-9600 TPU",
    "ES05" : "ES-6000 / GT-10000",
    "ES06" : "GT-6600",
    "ES07" : "GT-7600",
    "ES08" : "GT-7600 TPU",
    "ES09" : "EPSON_Scanner9",
    "ES0A" : "Stylus Scan 2500",
    "ES0B" : "Stylus Scan 2500 TPU",
    "ES0C" : "Stylus Scan 2000",
    "ES0D" : "ES-2000 / Expression 1600",
    "ES0E" : "ES-2000 TPU / Expression 1600 TPU",
    "ES0F" : "ES-8500 / Expression 1640XL",
    "ES10" : "ES-8500 TPU / Expression 1640XL TPU",
    "ES11" : "CC-700",
    "ES12" : "CC-700 TPU",
    "ES15" : "GT-6700 / Perfection 640",
    "ES16" : "GT-8700 / Perfection 1640",
    "ES17" : "GT-8700 TPU / Perfection 1640 TPU",
    "ES18" : "GT-7700 / Perfection 1240",
    "ES19" : "GT-7700 TPU / Perfection 1240 TPU",
    "ES1A" : "ES-9000H / GT-30000",
    "ES1B" : "ES-2200 / Expression 1680",
    "ES1C" : "ES-2200 TPU / Expression 1680 TPU",
    "ES1D" : "GT-7200 / Perfection1250",
    "ES1E" : "GT-7200 TPU / Perfection1250 TPU",
    "ES1F" : "GT-8200 / Perfection 1650",
    "ES20" : "GT-8200 TPU / Perfection 1650 TPU",
    "ES21" : "GT-9700 / Perfection 2450",
    "ES22" : "GT-9700 TPU / Perfection 2450 TPU",
    "ES23" : "GT-7300 / Perfection 1260",
    "ES24" : "GT-7300 TPU / Perfection 1260 TPU",
    "ES25" : "GT-8300 / Perfection 1660",
    "ES26" : "GT-8300 TPU / Perfection 1660 TPU",
    "ES27" : "GT-9300 / Perfection 2400",
    "ES28" : "GT-9300 TPU / Perfection 2400 TPU",
    "ES29" : "GT-9800 / Perfection 3200",
    "ES2A" : "GT-9800 TPU / Perfection 3200 TPU",
    "ES2B" : "ES-7000 / GT-15000",
    "ES2C" : "CC-550L / StylusScan 2800 / 1000ICS",
    "ES2D" : "CC-600PX / Stylus CX5200 / Stylus CX5100",
    "ES2E" : "CC-570L / Stylus CX3200 / Stylus CX3100",
    "ES30" : "GT-8400 / Perfection 1670",
    "ES31" : "GT-8400 TPU / Perfection 1670 TPU",
    "ES32" : "GT-9400 / Perfection 3170",
    "ES33" : "GT-9400 TPU / Perfection 3170 TPU",
    "ES34" : "GT-X700 / Perfection 4870",
    "ES35" : "GT-X700 TPU / Perfection 4870 TPU",
    "ES36" : "Stylus CX5400 / Stylus CX5300",
    "ES37" : "Stylus CX6400 / Stylus CX6300",
    "ES38" : "Stylus Photo RX500 TPU / Stylus Photo RX510 TPU",
    "ES39" : "Stylus Photo RX500 TPU / Stylus Photo RX510 TPU",
    "ES3A" : "Stylus Photo RX600 / Stylus Photo RX610",
    "ES3B" : "Stylus Photo RX600 TPU / Stylus Photo RX610 TPU",
    "ES3C" : "F-3200",
    "ES3D" : "F-3200 TPU",
    "ES3E" : "GT-7400 / Perfection 1270",
    "ES3F" : "ES-10000G / Expression 10000XL",
    "ES40" : "ES-10000G TPU / Expression 10000XL TPU",
    "ES41" : "GT-F500/F550 / Perfection2480/2580 ",
    "ES42" : "GT-F500/F550 TPU / Perfection2480/2580 TPU",
    "ES43" : "GT-F600 / Perfection4180",
    "ES44" : "GT-F600 TPU / Perfection4180 TPU",
    "ES46" : "Stylus CX4600 / Stylus CX4500",
    "ES47" : "Stylus CX3500 / Stylus CX3600",
    "ES48" : "Stylus Photo RX420 / Stylus Photo RX430",
    "ES49" : "Stylus CX6500 / Stylus CX6600",
    "ES4A" : "PM-A700",
    "ES4B" : "Stylus Photo RX620 / Stylus Photo RX630",
    "ES4C" : "PM-A870 TPU / Stylus Photo RX620 TPU / Stylus Photo RX630 TPU",
    "ES4D" : "PM-A900 / Stylus Photo RX700",
    "ES4E" : "PM-A900 TPU / Stylus Photo RX700 TPU",
    "ES4F" : "GT-X800 / Perfection 4990",
    "ES50" : "GT-X800 TPU/ Perfection 4990 TPU",
    "ES51" : "LP-A500 / AL-CX11",
    "ES52" : "GT-F520 ref / Perfection3490 ref",
    "ES53" : "GT-F520 film/Perfection3490 film",
    "ES54" : "GT-X750 ref / Perfection4490 ref",
    "ES55" : "GT-X750 film / Perfection4490 film",
    "ES56" : "LP-M5500 ref",
    "ES57" : "Stylus CX3700 ref",
    "ES58" : "PX-A650 ref / Stylus CX4700 ref",
    "ES59" : "Stylus CX4100 ref",
    "ES5A" : "Stylus CX5700F ref",
    "ES5B" : "Stylus CX7700 ref",
    "ES5C" : "Stylus CX7700 film",
    "ES5D" : "PM-A750 ref / Stylus Photo RX530 ref",
    "ES5E" : "PM-A750 film / Stylus Photo RX530 film",
    "ES5F" : "PM-A890 ref / Stylus Photo RX650 ref",
    "ES60" : "PM-A890 film / Stylus Photo RX650 film",
    "ES61" : "PM-A950 ref",
    "ES62" : "PM-A950 film",
    "ES63" : "GT-X900 ref / Perfection V700 ref",
    "ES64" : "GT-X900 film / Perfection V700 film",
    "ES65" : "ES-H300 ref / GT-2500 ref",
    "ES66" : "GT-F650 ref / Perfection V100 ref",
    "ES67" : "GT-F650 film / Perfection V100 film",
    "ES68" : "GT-F700 ref / Perfection V350 ref",
    "ES69" : "GT-F700 film / Perfection V350 film",
    "ES6A" : "Stylus CX2900 ref",
    "ES6B" : "PX-A620 ref / Stylus CX3900 ref",
    "ES6C" : "PX-A720 ref / Stylus CX5900 ref",
    "ES6E" : "Stylus CX6900F ref",
    "ES70" : "PM-A820 ref / Stylus Photo RX590 ref",
    "ES71" : "PM-A920 ref",
    "ES72" : "PM-A920 film",
    "ES73" : "PM-A970 ref",
    "ES74" : "PM-A970 film",
    "ES75" : "PM-T990 ref",
    "ES76" : "PM-T990 film",
    "ES77" : "Stylus CX4900 ref",
    "ES78" : "LP-M5600 ref",
    "ES79" : "AL-CX21 ref",
    "ES7A" : "GT-F670 ref / Perfection V200 ref",
    "ES7B" : "GT-F670 film / Perfection V200 film",
    "ES7C" : "GT-X770 ref / Perfection V500 ref",
    "ES7D" : "GT-X770 film / Perfection V500 film",
    "ES7E" : "Stylus CX4400 ref",
    "ES7F" : "PX-A640 ref / Stylus CX7300 ref",
    "ES80" : "PX-A740 ref / Stylus CX8300 ref",
    "ES81" : "PX-FA700 ref / Stylus CX9300F ref",
    "ES82" : "PM-T960 ref",
    "ES83" : "PM-T960 film",
    "ES84" : "PM-A940 ref / Stylus Photo RX690 ref",
    "ES85" : "PM-A840 ref / Stylus Photo RX610 ref",
    "ES86" : "GT-D1000 ref / GT-1500 ref",
    "ES87" : "GT-X970 ref",
    "ES88" : "GT-X970 film",
    "ES89" : "LP-M6000 ref",
    "ES8A" : "ES-H7200 ref / GT-20000 ref",
    "ES8B" : "GT-F720 ref / Perfection V300 ref",
    "ES8C" : "GT-F720 film / Perfection V300 film",
    "ES8D" : "Stylus NX200 ref",
    "ES8E" : "PX-501A ref / Stylus NX400 ref",
    "ES8F" : "Stylus Office BX300F ref / Stylus NX300 ref",
    "ES90" : "PX-601F ref / WorkForce 600 ref / Stylus SX600FW ref",
    "ES91" : "EP-901A ref / Artisan 800 ref",
    "ES92" : "EP-801A ref / Artisan 700 ref",
    "ES93" : "PX-401A ref / Stylus SX100 ref / Stylus NX100 ref",
    "ES96" : "WorkForce 500 ref",
    "ES97" : "LP-M5000 ref",
    "ES98" : "Epson Stylus NX410 ref",
    "ES99" : "PX-402A ref / Epson Stylus NX110 ref / Epson Stylus SX110 ref",
    "ES9A" : "Epson Stylus NX210 ref / Epson Stylus SX210 ref",
    "ES9B" : "WorkForce 310 ref / Epson Stylus Office BX310FN ref",
    "ES9C" : "PX-502A ref / Epson Stylus NX510 ref",
    "ES9D" : "PX-602F ref / WorkForce 610 ref / Epson Stylus Office BX610FW ref",
    "ES9E" : "EP-702A ref / Epson Stylus Photo PX650 ref",
    "ES9F" : "EP-902A ref / Artisan 810 ref",
    "ESA0" : "EP-802A ref / Artisan 710 ref",
    "ESA1" : "GT-X820 ref",
    "ESA2" : "GT-X820 film",
    "F001" : "L685",
    "F008" : "Fujitsu DL 5600",
    "F033" : "Citizen HSP-550",
    "F069" : "Citizen GSX-190",
    "F078" : "NEC SuperScript 4650N",
    "F10A" : "MultiPASS F10",
    "F110" : "",
    "F11A" : "MP110",
    "F13A" : "MP130",
    "F15A" : "MP150",
    "F15G" : "MF-8615G",
    "F17A" : "MP170",
    "F17E" : "MF-8617E",
    "F1D1" : "Iiyama MF-5215A",
    "f1e0" : "RICOH IPSiO Color 8000/8100/8150, RICOH Aficio AP3800c/CL6000",
    "F20A" : "MultiPASS F20",
    "F21E" : "MF-8621E",
    "F220" : "",
    "F23C" : "NEC MultiSync 4FG",
    "F242" : "FX ApeosPort-III C3305 Scan",
    "F25C" : "NEC Silentwriter2 290",
    "F2E1" : "Citizen GSX-140+",
    "F30A" : "MultiPASS F30",
    "F330" : "",
    "F33A" : "MP330",
    "F369" : "Star LaserPrinter 8",
    "F36A" : "MP360",
    "F375" : "Epson SQ-1170 ESC/P 2",
    "F37A" : "MP370",
    "F37B" : "MP375R",
    "F39A" : "MP390",
    "F3B0" : "Epson DFX-8000",
    "F3BA" : "Lite-On, Inc. CM-2090M",
    "F3F0" : "Mitsubishi FA-3425",
    "F408" : "Brother M-1924L",
    "F41A" : "MP410",
    "F43A" : "MP430",
    "F43D" : "Sampo AlphaScan 15",
    "F440" : "",
    "F446" : "FX ApeosPort-II 6000K Scan",
    "F45A" : "MP450",
    "F4E4" : "Epson LQ-500",
    "F50B" : "MultiPASS F50",
    "F50C" : "MP500",
    "F529" : "FX ApeosPort 650 I Scan",
    "F53A" : "Apple LaserWriter Plus",
    "F53B" : "MP530",
    "F550" : "",
    "F55B" : "MultiPASS C555",
    "F573" : "IBM Personal Page Printer II-31",
    "F5E4" : "FX ApeosPort C2521 I PS",
    "F5EC" : "Epson Compatible 24 Pin",
    "F5F2" : "Oki ML 590C Elite",
    "F600" : "",
    "F60A" : "MultiPASS F60",
    "F62B" : "Sharp JX-9660",
    "F65F" : "Epson FX-1000",
    "F65F" : "Epson FX-1000",
    "F660" : "",
    "F669" : "Star LaserPrinter 4",
    "F66C" : "Epson EX-1000",
    "F674" : "HP DeskJet 550C Printer",
    "F683" : "Digital LA324",
    "F693" : "Tektronix Phaser 780 Plus",
    "F70A" : "MP700",
    "F71A" : "MP710",
    "F72A" : "Digital DEClaser 5100",
    "F73A" : "MP730",
    "F74A" : "MP740",
    "F75A" : "MultiPASS C755",
    "F75B" : "MP750",
    "F76A" : "MP760",
    "F770" : "",
    "F77A" : "MP770",
    "F78A" : "MP780",
    "F79A" : "MP790",
    "F7A1" : "NEC Pinwriter P30",
    "F7B4" : "FUJI XEROX SCANNER1",
    "F80A" : "MultiPASS F80",
    "F80B" : "MP800",
    "F80C" : "MP800R",
    "f821" : "RICOH imagio Neo C325/C385",
    "F83A" : "MP830",
    "F842" : "FX ApeosPort-III 5000 Scan",
    "F85A" : "MultiPASS C855",
    "F880" : "",
    "F8B3" : "TI microLaser PS17",
    "F8B7" : "Star LC-20",
    "F8D4" : "FX ApeosPort C7550 I Scan",
    "F90A" : "MP900",
    "F937" : "HP LaserJet III PostScript+",
    "F94B" : "Conrac 7250",
    "F956" : "Epson LQ-860+",
    "F95A" : "MP950",
    "F988" : "Conrac 7211",
    "F990" : "",
    "F9A6" : "Epson LQ-850+",
    "F9CC" : "HP 7470A",
    "F9DB" : "Conrac 7351",
    "FA48" : "Conrac 7214",
    "FA55" : "FX DocuCentre Color 160 PS",
    "FAB5" : "FX DocuCentre-III 5000 Scan",
    "FAE1" : "NEC Silentwriter LC 860 Plus",
    "FAF4" : "HP LaserJet IIP PS Cartridge",
    "FB2A" : "Epson LQ-1170 ESC/P 2",
    "FB43" : "FX DocuCentre-II C6500 Scan",
    "FB57" : "FX Xerox DocuColor 2240 PS",
    "FB6C" : "FX DocuPrint C3140",
    "FB96" : "PM-5000C",
    "FBA6" : "Relisys RM-1541",
    "FBFE" : "Citizen PROjet II (Color)",
    "FC10" : "Oki OL-400e",
    "FC13" : "CTX International, Inc. CPS-1750",
    "FC27" : "Triumph Adler SDR 7706",
    "fc38" : "Ricoh Aficio CL7000",
    "FC4B" : "Epson RX-100+",
    "FC51" : "Mannesmann Tally T7040",
    "FCD4" : "ADI Microscan 3E SM-5514A",
    "FCE3" : "Compeq CT-1458",
    "FD1F" : "Epson FX-100+",
    "FDA4" : "Epson APT-1000",
    "FDBE" : "IBM Proprinter",
    "FDFB" : "Apple LaserWriter Personal NT",
    "FE0F" : "ViewSonic 4E",
    "FE9B" : "Star LC24-300",
    "FEB1" : "Okidata ML 320",
    "FEE9" : "Kyocera FS-3500/FS-3500A",
    "FEF9" : "Mannesmann Tally MT 290",
    "FF35" : "FX DocuCentre Color 240",
    "FF4B" : "Color Laser Printer XL-C3000",
    "FF51" : "Okidata ML 520",
    "FF52" : "Oki ML 393C Elite",
    "FF76" : "Falco Data Products, Inc. FMS",
    "FF7F" : "FX DocuCentre C2101",
    "FF90" : "FX DocuColor 1250 PLW E",
    "FFF4" : "Epson LQ-1010",
    "FNA6" : "MP810 Nega",
    "FNA7" : "MP960 Nega",
    "FNAE" : "MP970 Nega",
    "FP25" : "FP-2500 25inch SXGA(1280x1024) PDP display",
    "FP42" : "FP-4200 42inch  XGA(1024x 768) PDP display",
    "FPA6" : "MP810 Posi",
    "FPA7" : "MP960 Posi",
    "FPAE" : "MP970 Posi",
    "FPD" : "Flat Panel Display",
    "FRA0" : "MP160 Ref.",
    "FRA1" : "MP180 Ref.",
    "FRA2" : "MP460 Ref.",
    "FRA3" : "MP510 Ref.",
    "FRA4" : "MP600 Ref.",
    "FRA5" : "MP600R Ref.",
    "FRA6" : "MP810 Ref.",
    "FRA7" : "MP960 Ref.",
    "FRA8" : "MP140 Ref.",
    "FRA9" : "MP210 Ref.",
    "FRAA" : "MP220 Ref.",
    "FRAB" : "MP470 Ref.",
    "FRAC" : "MP520 Ref.",
    "FRAD" : "MP610 Ref.",
    "FRAE" : "MP970 Ref.",
    "FRAF" : "MX300 Ref.",
    "FRAG" : "MX310 Ref.",
    "FRAH" : "MX700 Ref.",
    "FUJI" : "CLW 3320PS",
    "FX00" : "700 Digital Color Press icpm",
    "FX01" : "FX DocuColor 1257 PSPX30E",
    "FX02" : "DocuColor 5151 P",
    "FX03" : "DocuColor 5000 Digital Press",
    "FX04" : "DocuColor 8000AP Digital Press",
    "FX05" : "DocuColor 1256 GA",
    "FX06" : "DocuColor 1257 GA",
    "FX07" : "Color Press 1000",
    "FX08" : "DocuColor 1450 GA",
    "fx0A" : "WorkCentre 7125 Scan",
    "fx0B" : "ApeosPort-IV 7080 Scan",
    "fx0C" : "ApeosPort-IV 6080 Scan",
    "fx0D" : "ApeosPort-IV 5080 Scan",
    "fx0E" : "DocuCentre-IV 7080 Scan",
    "fx0F" : "DocuCentre-IV 6080 Scan",
    "fx0G" : "DocuCentre-IV 5080 Scan",
    "fx0H" : "DocuCentre-IV 3070 Scan",
    "fx0I" : "DocuCentre-IV C2265 Scan",
    "fx0J" : "DocuCentre-IV C2263 Scan",
    "fx0K" : "ApeosPort-IV C5575 Scan",
    "fx0L" : "ApeosPort-IV C4475 Scan",
    "fx0M" : "ApeosPort-IV C3375 Scan",
    "fx0m" : "DocuCentre-IV 3060 Scan",
    "fx0N" : "ApeosPort-IV C3373 Scan",
    "fx0n" : "DocuCentre-IV 2060 Scan",
    "fx0O" : "ApeosPort-IV C2275 Scan",
    "fx0o" : "DocuCentre-IV 3065 Scan",
    "fx0P" : "DocuCentre-IV C5575 Scan",
    "fx0p" : "ApeosPort-IV 5070 Scan",
    "fx0Q" : "DocuCentre-IV C4475 Scan",
    "fx0q" : "ApeosPort-IV 4070 Scan",
    "fx0R" : "DocuCentre-IV C3375 Scan",
    "fx0r" : "ApeosPort-IV 3070 Scan",
    "fx0S" : "DocuCentre-IV C3373 Scan",
    "fx0s" : "DocuCentre-IV 5070 Scan",
    "fx0T" : "DocuCentre-IV C2275 Scan",
    "fx0t" : "DocuCentre-IV 4070 Scan",
    "fx0z" : "Xerox D95 Copier/Printer Scan",
    "G657" : "Roland PC-60",
    "G659" : "Roland Printer_1",
    "G660" : "Roland FJ-50",
    "G663" : "Roland Printer_2",
    "G680" : "Roland CJ-500",
    "GE50" : "CASIO SPEEDIA GE5000",
    "H10" : "H10 digital camera",
    "H20" : "H20 digital camera",
    "h20i" : "Hopper 20 impact",
    "H5" : "H 5 digital camera",
    "HARL" : "Harlequin RIP",
    "HD00" : "Vacant",
    "HD99" : "Vacant",
    "IDT1" : "Idanit Printer 1",
    "IDT2" : "Idanit Printer 2",
    "IDT3" : "Idanit Printer 3",
    "IDT4" : "",
    "IDT4" : "Idanit Printer 4",
    "IDT5" : "Idanit Printer 5",
    "IJ11" : "Inkjet 2011",
    "IRa1" : "Iris Printer",
    "IRa2" : "Iris Printer",
    "IRa3" : "Iris Printer",
    "IRa4" : "Iris Printer",
    "IRf1" : "Iris Printer",
    "IRf2" : "Iris Printer",
    "IRf3" : "Iris Printer",
    "IRf4" : "Iris Printer",
    "IRf5" : "Iris Printer",
    "IRp1" : "Iris Printer",
    "IRp2" : "Iris Printer",
    "IRp3" : "Iris Printer",
    "IRp4" : "Iris Printer",
    "ISDS" : "IS22xDC",
    "J03A" : "MFC-3820CN",
    "J04A" : "MFC-840CLN",
    "J06A" : "MFC-440CN",
    "J09A" : "MFC-J6710DW",
    "J11A" : "MFC-J825DW",
    "J12A" : "DCP-J140W",
    "J12I" : "MFC-J4510DW",
    "JAWS" : "Jaws RIP",
    "KPDM" : "Kodak Professional Digital Multi-Printer",
    "KPG0" : "OEM printer (PTSTM2856A FirstCheck)",
    "KTa1" : "Karat Printer 1",
    "KTa2" : "Karat Printer 2",
    "KTa3" : "Karat Printer 3",
    "KTa4" : "Karat Printer 4",
    "KTa5" : "Karat Printer 5",
    "L000" : "Standard LCD",
    "L05A" : "MFC-9420CN",
    "L080" : "",
    "L10A" : "HL-4140CN",
    "L110" : "LBP-2030",
    "L12A" : "HL-3170CDW",
    "L15A" : "DT3157",
    "L19A" : "DT3191",
    "L250" : "HP Color LaserJet 2500",
    "L367" : "L367",
    "L460" : "HP Color LaserJet 4600",
    "L500" : "",
    "L550" : "HP Color LaserJet 5500",
    "L567" : "L567",
    "L767" : "L767",
    "L885" : "L885",
    "L985" : "L985EX, R21",
    "LCRT" : "Kodak Professional Large Format CRT Printer",
    "LD11" : "Inkjet 2011",
    "LED1" : "Kodak Professional Digital LED printer Gen1",
    "LED2" : "Kodak Professional Digital LED Printer Gen2",
    "LINK" : "Link-o-lator",
    "LP01" : "SONY LPR-5000",
    "LP02" : "LPR-E5000",
    "LS83" : "14 inch XGA STN LCD",
    "LT83" : "14 inch XGA TFT LCD",
    "LT84" : "15 inch XGA TFT LCD",
    "LT94" : "FUJITSU LCD VL-17WDX1G",
    "LT96" : "16 inch SXGA TFT LCD",
    "LT97" : "21 inch SXGA TFT LCD",
    "LVT0" : "Light Valve Technology Printer",
    "M500" : "BJC-5000",
    "M501" : "BJC-5000",
    "M502" : "BJC-5000",
    "MC01" : "NEC PC-KM141 (MultiSync14)",
    "MC02" : "NEC PC-KM153R (MultiSync15)",
    "MC03" : "NEC PC-KM173 (MultiSync17)",
    "MC04" : "NEC PC-KM154 (MultiSync15Pro)",
    "MC05" : "NEC PC-KM174 (MultiSync17Pro)",
    "MC06" : "NEC PC-KM212 (MulitSync17Pro)",
    "MC07" : "NEC PC-TM151",
    "MC08" : "NEC PC-KM291",
    "MC09" : "NEC PC-KM371",
    "MC0A" : "NEC PC-KM151",
    "MC0B" : "NEC PC-KM152 (same as KM151)",
    "MC0C" : "NEC PC-KM153 (same as KM151)",
    "MC0D" : "NEC PC-KM171",
    "MC0E" : "NEC PC-KM172",
    "MC0F" : "NEC PC-KM211",
    "MC10" : "NEC PC-TD151",
    "MC11" : "NEC PC-TD211",
    "MC12" : "NEC PC-9821 (same as KD1522) (N)",
    "MC13" : "NEC PC-9821 Ce (same as KD1522) (N)",
    "MC14" : "NEC PC-9821 Ce2 (same as KD1522) (N,T)",
    "MC15" : "NEC PC/T2 (same as TD151)",
    "MC16" : "NEC PC-9821Cs2",
    "MC17" : "NEC PC-9821 Cb (98MULTiCanBe)",
    "MC18" : "NEC PC-9821 Cx/Cf (98MULTiCanBe)",
    "MC19" : "NEC PC-9821Cb2 (98MULTiCanBe)",
    "MC1A" : "NEC PC-9821 Cx2/S15 (98MULTiCanBe)",
    "MC1B" : "NEC PC-9821 Cx2/S17 (98MULTiCanBe)",
    "MC1C" : "NEC PC/S15 (98MATE)",
    "MC1D" : "NEC PC/S15 (98MATE)",
    "MC1E" : "NEC PC/S17 (98MATE)",
    "MC1F" : "NEC PC-KM153R2 (MultiSync15 II)",
    "MC20" : "NEC PC-KM173R (MultiSync17 II)",
    "MC21" : "NEC PC-9821 Cb3/T (98MULTiCanBe)",
    "MC22" : "NEC PC-9821 Cx3/S5T (98MULTiCanBe)",
    "MC23" : "NEC PC-9821Cx3/S7M (98MULTiCanBe)",
    "MC24" : "NEC PC-9821V7/C4K (98MATEValueStar)",
    "MC25" : "NEC PC-9821V7/S5K (98MATEValueStar)",
    "MC26" : "NEC PC-9821V7/S7K (98MATEValueStar)",
    "MC27" : "NEC PC-9821V10/S5K (98MATEValueStar)",
    "MC28" : "NEC PC-9821V10/S7K (98MATEValueStar)",
    "MC29" : "NEC PC/T (98MULTiCanBe)",
    "MC2A" : "NEC PC/S5T (98MULTiCanBe)",
    "MC2B" : "NEC PC/S7M (98MULTiCanBe)",
    "MC2C" : "NEC PC-9821V10/C4R (98MATEValueStar)",
    "MC2D" : "NEC PC-9821V12/S5R (98MATEValueStar)",
    "MC2E" : "NEC PC-9821V12/S7R (98MATEValueStar)",
    "MC2F" : "NEC PC-9821V13/S5R (98MATEValueStar)",
    "MC30" : "NEC PC-9821V13/S7R (98MATEValueStar)",
    "MC31" : "NEC PC/D (98MULTiCanBe)",
    "MC32" : "NEC PC/F (98MULTiCanBe)",
    "MC33" : "NEC PC-KM155 (MultiSync15AV)",
    "MC34" : "NEC PC-KM173R2 (MultiSync17VL)",
    "MC35" : "NEC PC-KM174 (MultiSync17AV)",
    "MC36" : "NEC PC-TM171",
    "MC37" : "NEC PC-9821V13/M7 (TR63H)",
    "MC38" : "NEC PC-9821V20/M7 (TR67H)",
    "MC39" : "NEC PC/M7 (MR63H)",
    "MC3A" : "NEC PC-9821V13/S5 (TR63W)",
    "MC3B" : "NEC PC-9821V16/S5 (TR65W)",
    "MC3C" : "NEC PC/S5 (MR63W)",
    "MC3D" : "NEC PC-KM174R (MultiSync 17Pro II)",
    "MC3E" : "NEC JC-1574VM (MulitSync X500)",
    "MC3F" : "NEC JC-1746UM (MultiSync X750)",
    "MC40" : "NEC JC-2145UM (MultiSync P2150)",
    "MC41" : "NEC DV17C2",
    "MC42" : "NEC DV17C1",
    "MC43" : "NEC DV17A1",
    "MC44" : "NEC DV17B1",
    "MC45" : "NEC DV15A1",
    "MC46" : "NEC JC-1736VM (MultiSyncX700)",
    "MC47" : "NEC DV15D1",
    "MC48" : "NEC PK-DH28W2",
    "MC49" : "NEC PK-DH32W2",
    "MC4A" : "NEC PK-DH172",
    "MC4B" : "NEC DV15A2",
    "MC4C" : "NEC DV17B2",
    "MC4D" : "NEC DV17C3",
    "MC4E" : "NEC JC-1578VM (MultiSync X510)",
    "MC4F" : "NEC JC-2148UMW (MultiSync P1250+)",
    "MC50" : "NEC DV17C4",
    "MC51" : "NEC DV17D1",
    "MC52" : "NEC DV15A3",
    "MC53" : "NEC DV17D2",
    "MC54" : "NEC FE90 (MultiSync FE90)",
    "MC55" : "NEC DV15A4",
    "MC56" : "NEC DV17A2",
    "MC57" : "NEC FE91 (MultiSyncFE91)",
    "MC58" : "NEC DV15B1",
    "MC59" : "NEC DV15B2",
    "MC5A" : "NEC DV17D3",
    "MC5B" : "NEC DV17D4",
    "MC5C" : "NEC HR17 (HR17 MultiSync)",
    "MC5D" : "NEC HR19 (HR19 MultiSync)",
    "MC5E" : "NEC DV15A5",
    "MC5F" : "NEC DV17D5",
    "MC60" : "NEC DV17D6",
    "MC61" : "NEC DV17H1",
    "MC62" : "NEC FE991SB",
    "MC63" : "NEC F15T7A",
    "MD1A" : "MD-2000",
    "MD1B" : "MD-2010",
    "MD1C" : "MD-2300",
    "MD1D" : "MD-4000",
    "MD1E" : "MD-1000",
    "MD1F" : "MD-1300",
    "MD1G" : "MD-1500",
    "MD1H" : "MD-5000",
    "MD1I" : "MD-5000P",
    "MD1J" : "MD-5500 printer",
    "MD1K" : "MD-5500P printer",
    "MD1L" : "MDP-10 printer",
    "MD1M" : "MDP-10P",
    "MD2A" : "MD Printer PostScript",
    "MD2B" : "MD2010 PS",
    "MD2C" : "MD2300 PS",
    "MD2D" : "MD4000 PS",
    "MD2E" : "MD1000 PS",
    "MD2F" : "MD1300 PS",
    "MD2G" : "MD1500 PS",
    "ML01" : "NEC PC-KP511 Display LCD",
    "ML02" : "NEC PC-KP651 (MulitSyncLCD12)",
    "ML03" : "NEC F14T1",
    "ML04" : "NEC LA-1423JM (MultiSyncLCD400V)",
    "ML05" : "NEC F14T2",
    "ML06" : "NEC PK-DH142",
    "ML07" : "NEC F15T1",
    "ML6A" : "NEC FT14T2H",
    "ML6B" : "NEC FT14T2L",
    "ML6C" : "NEC F14T3B",
    "ML6D" : "NEC F14T3W",
    "ML6E" : "NEC F14S1B",
    "ML6F" : "NEC F14S1W",
    "ML70" : "NEC F15S1B",
    "ML71" : "NEC F15S1W",
    "ML72" : "NEC F18S1W",
    "ML73" : "NEC LA-1521JM (MultiSync LCD1510)",
    "ML74" : "NEC LA-1522JM (MultiSync LCD1510V)",
    "ML75" : "NEC LA-2032JM (MultiSync LCD2010)",
    "ML76" : "NEC LA-1831JM (MultiSync LCD1810)",
    "ML77" : "NEC F15R1W",
    "ML78" : "NEC F15R2W",
    "ML7A" : "NEC F15T2W",
    "ML7B" : "NEC F14T41W",
    "ML7C" : "NEC F14T41B",
    "ML7D" : "NEC F15S21W",
    "ML7E" : "NEC F15S21B",
    "ML7F" : "NEC F15T31B",
    "ML80" : "NEC F15H11W",
    "ML81" : "NEC F15R41W",
    "ML82" : "NEC F15R42W",
    "ML83" : "NEC FPD15",
    "ML84" : "NEC F15R41B",
    "ML85" : "NEC F15T31W",
    "ML87" : "NEC SlimView S530",
    "ML88" : "NEC F14T51",
    "ML89" : "NEC F15T41",
    "ML8A" : "NEC F15H21",
    "ML8B" : "NEC F15S31",
    "ML8C" : "NEC F15T52",
    "ML8D" : "NEC F15T42",
    "ML8E" : "NEC F15S32",
    "ML8F" : "NEC F14T61",
    "ML90" : "NEC F15T51",
    "ML91" : "NEC F15H31",
    "ML92" : "NEC FPD14",
    "ML93" : "NEC F15T51B",
    "ML94" : "NEC F15H41",
    "ML95" : "NEC F15R51",
    "ML96" : "NEC F15W11",
    "ML97" : "NEC F14T62",
    "ML98" : "NEC F14T63",
    "ML99" : "NEC F15T52",
    "ML9A" : "NEC F15T53",
    "ML9B" : "NEC F15R52",
    "ML9C" : "NEC F15R53",
    "ML9D" : "NEC F15W12",
    "ML9E" : "NEC F17W11",
    "ML9F" : "NEC F17R11",
    "MLA1" : "NEC F15T54",
    "MLA2" : "NEC F15R54",
    "MLA5" : "NEC F15T51BA",
    "mla5" : "",
    "MLA7" : "NEC F15H61",
    "MLA8" : "NEC F15W21",
    "MLA9" : "NEC F17W21",
    "MLAA" : "NEC F17W2A",
    "MLAE" : "NEC F15T61",
    "MLAF" : "NEC F15H71",
    "MLB0" : "NEC F17W2B",
    "MLB1" : "NEC F17W22",
    "MLB2" : "NEC F17W31",
    "MLB3" : "NEC F15T6A",
    "MLB4" : "NEC F15T62",
    "MLB5" : "NEC F16R11",
    "MLB6" : "NEC F17W41",
    "MLB7" : "NEC F17W51",
    "MLB8" : "NEC F15M01(Analog)",
    "MLBF" : "F15T71",
    "MLC0" : "F23W11",
    "MLC1" : "F15T81",
    "MLC2" : "F19R11",
    "MLC3" : "F15K02",
    "MLC4" : "F17K02",
    "MLC5" : "F17M02 digital",
    "MLC6" : "F17M02 analog",
    "MLC7" : "F17R31",
    "MLC8" : "F17W91",
    "MLC9" : "F19R21",
    "MLCA" : "F17R41",
    "MLCB" : "F19R31",
    "MLCC" : "NEC F17R51",
    "MLCD" : "F20W11",
    "MLCF" : "F17R42",
    "MLCG" : "F20W12",
    "MLCH" : "F20WZ1",
    "MLCI" : "F17R52",
    "MLCJ" : "F17R61",
    "MLCK" : "NEC F20W31",
    "MLCL" : "NEC F20WZ2",
    "MLCM" : "F17R71",
    "MP00" : "",
    "MP01" : "",
    "MP02" : "",
    "MP03" : "",
    "MP04" : "",
    "MS00" : "Surface RT display",
    "MS11" : "S415448",
    "MULT" : "MultiSync Type Monitor",
    "Mult" : "NEC PC-KM141 (MultiSync14)",
    "N001" : "Fujitsu Integrated001",
    "N002" : "Fujitsu Integrated002",
    "N003" : "Fujitsu Integrated003",
    "N004" : "Fujitsu Integrated004",
    "N005" : "Fujitsu Integrated005",
    "N006" : "Fujitsu Integrated006",
    "N007" : "Fujitsu Integrated007",
    "N008" : "Fujitsu Integrated008",
    "N009" : "Fujitsu Integrated009",
    "N010" : "Fujitsu Integrated010",
    "N011" : "",
    "N012" : "",
    "N013" : "",
    "N014" : "",
    "N015" : "",
    "N016" : "",
    "N017" : "",
    "N018" : "",
    "N019" : "",
    "N300" : "CASIO SPEEDIA N3000/N3500",
    "N400" : "CASIO COLOR PAGEPRESTO N4",
    "N403" : "CASIO COLOR PAGEPRESTO N4-612",
    "N414" : "CASIO SPEEDIA N4-614",
    "N501" : "CASIO SPEEDIA N5",
    "N510" : "CASIO SPEEDIA N5100",
    "N530" : "CASIO SPEEDIA N5300",
    "N600" : "CASIO SPEEDIA N6000",
    "NC" : "D-1",
    "NCDH" : "D1H",
    "NCDX" : "D1X",
    "NS!!" : "LS-2000",
    "NS!" : "LS-30",
    "NS" : "LS-20",
    "NS" : "LS-1000",
    "NS0" : "LS-4500",
    "NS40" : "COOLSCAN 4 ED",
    "NS4K" : "SUPER COOLSCAN 4000 ED",
    "NS8K" : "SUPER COOLSCAN 8000 ED",
    "NS@!" : "AX-210",
    "NS@" : "AX-110",
    "O101" : "CX 350",
    "OM1x" : "",
    "OM2A" : "",
    "P000" : "KL-W9000",
    "P001" : "KL-W7000",
    "P002" : "KL-W9000A",
    "P003" : "KL-W7000A",
    "P004" : "KL-W9000S",
    "P005" : "KL-X9200",
    "P310" : "Dye Sublimation Plastic Card Printer",
    "P420" : "Dye Sublimation Plastic Card Printer",
    "P520" : "Dye Sublimation Plastic Card Printer",
    "P750" : "Tektronix Phaser 750",
    "P780" : "Tektronix Phaser 780",
    "P850" : "Tektronix Phaser 850",
    "PI01" : "NEC SuperScript 700C Printer",
    "PI02" : "NEC PICTY V90",
    "PI03" : "R3 SUPER",
    "PL01" : "NEC Color MultiWiter 9000",
    "PL02" : "NEC Color MultiWiter 9050",
    "PL03" : "NEC Color MultiWiter 9200C",
    "PL04" : "NEC Color MultiWriter 9400C",
    "POFX" : "PowerPhase FX digital camera",
    "PT01" : "NEC PC-PR830L Printer",
    "R110" : "",
    "R220" : "",
    "R330" : "",
    "R440" : "",
    "R550" : "",
    "R600" : "",
    "R660" : "",
    "R700" : "UP-GR700",
    "R770" : "",
    "R880" : "",
    "R990" : "",
    "RMG0" : "OEM printer (CDPR20)",
    "RSNC" : "FUJITSU Rapidscan-C",
    "S11G" : "S101GT/102GT",
    "S12A" : "CanoScan FB1200S",
    "S12B" : "CanoScan FB1200S FAU Pos.",
    "S12C" : "CanoScan FB1200S FAU Neg.",
    "S12D" : "CanoScan FB1210U",
    "S12E" : "CanoScan N1220U",
    "S12F" : "CanoScan D1230U Reflective",
    "S12G" : "CanoScan D1230U Pos. Film",
    "S12H" : "CanoScan D1230U Neg. Film",
    "S12I" : "CanoScan N1240U",
    "S12J" : "CanoScan D1250U2 Ref.",
    "S12K" : "CanoScan D1250U2 Pos. Film",
    "S12L" : "CanoScan D1250U2 Neg. Film",
    "S12N" : "CanoScan LiDE 50",
    "S12O" : "CanoScan 3000/3000F Ref.",
    "S12P" : "CanoScan 3000/3000F Pos.",
    "S12Q" : "CanoScan 3000/3000F Neg.",
    "S12R" : "CanoScan 3000/3000F Ref. WIA",
    "S12S" : "CanoScan 3200/3200F Ref.",
    "S12T" : "CanoScan 3200/3200F Pos.",
    "S12U" : "CanoScan 3200/3200F Neg.",
    "S12V" : "CanoScan LiDE 32/30",
    "S12W" : "CanoScan LiDE 40/50",
    "S12X" : "CanoScan LiDE 35",
    "S12Y" : "CanoScan LiDE 25",
    "S12Z" : "CanoScan LiDE 60",
    "S24A" : "CanoScan D2400U Reflective",
    "S24B" : "CanoScan D2400U Pos. Film",
    "S24C" : "CanoScan D2400U Neg. Film",
    "S24D" : "CanoScan 5000/5000F Ref.",
    "S24E" : "CanoScan 5000/5000F Pos. Film",
    "S24F" : "CanoScan 5000/5000F Neg. Film",
    "S24G" : "CanoScan 8000F Ref.",
    "S24H" : "CanoScan 8000F Pos. Film",
    "S24I" : "CanoScan 8000F Neg. Film",
    "S24J" : "CanoScan LiDE 80 Ref.",
    "S24K" : "CanoScan LiDE 80 Pos.",
    "S24L" : "CanoScan LiDE 80 Neg.",
    "S24M" : "CanoScan 8200F Ref.",
    "S24N" : "CanoScan 8200F Pos.",
    "S24O" : "CanoScan 8200F Neg.",
    "S24P" : "CanoScan 5200F Ref.",
    "S24Q" : "CanoScan 5200F Pos.",
    "S24R" : "CanoScan 5200F Neg.",
    "S24S" : "CanoScan LiDE 500F Ref.",
    "S24T" : "CanoScan LiDE 500F Pos.",
    "S24U" : "CanoScan LiDE 500F Neg.",
    "S24V" : "CanoScan 5400F Ref.",
    "S24W" : "CanoScan 5400F Pos.",
    "S24X" : "CanoScan 5400F Neg.",
    "S27A" : "CanoScan 2700F",
    "S27B" : "CanoScan FS2710",
    "S27C" : "CanoScan 2700F",
    "S30A" : "IX-4025",
    "S30B" : "CanoScan300",
    "S30C" : "CanoScan 300S",
    "S30D" : "CanoScan FB320P",
    "S30E" : "CanoScan FB320S",
    "S30F" : "CanoScan FB320U",
    "S30I" : "CanoScan FB330P",
    "S30J" : "CanoScan N340P",
    "S32A" : "CanoScan 9900F Ref.",
    "S32B" : "CanoScan 9900F Pos. Film",
    "S32C" : "CanoScan 9900F Neg. Film",
    "S32D" : "CanoScan 9900F Ref. WIA",
    "S32E" : "CanoScan 4200F Ref.",
    "S32F" : "CanoScan 4200F Pos.",
    "S32G" : "CanoScan 4200F Neg.",
    "S32H" : "CanoScan 8400F Ref.",
    "S32I" : "CanoScan 8400F Pos.",
    "S32J" : "CanoScan 8400F Neg.",
    "S40A" : "IX-4015",
    "S40B" : "CanoScan600",
    "S48A" : "CanoScan 9950F Ref.",
    "S48B" : "CanoScan 9950F Pos.",
    "S48C" : "CanoScan 9950F Neg.",
    "S60B" : "CanoScan FB320P",
    "S60C" : "CanoScan FB620S",
    "S60D" : "CanoScan FB620U",
    "S60F" : "CanoScan FB630P",
    "S60G" : "CanoScan FB630U",
    "S60H" : "CanoScan N650U/N656U",
    "S60I" : "CanoScan N650U/N656U",
    "S60J" : "CanoScan N640P",
    "S60K" : "CanoScan D660U Reflective",
    "S60L" : "CanoScan D660U Pos. Film",
    "S60M" : "CanoScan D660U Neg. Film",
    "S60N" : "CanoScan D646U",
    "S60O" : "CanoScan N670U/N676U",
    "S60P" : "CanoScan LiDE 20",
    "S71G" : "S701GT/702GT",
    "S91G" : "S901G/GT",
    "SC01" : "NEC PC-IN700/6C",
    "SC02" : "NEC PC-IN700/4C",
    "SC03" : "NEC PC-IN700/6CR (MultiReader600)",
    "SC04" : "NEC PC-IN700/4CR (MultiReader400)",
    "SC05" : "NEC PC-IN700/3S (MultiReader300S)",
    "SC06" : "NEC PC-IN700/6S (MultiReader600S)",
    "SC07" : "NEC PC-IN700/6SR (MultiReader600SR)",
    "SC08" : "NEC PC-IN700/3S2 (MultiReader300S2)",
    "SC09" : "NEC PC-IN700/3U (MulitReader300U)",
    "SC0A" : "NEC PC-IN800U (MultiReader PetiScan)",
    "SC0B" : "NEC PC-IN700/6U (MultiReader 600U)",
    "SC2A" : "SmartScanner",
    "SC2B" : "SmartTwo",
    "SC2C" : "Smart720",
    "SC2D" : "Smart730",
    "SC3A" : "Smart340, Smart340L",
    "SC3B" : "Smart320 Scanner",
    "SC3D" : "Smart342 Scanner",
    "SC3E" : "Smart342L Scanner",
    "SC40" : "DFE SCX_DC40",
    "SC70" : "DFE SCX_DC70",
    "SCa1" : "Leaf DCB1 Digital Camera",
    "SCa2" : "Leaf DCB2 Digital Camera",
    "SCa3" : "Leaf DCB3 Digital Camera",
    "SCa4" : "CATCHLIGHT Digital Camera",
    "SCam" : "Leaf Volare Digital Camera",
    "SCDV" : "Dolev Plate",
    "SCEA" : "EverSmartPro Scanner",
    "SCES" : "EverSmart Scanner",
    "SCLM" : "Lotem Plate",
    "SCP1" : "APP Printer 1",
    "SCP2" : "APP Printer 2",
    "SCP3" : "APP Printer 3",
    "SCP4" : "APP Printer 4",
    "SCP5" : "APP Printer 5",
    "SCRT" : "Kodak Professional Small Format CRT Printer",
    "SCSP" : "EverSmartSupreme Scanner",
    "SCTP" : "Plate",
    "SDP1" : "SDP Printer 1",
    "SDP2" : "SDP Printer 2",
    "SDP3" : "SDP Printer 3",
    "SDP4" : "SDP Printer 4",
    "SDP5" : "SDP Printer 5",
    "sj2c" : "HP ScanJet IIc",
    "SLFP" : "Spectro LFP",
    "SN00" : "CanoScan LiDE 600F Nega",
    "SN02" : "CanoScan 4400F Nega",
    "SN03" : "CanoScan 8600F Nega",
    "SN05" : "CanoScan 8800F Nega",
    "SP00" : "CanoScan LiDE 600F Posi",
    "SP02" : "CanoScan 4400F Posi",
    "SP03" : "CanoScan 8600F Posi",
    "SP05" : "CanoScan 8800F Posi",
    "SR00" : "CanoScan LiDE 600F Ref.",
    "SR01" : "CanoScan LiDE 70",
    "SR02" : "CanoScan 4400F Ref.",
    "SR03" : "CanoScan 8600F Ref.",
    "SR04" : "CanoScan LiDE 80",
    "SR05" : "CanoScan 8800F Ref.",
    "sRGB" : "",
    "SWNG" : "Spectro Swing",
    "T17E" : "MT-8617/9017E",
    "T21E" : "MT-9021E",
    "TOSH" : "",
    "V150" : "CASIO SPEEDIA V1500",
    "V201" : "CASIO SPEEDIA V2",
    "vcgt" : "",
    "VM01" : "VGP-D23HD1",
    "W17A" : "W17-LC50",
    "W23A" : "W23-LC50",
    "WN00" : "icUlntNumber",
    "X555" : "",
    "y" : "PS3REGIST_8412",
    "Z11" : "Lexmark Z11",
    "Z31" : "Lexmark Z31",
    "Z51" : "Lexmark Z51"
}

readable_relations = {
    "model" : models,
    "manufacturer": manufacturers,
    "creator" : manufacturers
}
